<?php
/**
 * States
 *
 * Returns an array of country states. This deprecates and replaces the /states/ directory found in older versions.
 * States should be defined in English and translated native through localisation files.
 * Country codes and states (or province) names should follow the Unicode CLDR recommendation (https://cldr.unicode.org/translation/displaynames/countryregion-territory-names).
 * Countries defined with empty arrays have no states.
 *
 * @package WooCommerce\i18n
 * @version 3.8.0
 */

defined( 'ABSPATH' ) || exit;

return array(
	'AF' => array(),
	'AL' => array( // Albanian states.
		'AL-01' => __( 'Berat', 'woocommerce' ),
		'AL-09' => __( 'Dibër', 'woocommerce' ),
		'AL-02' => __( 'Durrës', 'woocommerce' ),
		'AL-03' => __( 'Elbasan', 'woocommerce' ),
		'AL-04' => __( 'Fier', 'woocommerce' ),
		'AL-05' => __( 'Gjirokastër', 'woocommerce' ),
		'AL-06' => __( 'Korçë', 'woocommerce' ),
		'AL-07' => __( 'Kukës', 'woocommerce' ),
		'AL-08' => __( 'Lezhë', 'woocommerce' ),
		'AL-10' => __( 'Shkodër', 'woocommerce' ),
		'AL-11' => __( 'Tirana', 'woocommerce' ),
		'AL-12' => __( 'Vlorë', 'woocommerce' ),
	),
	'AO' => array( // Angolan states.
		'BGO' => __( '本戈', 'woocommerce' ),
		'BLU' => __( '本格拉', 'woocommerce' ),
		'BIE' => __( '比耶', 'woocommerce' ),
		'CAB' => __( '卡宾达', 'woocommerce' ),
		'CNN' => __( '库内内', 'woocommerce' ),
		'HUA' => __( '万博', 'woocommerce' ),
		'HUI' => __( '威拉', 'woocommerce' ),
		'CCU' => __( '宽多-库邦戈', 'woocommerce' ),
		'CNO' => __( '北宽扎', 'woocommerce' ),
		'CUS' => __( '南宽扎', 'woocommerce' ),
		'LUA' => __( '罗安达', 'woocommerce' ),
		'LNO' => __( '北隆达', 'woocommerce' ),
		'LSU' => __( '南隆达', 'woocommerce' ),
		'MAL' => __( '马兰热', 'woocommerce' ),
		'MOX' => __( '莫希科', 'woocommerce' ),
		'NAM' => __( '纳米贝', 'woocommerce' ),
		'UIG' => __( '威热', 'woocommerce' ),
		'ZAI' => __( '扎伊尔', 'woocommerce' ),
	),
	'AR' => array( // Argentinian provinces.
		'C' => __( '布宜诺斯艾利斯自治市', 'woocommerce' ),
		'B' => __( '布宜诺斯艾利斯', 'woocommerce' ),
		'K' => __( '布宜诺斯艾利斯自治市', 'woocommerce' ),
		'H' => __( '查科', 'woocommerce' ),
		'U' => __( '丘布特', 'woocommerce' ),
		'X' => __( '科尔多瓦', 'woocommerce' ),
		'W' => __( '科连特斯', 'woocommerce' ),
		'E' => __( '恩特雷里奥斯省', 'woocommerce' ),
		'P' => __( '福尔摩沙', 'woocommerce' ),
		'Y' => __( '胡胡伊', 'woocommerce' ),
		'L' => __( '拉潘帕', 'woocommerce' ),
		'F' => __( 'La Rioja', 'woocommerce' ),
		'M' => __( '门多萨', 'woocommerce' ),
		'N' => __( '米西奥内斯', 'woocommerce' ),
		'Q' => __( '内乌肯', 'woocommerce' ),
		'R' => __( '内格罗河省', 'woocommerce' ),
		'A' => __( '萨尔塔', 'woocommerce' ),
		'J' => __( '圣胡安', 'woocommerce' ),
		'D' => __( '圣路易', 'woocommerce' ),
		'Z' => __( '圣克鲁斯', 'woocommerce' ),
		'S' => __( '圣菲', 'woocommerce' ),
		'G' => __( '圣地亚哥-德尔埃斯特罗', 'woocommerce' ),
		'V' => __( '火地岛', 'woocommerce' ),
		'T' => __( '图库曼', 'woocommerce' ),
	),
	'AT' => array(),
	'AU' => array( // Australian states.
		'ACT' => __( '澳大利亚首都直辖区', 'woocommerce' ),
		'NSW' => __( '新南威尔士州', 'woocommerce' ),
		'NT'  => __( '北领地', 'woocommerce' ),
		'QLD' => __( '昆士兰', 'woocommerce' ),
		'SA'  => __( '南澳大利亚', 'woocommerce' ),
		'TAS' => __( '塔斯马尼亚', 'woocommerce' ),
		'VIC' => __( '维多利亚', 'woocommerce' ),
		'WA'  => __( '西澳大利亚州', 'woocommerce' ),
	),
	'AX' => array(),
	'BD' => array( // Bangladeshi districts.
		'BD-05' => __( '巴格尔哈特', 'woocommerce' ),
		'BD-01' => __( '班多尔班', 'woocommerce' ),
		'BD-02' => __( '巴尔古纳', 'woocommerce' ),
		'BD-06' => __( '巴里萨尔', 'woocommerce' ),
		'BD-07' => __( '波拉', 'woocommerce' ),
		'BD-03' => __( '博格拉', 'woocommerce' ),
		'BD-04' => __( '布拉曼巴里亚', 'woocommerce' ),
		'BD-09' => __( '昌德浦', 'woocommerce' ),
		'BD-10' => __( 'Chattogram', 'woocommerce' ),
		'BD-12' => __( '朱瓦当加', 'woocommerce' ),
		'BD-11' => __( "科克斯巴扎尔", 'woocommerce' ),
		'BD-08' => __( '科米拉', 'woocommerce' ),
		'BD-13' => __( '达卡', 'woocommerce' ),
		'BD-14' => __( '迪纳杰布尔', 'woocommerce' ),
		'BD-15' => __( '福里德布尔', 'woocommerce' ),
		'BD-16' => __( '费尼', 'woocommerce' ),
		'BD-19' => __( '贝哈尔', 'woocommerce' ),
		'BD-18' => __( '加济布尔', 'woocommerce' ),
		'BD-17' => __( '戈帕尔甘杰', 'woocommerce' ),
		'BD-20' => __( '霍比甘杰', 'woocommerce' ),
		'BD-21' => __( '杰马勒布尔', 'woocommerce' ),
		'BD-22' => __( 'Jashore', 'woocommerce' ),
		'BD-25' => __( '恰洛加蒂', 'woocommerce' ),
		'BD-23' => __( '切尼达', 'woocommerce' ),
		'BD-24' => __( '焦伊布尔哈德', 'woocommerce' ),
		'BD-29' => __( '科格拉焦里', 'woocommerce' ),
		'BD-27' => __( '库尔纳', 'woocommerce' ),
		'BD-26' => __( '吉绍尔甘杰', 'woocommerce' ),
		'BD-28' => __( '古里格拉姆', 'woocommerce' ),
		'BD-30' => __( '库什蒂亚', 'woocommerce' ),
		'BD-31' => __( '罗基布尔', 'woocommerce' ),
		'BD-32' => __( '拉尔莫尼哈德', 'woocommerce' ),
		'BD-36' => __( '马达里布尔', 'woocommerce' ),
		'BD-37' => __( '马古拉', 'woocommerce' ),
		'BD-33' => __( '马尼格甘杰 ', 'woocommerce' ),
		'BD-39' => __( '莫赫尔普', 'woocommerce' ),
		'BD-38' => __( '毛尔维巴扎尔', 'woocommerce' ),
		'BD-35' => __( '蒙希甘杰', 'woocommerce' ),
		'BD-34' => __( '迈门辛', 'woocommerce' ),
		'BD-48' => __( '瑙冈', 'woocommerce' ),
		'BD-43' => __( '诺拉尔', 'woocommerce' ),
		'BD-40' => __( '纳拉扬甘杰', 'woocommerce' ),
		'BD-42' => __( '诺尔辛迪', 'woocommerce' ),
		'BD-44' => __( '诺多尔', 'woocommerce' ),
		'BD-45' => __( '讷瓦布根杰', 'woocommerce' ),
		'BD-41' => __( '内德罗戈纳', 'woocommerce' ),
		'BD-46' => __( '尼尔帕马里', 'woocommerce' ),
		'BD-47' => __( '诺阿卡利', 'woocommerce' ),
		'BD-49' => __( '巴布纳', 'woocommerce' ),
		'BD-52' => __( '班乔戈尔', 'woocommerce' ),
		'BD-51' => __( '博杜阿卡利', 'woocommerce' ),
		'BD-50' => __( '比罗杰布尔', 'woocommerce' ),
		'BD-53' => __( '拉杰巴里', 'woocommerce' ),
		'BD-54' => __( '拉杰沙希', 'woocommerce' ),
		'BD-56' => __( ' 兰加马蒂', 'woocommerce' ),
		'BD-55' => __( '朗布尔', 'woocommerce' ),
		'BD-58' => __( '萨德基拉', 'woocommerce' ),
		'BD-62' => __( '沙里亚德布尔', 'woocommerce' ),
		'BD-57' => __( '谢尔布尔', 'woocommerce' ),
		'BD-59' => __( '锡拉杰甘杰', 'woocommerce' ),
		'BD-61' => __( '苏纳姆甘杰', 'woocommerce' ),
		'BD-60' => __( '锡尔赫特', 'woocommerce' ),
		'BD-63' => __( '坦盖尔', 'woocommerce' ),
		'BD-64' => __( '塔古尔冈', 'woocommerce' ),
	),
	'BE' => array(),
	'BG' => array( // Bulgarian states.
		'BG-01' => __( 'Blagoevgrad', 'woocommerce' ),
		'BG-02' => __( 'Burgas', 'woocommerce' ),
		'BG-08' => __( 'Dobrich', 'woocommerce' ),
		'BG-07' => __( 'Gabrovo', 'woocommerce' ),
		'BG-26' => __( 'Haskovo', 'woocommerce' ),
		'BG-09' => __( 'Kardzhali', 'woocommerce' ),
		'BG-10' => __( 'Kyustendil', 'woocommerce' ),
		'BG-11' => __( 'Lovech', 'woocommerce' ),
		'BG-12' => __( '蒙大拿', 'woocommerce' ),
		'BG-13' => __( 'Pazardzhik', 'woocommerce' ),
		'BG-14' => __( 'Pernik', 'woocommerce' ),
		'BG-15' => __( 'Pleven', 'woocommerce' ),
		'BG-16' => __( 'Plovdiv', 'woocommerce' ),
		'BG-17' => __( 'Razgrad', 'woocommerce' ),
		'BG-18' => __( 'Ruse', 'woocommerce' ),
		'BG-27' => __( 'Shumen', 'woocommerce' ),
		'BG-19' => __( 'Silistra', 'woocommerce' ),
		'BG-20' => __( 'Sliven', 'woocommerce' ),
		'BG-21' => __( 'Smolyan', 'woocommerce' ),
		'BG-23' => __( 'Sofia', 'woocommerce' ),
		'BG-22' => __( 'Sofia-Grad', 'woocommerce' ),
		'BG-24' => __( 'Stara Zagora', 'woocommerce' ),
		'BG-25' => __( 'Targovishte', 'woocommerce' ),
		'BG-03' => __( 'Varna', 'woocommerce' ),
		'BG-04' => __( 'Veliko Tarnovo', 'woocommerce' ),
		'BG-05' => __( 'Vidin', 'woocommerce' ),
		'BG-06' => __( 'Vratsa', 'woocommerce' ),
		'BG-28' => __( 'Yambol', 'woocommerce' ),
	),
	'BH' => array(),
	'BI' => array(),
	'BJ' => array( // Beninese states.
		'AL' => __( '阿黎博里', 'woocommerce' ),
		'AK' => __( '阿塔科拉', 'woocommerce' ),
		'AQ' => __( '大西洋', 'woocommerce' ),
		'BO' => __( '博尔古', 'woocommerce' ),
		'CO' => __( '丘陵', 'woocommerce' ),
		'KO' => __( '库福', 'woocommerce' ),
		'DO' => __( '东嘎', 'woocommerce' ),
		'LI' => __( '利特洛', 'woocommerce' ),
		'MO' => __( '莫努', 'woocommerce' ),
		'OU' => __( '乌尔美', 'woocommerce' ),
		'PL' => __( '高原', 'woocommerce' ),
		'ZO' => __( '祖', 'woocommerce' ),
	),
	'BO' => array( // Bolivian states.
		'BO-B' => __( '贝尼', 'woocommerce' ),
		'BO-H' => __( '丘基萨卡', 'woocommerce' ),
		'BO-C' => __( '科恰班巴', 'woocommerce' ),
		'BO-L' => __( '拉巴斯', 'woocommerce' ),
		'BO-O' => __( '奥鲁罗', 'woocommerce' ),
		'BO-N' => __( '潘多', 'woocommerce' ),
		'BO-P' => __( '波多西', 'woocommerce' ),
		'BO-S' => __( '圣克鲁斯', 'woocommerce' ),
		'BO-T' => __( '塔里哈', 'woocommerce' ),
	),
	'BR' => array( // Brazilian states.
		'AC' => __( '英亩', 'woocommerce' ),
		'AL' => __( '阿拉戈斯州', 'woocommerce' ),
		'AP' => __( '阿马帕州', 'woocommerce' ),
		'AM' => __( '亚马逊', 'woocommerce' ),
		'BA' => __( '巴伊亚', 'woocommerce' ),
		'CE' => __( '塞阿拉', 'woocommerce' ),
		'DF' => __( '联邦首都区', 'woocommerce' ),
		'ES' => __( '圣埃斯皮里图州', 'woocommerce' ),
		'GO' => __( '戈亚斯', 'woocommerce' ),
		'MA' => __( '马拉尼昂州', 'woocommerce' ),
		'MT' => __( '马托格罗索', 'woocommerce' ),
		'MS' => __( 'Mato Grosso do Sul', 'woocommerce' ),
		'MG' => __( 'Minas Gerais', 'woocommerce' ),
		'PA' => __( '帕拉', 'woocommerce' ),
		'PB' => __( '帕拉伊巴州', 'woocommerce' ),
		'PR' => __( '柏拉拿州', 'woocommerce' ),
		'PE' => __( '伯南布哥', 'woocommerce' ),
		'PI' => __( '皮奥伊州', 'woocommerce' ),
		'RJ' => __( '里约热内卢', 'woocommerce' ),
		'RN' => __( '北里奥格兰德', 'woocommerce' ),
		'RS' => __( '南里奥格兰德', 'woocommerce' ),
		'RO' => __( '朗多尼亚州', 'woocommerce' ),
		'RR' => __( '罗赖马', 'woocommerce' ),
		'SC' => __( '圣卡塔琳娜', 'woocommerce' ),
		'SP' => __( '圣保罗', 'woocommerce' ),
		'SE' => __( '塞尔希培', 'woocommerce' ),
		'TO' => __( '托坎廷斯', 'woocommerce' ),
	),
	'CA' => array( // Canadian states.
		'AB' => __( '阿尔伯塔', 'woocommerce' ),
		'BC' => __( '不列颠哥伦比亚', 'woocommerce' ),
		'MB' => __( '马尼托巴', 'woocommerce' ),
		'NB' => __( '新不伦瑞克', 'woocommerce' ),
		'NL' => __( '纽芬兰与拉布拉多', 'woocommerce' ),
		'NT' => __( '西北地区', 'woocommerce' ),
		'NS' => __( '新斯科舍', 'woocommerce' ),
		'NU' => __( '努纳武特地区', 'woocommerce' ),
		'ON' => __( '安大略', 'woocommerce' ),
		'PE' => __( '爱德华王子岛', 'woocommerce' ),
		'QC' => __( '魁北克', 'woocommerce' ),
		'SK' => __( '萨斯喀彻温省', 'woocommerce' ),
		'YT' => __( '育空地区', 'woocommerce' ),
	),
	'CH' => array( // Swiss cantons.
		'AG' => __( '阿尔高州', 'woocommerce' ),
		'AR' => __( '外阿彭策尔州', 'woocommerce' ),
		'AI' => __( '内阿彭策尔州', 'woocommerce' ),
		'BL' => __( '巴泽尔乡村半州', 'woocommerce' ),
		'BS' => __( '巴塞尔城市州', 'woocommerce' ),
		'BE' => __( '伯尔尼', 'woocommerce' ),
		'FR' => __( '弗里堡', 'woocommerce' ),
		'GE' => __( '日内瓦', 'woocommerce' ),
		'GL' => __( '格拉鲁斯州', 'woocommerce' ),
		'GR' => __( '格劳宾登州', 'woocommerce' ),
		'JU' => __( '汝拉州', 'woocommerce' ),
		'LU' => __( '卢塞恩', 'woocommerce' ),
		'NE' => __( '纳沙泰尔州', 'woocommerce' ),
		'NW' => __( '下瓦尔登州', 'woocommerce' ),
		'OW' => __( '上瓦尔登', 'woocommerce' ),
		'SH' => __( '沙夫豪森', 'woocommerce' ),
		'SZ' => __( '施维茨', 'woocommerce' ),
		'SO' => __( '索洛图恩', 'woocommerce' ),
		'SG' => __( '圣加仑', 'woocommerce' ),
		'TG' => __( '图尔高', 'woocommerce' ),
		'TI' => __( '提契诺州', 'woocommerce' ),
		'UR' => __( '乌里', 'woocommerce' ),
		'VS' => __( '瓦莱州', 'woocommerce' ),
		'VD' => __( '沃州', 'woocommerce' ),
		'ZG' => __( '楚格', 'woocommerce' ),
		'ZH' => __( '苏黎世', 'woocommerce' ),
	),
	'CL' => array( // Chilean states.
		'CL-AI' => __( 'Aisén del General Carlos Ibañez del Campo', 'woocommerce' ),
		'CL-AN' => __( 'Antofagasta', 'woocommerce' ),
		'CL-AP' => __( 'Arica y Parinacota', 'woocommerce' ),
		'CL-AR' => __( 'La Araucanía', 'woocommerce' ),
		'CL-AT' => __( 'Atacama', 'woocommerce' ),
		'CL-BI' => __( 'Biobío', 'woocommerce' ),
		'CL-CO' => __( 'Coquimbo', 'woocommerce' ),
		'CL-LI' => __( 'Libertador General Bernardo O\'Higgins', 'woocommerce' ),
		'CL-LL' => __( 'Los Lagos', 'woocommerce' ),
		'CL-LR' => __( 'Los Ríos', 'woocommerce' ),
		'CL-MA' => __( 'Magallanes', 'woocommerce' ),
		'CL-ML' => __( '毛勒', 'woocommerce' ),
		'CL-NB' => __( 'Ñuble', 'woocommerce' ),
		'CL-RM' => __( 'Región Metropolitana de Santiago', 'woocommerce' ),
		'CL-TA' => __( 'Tarapacá', 'woocommerce' ),
		'CL-VS' => __( 'Valparaíso', 'woocommerce' ),
	),
	'CN' => array( // Chinese states.
		'CN1'  => __( '云南', 'woocommerce' ),
		'CN2'  => __( '北京', 'woocommerce' ),
		'CN3'  => __( '天津', 'woocommerce' ),
		'CN4'  => __( '河北', 'woocommerce' ),
		'CN5'  => __( '山西', 'woocommerce' ),
		'CN6'  => __( '內蒙古', 'woocommerce' ),
		'CN7'  => __( '辽宁', 'woocommerce' ),
		'CN8'  => __( '吉林', 'woocommerce' ),
		'CN9'  => __( '黑龙江', 'woocommerce' ),
		'CN10' => __( '上海', 'woocommerce' ),
		'CN11' => __( '江苏', 'woocommerce' ),
		'CN12' => __( '浙江', 'woocommerce' ),
		'CN13' => __( '安徽', 'woocommerce' ),
		'CN14' => __( '福建', 'woocommerce' ),
		'CN15' => __( '江西', 'woocommerce' ),
		'CN16' => __( '山东', 'woocommerce' ),
		'CN17' => __( '河南', 'woocommerce' ),
		'CN18' => __( '湖北', 'woocommerce' ),
		'CN19' => __( '湖南', 'woocommerce' ),
		'CN20' => __( '广东', 'woocommerce' ),
		'CN21' => __( '广西', 'woocommerce' ),
		'CN22' => __( '海南', 'woocommerce' ),
		'CN23' => __( '重庆', 'woocommerce' ),
		'CN24' => __( '四川', 'woocommerce' ),
		'CN25' => __( '贵州', 'woocommerce' ),
		'CN26' => __( '陕西', 'woocommerce' ),
		'CN27' => __( '甘肃', 'woocommerce' ),
		'CN28' => __( '青海', 'woocommerce' ),
		'CN29' => __( '宁夏', 'woocommerce' ),
		'CN30' => __( '澳门', 'woocommerce' ),
		'CN31' => __( '西藏', 'woocommerce' ),
		'CN32' => __( '新疆', 'woocommerce' ),
	),
	'CO' => array( // Colombian states.
		'CO-AMA' => __( '亚马逊', 'woocommerce' ),
		'CO-ANT' => __( 'Antioquia', 'woocommerce' ),
		'CO-ARA' => __( 'Arauca', 'woocommerce' ),
		'CO-ATL' => __( 'Atlántico', 'woocommerce' ),
		'CO-BOL' => __( '玻利瓦尔', 'woocommerce' ),
		'CO-BOY' => __( 'Boyacá', 'woocommerce' ),
		'CO-CAL' => __( 'Caldas', 'woocommerce' ),
		'CO-CAQ' => __( 'Caquetá', 'woocommerce' ),
		'CO-CAS' => __( 'Casanare', 'woocommerce' ),
		'CO-CAU' => __( 'Cauca', 'woocommerce' ),
		'CO-CES' => __( 'Cesar', 'woocommerce' ),
		'CO-CHO' => __( 'Chocó', 'woocommerce' ),
		'CO-COR' => __( '科尔多瓦', 'woocommerce' ),
		'CO-CUN' => __( 'Cundinamarca', 'woocommerce' ),
		'CO-DC' => __( 'Capital District', 'woocommerce' ),
		'CO-GUA' => __( 'Guainía', 'woocommerce' ),
		'CO-GUV' => __( 'Guaviare', 'woocommerce' ),
		'CO-HUI' => __( 'Huila', 'woocommerce' ),
		'CO-LAG' => __( 'La Guajira', 'woocommerce' ),
		'CO-MAG' => __( 'Magdalena', 'woocommerce' ),
		'CO-MET' => __( '元数据', 'woocommerce' ),
		'CO-NAR' => __( 'Nariño', 'woocommerce' ),
		'CO-NSA' => __( 'Norte de Santander', 'woocommerce' ),
		'CO-PUT' => __( 'Putumayo', 'woocommerce' ),
		'CO-QUI' => __( 'Quindío', 'woocommerce' ),
		'CO-RIS' => __( 'Risaralda', 'woocommerce' ),
		'CO-SAN' => __( 'Santander', 'woocommerce' ),
		'CO-SAP' => __( 'San Andrés & Providencia', 'woocommerce' ),
		'CO-SUC' => __( '苏克雷', 'woocommerce' ),
		'CO-TOL' => __( 'Tolima', 'woocommerce' ),
		'CO-VAC' => __( 'Valle del Cauca', 'woocommerce' ),
		'CO-VAU' => __( 'Vaupés', 'woocommerce' ),
		'CO-VID' => __( 'Vichada', 'woocommerce' ),
	),
	'CR' => array( // Costa Rican states.
		'CR-A' => __( 'Alajuela', 'woocommerce' ),
		'CR-C' => __( 'Cartago', 'woocommerce' ),
		'CR-G' => __( 'Guanacaste', 'woocommerce' ),
		'CR-H' => __( 'Heredia', 'woocommerce' ),
		'CR-L' => __( 'Limón', 'woocommerce' ),
		'CR-P' => __( 'Puntarenas', 'woocommerce' ),
		'CR-SJ' => __( 'San José', 'woocommerce' ),
	),
	'CZ' => array(),
	'DE' => array( // German states.
		'DE-BW' => __( '巴登-符腾堡', 'woocommerce' ),
		'DE-BY' => __( '巴伐利亚', 'woocommerce' ),
		'DE-BE' => __( '柏林', 'woocommerce' ),
		'DE-BB' => __( '勃兰登堡', 'woocommerce' ),
		'DE-HB' => __( '不来梅', 'woocommerce' ),
		'DE-HH' => __( '汉堡', 'woocommerce' ),
		'DE-HE' => __( '黑森', 'woocommerce' ),
		'DE-MV' => __( '梅克伦堡-前波美拉尼亚', 'woocommerce' ),
		'DE-NI' => __( '下萨克森', 'woocommerce' ),
		'DE-NW' => __( '北莱茵-威斯特法伦', 'woocommerce' ),
		'DE-RP' => __( '莱茵兰-普法尔茨', 'woocommerce' ),
		'DE-SL' => __( '萨尔区', 'woocommerce' ),
		'DE-SN' => __( '萨克森', 'woocommerce' ),
		'DE-ST' => __( '萨克森-安哈尔特', 'woocommerce' ),
		'DE-SH' => __( '石勒苏益格-荷尔斯泰因', 'woocommerce' ),
		'DE-TH' => __( '图林根', 'woocommerce' ),
	),
	'DK' => array(),
	'DO' => array( // Dominican states.
		'DO-01' => __( '国家特区', 'woocommerce' ),
		'DO-02' => __( '阿苏阿', 'woocommerce' ),
		'DO-03' => __( '巴奥鲁科', 'woocommerce' ),
		'DO-04' => __( '巴拉奥纳', 'woocommerce' ),
		'DO-33' => __( 'Cibao Nordeste', 'woocommerce' ),
		'DO-34' => __( 'Cibao Noroeste', 'woocommerce' ),
		'DO-35' => __( 'Cibao Norte', 'woocommerce' ),
		'DO-36' => __( 'Cibao Sur', 'woocommerce' ),
		'DO-05' => __( '达哈翁', 'woocommerce' ),
		'DO-06' => __( '杜阿尔特', 'woocommerce' ),
		'DO-08' => __( '赛堡省', 'woocommerce' ),
		'DO-37' => __( 'El Valle', 'woocommerce' ),
		'DO-07' => __( '艾利斯皮亚省', 'woocommerce' ),
		'DO-38' => __( 'Enriquillo', 'woocommerce' ),		
		'DO-09' => __( '埃斯帕拉特', 'woocommerce' ),
		'DO-30' => __( '阿托马约', 'woocommerce' ),
		'DO-19' => __( '米拉贝姐妹省', 'woocommerce' ),
		'DO-39' => __( 'Higüamo', 'woocommerce' ),
		'DO-10' => __( '独立市', 'woocommerce' ),
		'DO-11' => __( '阿尔塔格拉西亚', 'woocommerce' ),
		'DO-12' => __( '拉罗马纳', 'woocommerce' ),
		'DO-13' => __( '拉贝加', 'woocommerce' ),
		'DO-14' => __( '玛丽亚特立尼达桑切斯', 'woocommerce' ),
		'DO-28' => __( '主教·瑙黎省', 'woocommerce' ),
		'DO-15' => __( '蒙特克里斯蒂', 'woocommerce' ),
		'DO-29' => __( '蒙特普拉塔', 'woocommerce' ),
		'DO-40' => __( 'Ozama', 'woocommerce' ),
		'DO-16' => __( '佩德纳勒斯', 'woocommerce' ),
		'DO-17' => __( '佩拉维亚', 'woocommerce' ),
		'DO-18' => __( '普拉塔港', 'woocommerce' ),
		'DO-20' => __( '萨马纳', 'woocommerce' ),
		'DO-21' => __( '圣克里斯托瓦尔', 'woocommerce' ),
		'DO-31' => __( '圣何塞德奥科阿', 'woocommerce' ),
		'DO-22' => __( '圣胡安', 'woocommerce' ),
		'DO-23' => __( '圣佩德罗德马科里斯', 'woocommerce' ),
		'DO-24' => __( '桑切斯·拉米斯省', 'woocommerce' ),
		'DO-25' => __( '圣地亚哥', 'woocommerce' ),
		'DO-26' => __( '圣地亚哥罗德里格斯', 'woocommerce' ),
		'DO-32' => __( '圣多明各', 'woocommerce' ),
		'DO-41' => __( 'Valdesia', 'woocommerce' ),
		'DO-27' => __( '巴尔韦德', 'woocommerce' ),
		'DO-42' => __( 'Yuma', 'woocommerce' ),
	),
	'DZ' => array( // Algerian states.
		'DZ-01' => __( '阿德拉尔', 'woocommerce' ),
		'DZ-02' => __( '切尔夫', 'woocommerce' ),
		'DZ-03' => __( '拉古特', 'woocommerce' ),
		'DZ-04' => __( '乌姆布瓦吉', 'woocommerce' ),
		'DZ-05' => __( '巴特纳', 'woocommerce' ),
		'DZ-06' => __( '贝贾亚', 'woocommerce' ),
		'DZ-07' => __( '比斯克拉', 'woocommerce' ),
		'DZ-08' => __( '贝沙尔', 'woocommerce' ),
		'DZ-09' => __( '卜利达', 'woocommerce' ),
		'DZ-10' => __( '布维拉', 'woocommerce' ),
		'DZ-11' => __( '塔曼拉塞特', 'woocommerce' ),
		'DZ-12' => __( '泰贝萨', 'woocommerce' ),
		'DZ-13' => __( '特莱姆森', 'woocommerce' ),
		'DZ-14' => __( '提亚雷特', 'woocommerce' ),
		'DZ-15' => __( '提济乌祖', 'woocommerce' ),
		'DZ-16' => __( '阿尔及尔', 'woocommerce' ),
		'DZ-17' => __( '杰勒法', 'woocommerce' ),
		'DZ-18' => __( '吉杰勒', 'woocommerce' ),
		'DZ-19' => __( '塞提夫', 'woocommerce' ),
		'DZ-20' => __( '赛伊达', 'woocommerce' ),
		'DZ-21' => __( '斯基克达', 'woocommerce' ),
		'DZ-22' => __( '西迪·贝勒·阿贝斯', 'woocommerce' ),
		'DZ-23' => __( '安那巴', 'woocommerce' ),
		'DZ-24' => __( '盖勒马', 'woocommerce' ),
		'DZ-25' => __( '君士坦丁', 'woocommerce' ),
		'DZ-26' => __( '麦迪亚', 'woocommerce' ),
		'DZ-27' => __( '穆斯塔加奈姆', 'woocommerce' ),
		'DZ-28' => __( '姆西拉', 'woocommerce' ),
		'DZ-29' => __( '马斯卡拉', 'woocommerce' ),
		'DZ-30' => __( '瓦尔格拉', 'woocommerce' ),
		'DZ-31' => __( '奥兰', 'woocommerce' ),
		'DZ-32' => __( '贝伊德', 'woocommerce' ),
		'DZ-33' => __( '伊利奇', 'woocommerce' ),
		'DZ-34' => __( '布阿拉里季堡', 'woocommerce' ),
		'DZ-35' => __( '布米尔达斯', 'woocommerce' ),
		'DZ-36' => __( '塔里夫', 'woocommerce' ),
		'DZ-37' => __( '廷杜夫', 'woocommerce' ),
		'DZ-38' => __( '提塞姆西勒特', 'woocommerce' ),
		'DZ-39' => __( '阿伯迪', 'woocommerce' ),
		'DZ-40' => __( '汉舍莱', 'woocommerce' ),
		'DZ-41' => __( '苏格艾赫拉斯', 'woocommerce' ),
		'DZ-42' => __( '蒂巴萨', 'woocommerce' ),
		'DZ-43' => __( '米拉', 'woocommerce' ),
		'DZ-44' => __( '艾因迪夫拉', 'woocommerce' ),
		'DZ-45' => __( '尼伊玛', 'woocommerce' ),
		'DZ-46' => __( '艾因泰穆尚特', 'woocommerce' ),
		'DZ-47' => __( '盖尔达耶', 'woocommerce' ),
		'DZ-48' => __( '埃利赞', 'woocommerce' ),
	),
	'EE' => array(),
	'EC' => array( // Ecuadorian states.
		'EC-A' => __( 'Azuay', 'woocommerce' ),
		'EC-B' => __( '玻利瓦尔', 'woocommerce' ),
		'EC-F' => __( 'Cañar', 'woocommerce' ),
		'EC-C' => __( 'Carchi', 'woocommerce' ),
		'EC-H' => __( 'Chimborazo', 'woocommerce' ),
		'EC-X' => __( 'Cotopaxi', 'woocommerce' ),
		'EC-O' => __( 'El Oro', 'woocommerce' ),
		'EC-E' => __( 'Esmeraldas', 'woocommerce' ),
		'EC-W' => __( 'Galápagos', 'woocommerce' ),
		'EC-G' => __( 'Guayas', 'woocommerce' ),
		'EC-I' => __( 'Imbabura', 'woocommerce' ),
		'EC-L' => __( 'Loja', 'woocommerce' ),
		'EC-R' => __( 'Los Ríos', 'woocommerce' ),
		'EC-M' => __( 'Manabí', 'woocommerce' ),
		'EC-S' => __( 'Morona-Santiago', 'woocommerce' ),
		'EC-N' => __( 'Napo', 'woocommerce' ),
		'EC-D' => __( 'Orellana', 'woocommerce' ),
		'EC-Y' => __( 'Pastaza', 'woocommerce' ),
		'EC-P' => __( 'Pichincha', 'woocommerce' ),
		'EC-SE' => __( 'Santa Elena', 'woocommerce' ),
		'EC-SD' => __( 'Santo Domingo de los Tsáchilas', 'woocommerce' ),
		'EC-U' => __( 'Sucumbíos', 'woocommerce' ),
		'EC-T' => __( 'Tungurahua', 'woocommerce' ),
		'EC-Z' => __( 'Zamora-Chinchipe', 'woocommerce' ),
	),
	'EG' => array( // Egyptian states.
		'EGALX' => __( '亚历山大', 'woocommerce' ),
		'EGASN' => __( '阿斯旺', 'woocommerce' ),
		'EGAST' => __( '艾斯尤特', 'woocommerce' ),
		'EGBA'  => __( '红海', 'woocommerce' ),
		'EGBH'  => __( '佩雷拉', 'woocommerce' ),
		'EGBNS' => __( '贝尼苏韦夫', 'woocommerce' ),
		'EGC'   => __( '开罗', 'woocommerce' ),
		'EGDK'  => __( '代盖赫利耶', 'woocommerce' ),
		'EGDT'  => __( '达米埃塔', 'woocommerce' ),
		'EGFYM' => __( '法尤姆', 'woocommerce' ),
		'EGGH'  => __( '西部', 'woocommerce' ),
		'EGGZ'  => __( '吉萨', 'woocommerce' ),
		'EGIS'  => __( '伊斯梅利亚', 'woocommerce' ),
		'EGJS'  => __( '南西奈', 'woocommerce' ),
		'EGKB'  => __( '卡流比亚', 'woocommerce' ),
		'EGKFS' => __( '卡夫拉谢赫', 'woocommerce' ),
		'EGKN'  => __( '基纳', 'woocommerce' ),
		'EGLX'  => __( '卢克索', 'woocommerce' ),
		'EGMN'  => __( '明亚', 'woocommerce' ),
		'EGMNF' => __( '米努夫', 'woocommerce' ),
		'EGMT'  => __( '马特鲁', 'woocommerce' ),
		'EGPTS' => __( '塞得港', 'woocommerce' ),
		'EGSHG' => __( '索哈杰', 'woocommerce' ),
		'EGSHR' => __( '艾尔沙拉齐亚', 'woocommerce' ),
		'EGSIN' => __( '北西奈', 'woocommerce' ),
		'EGSUZ' => __( '苏伊士', 'woocommerce' ),
		'EGWAD' => __( '新河谷', 'woocommerce' ),
	),
	'ES' => array( // Spanish states.
		'C'  => __( '拉科鲁尼亚', 'woocommerce' ),
		'VI' => __( '阿拉瓦', 'woocommerce' ),
		'AB' => __( 'Albacete', 'woocommerce' ),
		'A'  => __( 'Alicante', 'woocommerce' ),
		'AL' => __( '阿尔梅里亚', 'woocommerce' ),
		'O'  => __( 'Asturias', 'woocommerce' ),
		'AV' => __( '阿维拉', 'woocommerce' ),
		'BA' => __( 'Badajoz', 'woocommerce' ),
		'PM' => __( 'Baleares', 'woocommerce' ),
		'B'  => __( '巴塞罗那', 'woocommerce' ),
		'BU' => __( '布尔戈斯', 'woocommerce' ),
		'CC' => __( '卡塞雷斯', 'woocommerce' ),
		'CA' => __( '加的斯', 'woocommerce' ),
		'S'  => __( 'Cantabria', 'woocommerce' ),
		'CS' => __( '卡斯特利翁', 'woocommerce' ),
		'CE' => __( 'Ceuta', 'woocommerce' ),
		'CR' => __( 'Ciudad Real', 'woocommerce' ),
		'CO' => __( '科尔多瓦', 'woocommerce' ),
		'CU' => __( 'Cuenca', 'woocommerce' ),
		'GI' => __( 'Girona', 'woocommerce' ),
		'GR' => __( 'Granada', 'woocommerce' ),
		'GU' => __( 'Guadalajara', 'woocommerce' ),
		'SS' => __( 'Gipuzkoa', 'woocommerce' ),
		'H'  => __( 'Huelva', 'woocommerce' ),
		'HU' => __( 'Huesca', 'woocommerce' ),
		'J'  => __( '哈恩', 'woocommerce' ),
		'LO' => __( 'La Rioja', 'woocommerce' ),
		'GC' => __( 'Las Palmas', 'woocommerce' ),
		'LE' => __( '利昂', 'woocommerce' ),
		'L'  => __( 'Lleida', 'woocommerce' ),
		'LU' => __( 'Lugo', 'woocommerce' ),
		'M'  => __( 'Madrid', 'woocommerce' ),
		'MA' => __( '马拉加', 'woocommerce' ),
		'ML' => __( 'Melilla', 'woocommerce' ),
		'MU' => __( 'Murcia', 'woocommerce' ),
		'NA' => __( 'Navarra', 'woocommerce' ),
		'OR' => __( 'Ourense', 'woocommerce' ),
		'P'  => __( 'Palencia', 'woocommerce' ),
		'PO' => __( 'Pontevedra', 'woocommerce' ),
		'SA' => __( 'Salamanca', 'woocommerce' ),
		'TF' => __( 'Santa Cruz de Tenerife', 'woocommerce' ),
		'SG' => __( 'Segovia', 'woocommerce' ),
		'SE' => __( 'Sevilla', 'woocommerce' ),
		'SO' => __( 'Soria', 'woocommerce' ),
		'T'  => __( 'Tarragona', 'woocommerce' ),
		'TE' => __( 'Teruel', 'woocommerce' ),
		'TO' => __( 'Toledo', 'woocommerce' ),
		'V'  => __( 'Valencia', 'woocommerce' ),
		'VA' => __( 'Valladolid', 'woocommerce' ),
		'BI' => __( '比斯开', 'woocommerce' ),
		'ZA' => __( 'Zamora', 'woocommerce' ),
		'Z'  => __( '萨拉戈萨', 'woocommerce' ),
	),
	'FI' => array(),
	'FR' => array(),
	'GF' => array(),
	'GH' => array( // Ghanaian regions.
		'AF' => __( '阿哈福地区', 'woocommerce' ),
		'AH' => __( '阿散蒂地区', 'woocommerce' ),
		'BA' => __( '布朗阿哈福地区', 'woocommerce' ),
		'BO' => __( '波诺地区', 'woocommerce' ),
		'BE' => __( '波诺东部地区', 'woocommerce' ),
		'CP' => __( '中央省', 'woocommerce' ),
		'EP' => __( '东部', 'woocommerce' ),
		'AA' => __( '大阿克拉地区', 'woocommerce' ),
		'NE' => __( '东北地区', 'woocommerce' ),
		'NP' => __( '北部', 'woocommerce' ),
		'OT' => __( '奥蒂河', 'woocommerce' ),
		'SV' => __( '萨凡纳', 'woocommerce' ),
		'UE' => __( '上东城', 'woocommerce' ),
		'UW' => __( '上西城', 'woocommerce' ),
		'TV' => __( '沃尔特', 'woocommerce' ),
		'GC' => __( '西部', 'woocommerce' ),
		'WN' => __( '西北地区', 'woocommerce' ),
	),
	'GP' => array(),
	'GR' => array( // Greek regions.
		'I' => __( '阿提卡', 'woocommerce' ),
		'A' => __( '东马其顿和色雷斯', 'woocommerce' ),
		'B' => __( '中马其顿', 'woocommerce' ),
		'C' => __( '西马其顿', 'woocommerce' ),
		'D' => __( '伊庇鲁斯', 'woocommerce' ),
		'E' => __( '塞萨利', 'woocommerce' ),
		'F' => __( '爱奥尼亚群岛', 'woocommerce' ),
		'G' => __( '希腊西部', 'woocommerce' ),
		'H' => __( '希腊中部', 'woocommerce' ),
		'J' => __( '伯罗奔尼撒', 'woocommerce' ),
		'K' => __( '北爱琴海', 'woocommerce' ),
		'L' => __( '南爱琴海', 'woocommerce' ),
		'M' => __( '克里特岛', 'woocommerce' ),
	),
	'GT' => array( // Guatemalan states.
		'GT-AV' => __( '上维拉帕斯', 'woocommerce' ),
		'GT-BV' => __( '下维拉帕斯', 'woocommerce' ),
		'GT-CM' => __( '奇马尔特南戈', 'woocommerce' ),
		'GT-CQ' => __( '奇基穆拉', 'woocommerce' ),
		'GT-PR' => __( '埃尔普罗格雷索', 'woocommerce' ),
		'GT-ES' => __( '埃斯昆特拉', 'woocommerce' ),
		'GT-GU' => __( '危地马拉', 'woocommerce' ),
		'GT-HU' => __( '韦韦特南戈', 'woocommerce' ),
		'GT-IZ' => __( '伊扎巴尔', 'woocommerce' ),
		'GT-JA' => __( '贾拉帕', 'woocommerce' ),
		'GT-JU' => __( '胡蒂亚帕', 'woocommerce' ),
		'GT-PE' => __( '佩登', 'woocommerce' ),
		'GT-QZ' => __( '克萨尔特南戈', 'woocommerce' ),
		'GT-QC' => __( '基切', 'woocommerce' ),
		'GT-RE' => __( '雷塔卢莱乌', 'woocommerce' ),
		'GT-SA' => __( '萨卡特佩克斯', 'woocommerce' ),
		'GT-SM' => __( '圣马科斯', 'woocommerce' ),
		'GT-SR' => __( '圣罗萨', 'woocommerce' ),
		'GT-SO' => __( '索洛拉', 'woocommerce' ),
		'GT-SU' => __( '苏奇特佩克斯', 'woocommerce' ),
		'GT-TO' => __( '托托尼卡潘', 'woocommerce' ),
		'GT-ZA' => __( '萨凯帕', 'woocommerce' ),
	),
	'HK' => array( // Hong Kong states.
		'HONG KONG'       => __( '香港岛', 'woocommerce' ),
		'KOWLOON'         => __( 'Kowloon', 'woocommerce' ),
		'NEW TERRITORIES' => __( '新界', 'woocommerce' ),
	),
	'HN' => array( // Honduran states.
		'HN-AT' => __( 'Atlántida', 'woocommerce' ),
		'HN-IB' => __( 'Bay Islands', 'woocommerce' ),
		'HN-CH' => __( 'Choluteca', 'woocommerce' ),
		'HN-CL' => __( 'Colón', 'woocommerce' ),
		'HN-CM' => __( 'Comayagua', 'woocommerce' ),
		'HN-CP' => __( 'Copán', 'woocommerce' ),
		'HN-CR' => __( 'Cortés', 'woocommerce' ),
		'HN-EP' => __( 'El Paraíso', 'woocommerce' ),
		'HN-FM' => __( 'Francisco Morazán', 'woocommerce' ),
		'HN-GD' => __( 'Gracias a Dios', 'woocommerce' ),
		'HN-IN' => __( 'Intibucá', 'woocommerce' ),
		'HN-LE' => __( 'Lempira', 'woocommerce' ),
		'HN-LP' => __( '拉巴斯', 'woocommerce' ),
		'HN-OC' => __( 'Ocotepeque', 'woocommerce' ),
		'HN-OL' => __( 'Olancho', 'woocommerce' ),
		'HN-SB' => __( 'Santa Bárbara', 'woocommerce' ),
		'HN-VA' => __( 'Valle', 'woocommerce' ),
		'HN-YO' => __( 'Yoro', 'woocommerce' ),
	),
	'HU' => array( // Hungarian states.
		'BK' => __( 'Bács-Kiskun', 'woocommerce' ),
		'BE' => __( 'Békés', 'woocommerce' ),
		'BA' => __( 'Baranya', 'woocommerce' ),
		'BZ' => __( 'Borsod-Abaúj-Zemplén', 'woocommerce' ),
		'BU' => __( 'Budapest', 'woocommerce' ),
		'CS' => __( '琼格拉德-乔纳德', 'woocommerce' ),
		'FE' => __( 'Fejér', 'woocommerce' ),
		'GS' => __( 'Győr-Moson-Sopron', 'woocommerce' ),
		'HB' => __( 'Hajdú-Bihar', 'woocommerce' ),
		'HE' => __( 'Heves', 'woocommerce' ),
		'JN' => __( 'Jász-Nagykun-Szolnok', 'woocommerce' ),
		'KE' => __( 'Komárom-Esztergom', 'woocommerce' ),
		'NO' => __( 'Nógrád', 'woocommerce' ),
		'PE' => __( 'Pest', 'woocommerce' ),
		'SO' => __( 'Somogy', 'woocommerce' ),
		'SZ' => __( 'Szabolcs-Szatmár-Bereg', 'woocommerce' ),
		'TO' => __( 'Tolna', 'woocommerce' ),
		'VA' => __( 'Vas', 'woocommerce' ),
		'VE' => __( 'Veszprém', 'woocommerce' ),
		'ZA' => __( 'Zala', 'woocommerce' ),
	),
	'ID' => array( // Indonesian provinces.
		'AC' => __( 'Daerah Istimewa Aceh', 'woocommerce' ),
		'SU' => __( 'Sumatera Utara', 'woocommerce' ),
		'SB' => __( 'Sumatera Barat', 'woocommerce' ),
		'RI' => __( 'Riau', 'woocommerce' ),
		'KR' => __( 'Kepulauan Riau', 'woocommerce' ),
		'JA' => __( 'Jambi', 'woocommerce' ),
		'SS' => __( 'Sumatera Selatan', 'woocommerce' ),
		'BB' => __( 'Bangka Belitung', 'woocommerce' ),
		'BE' => __( 'Bengkulu', 'woocommerce' ),
		'LA' => __( 'Lampung', 'woocommerce' ),
		'JK' => __( 'DKI Jakarta', 'woocommerce' ),
		'JB' => __( 'Jawa Barat', 'woocommerce' ),
		'BT' => __( 'Banten', 'woocommerce' ),
		'JT' => __( 'Jawa Tengah', 'woocommerce' ),
		'JI' => __( 'Jawa Timur', 'woocommerce' ),
		'YO' => __( 'Daerah Istimewa Yogyakarta', 'woocommerce' ),
		'BA' => __( 'Bali', 'woocommerce' ),
		'NB' => __( 'Nusa Tenggara Barat', 'woocommerce' ),
		'NT' => __( 'Nusa Tenggara Timur', 'woocommerce' ),
		'KB' => __( 'Kalimantan Barat', 'woocommerce' ),
		'KT' => __( 'Kalimantan Tengah', 'woocommerce' ),
		'KI' => __( 'Kalimantan Timur', 'woocommerce' ),
		'KS' => __( 'Kalimantan Selatan', 'woocommerce' ),
		'KU' => __( 'Kalimantan Utara', 'woocommerce' ),
		'SA' => __( 'Sulawesi Utara', 'woocommerce' ),
		'ST' => __( 'Sulawesi Tengah', 'woocommerce' ),
		'SG' => __( 'Sulawesi Tenggara', 'woocommerce' ),
		'SR' => __( 'Sulawesi Barat', 'woocommerce' ),
		'SN' => __( 'Sulawesi Selatan', 'woocommerce' ),
		'GO' => __( 'Gorontalo', 'woocommerce' ),
		'MA' => __( 'Maluku', 'woocommerce' ),
		'MU' => __( 'Maluku Utara', 'woocommerce' ),
		'PA' => __( '巴布亚新几内亚', 'woocommerce' ),
		'PB' => __( '巴布亚新几内亚', 'woocommerce' ),
	),
	'IE' => array( // Irish states.
		'CW' => __( '卡洛', 'woocommerce' ),
		'CN' => __( '卡万', 'woocommerce' ),
		'CE' => __( '克莱尔', 'woocommerce' ),
		'CO' => __( '软木', 'woocommerce' ),
		'DL' => __( '多尼加尔', 'woocommerce' ),
		'D'  => __( '都柏林', 'woocommerce' ),
		'G'  => __( '高威', 'woocommerce' ),
		'KY' => __( '克里', 'woocommerce' ),
		'KE' => __( '基尔达勒', 'woocommerce' ),
		'KK' => __( '基尔肯尼', 'woocommerce' ),
		'LS' => __( '劳瓦', 'woocommerce' ),
		'LM' => __( '莱特林', 'woocommerce' ),
		'LK' => __( '利默里克', 'woocommerce' ),
		'LD' => __( '朗福德', 'woocommerce' ),
		'LH' => __( '卢斯', 'woocommerce' ),
		'MO' => __( '梅奥', 'woocommerce' ),
		'MH' => __( '迈思', 'woocommerce' ),
		'MN' => __( '莫纳汉', 'woocommerce' ),
		'OY' => __( '奥法利', 'woocommerce' ),
		'RN' => __( '罗丝康门', 'woocommerce' ),
		'SO' => __( '斯利戈', 'woocommerce' ),
		'TA' => __( '雷里', 'woocommerce' ),
		'WD' => __( '沃特福德', 'woocommerce' ),
		'WH' => __( '韦斯特迈思', 'woocommerce' ),
		'WX' => __( '韦克斯福德', 'woocommerce' ),
		'WW' => __( '威克洛', 'woocommerce' ),
	),
	'IN' => array( // Indian states.
		'AP' => __( '安得拉邦', 'woocommerce' ),
		'AR' => __( 'Arunachal Pradesh', 'woocommerce' ),
		'AS' => __( 'Assam', 'woocommerce' ),
		'BR' => __( 'Bihar', 'woocommerce' ),
		'CT' => __( 'Chhattisgarh', 'woocommerce' ),
		'GA' => __( 'Goa', 'woocommerce' ),
		'GJ' => __( 'Gujarat', 'woocommerce' ),
		'HR' => __( 'Haryana', 'woocommerce' ),
		'HP' => __( 'Himachal Pradesh', 'woocommerce' ),
		'JK' => __( '查谟和喀什米尔', 'woocommerce' ),
		'JH' => __( 'Jharkhand', 'woocommerce' ),
		'KA' => __( 'Karnataka', 'woocommerce' ),
		'KL' => __( 'Kerala', 'woocommerce' ),
		'LA' => __( 'Ladakh', 'woocommerce' ),
		'MP' => __( 'Madhya Pradesh', 'woocommerce' ),
		'MH' => __( 'Maharashtra', 'woocommerce' ),
		'MN' => __( 'Manipur', 'woocommerce' ),
		'ML' => __( 'Meghalaya', 'woocommerce' ),
		'MZ' => __( 'Mizoram', 'woocommerce' ),
		'NL' => __( 'Nagaland', 'woocommerce' ),
		'OR' => __( '奥里萨邦', 'woocommerce' ),
		'PB' => __( 'Punjab', 'woocommerce' ),
		'RJ' => __( 'Rajasthan', 'woocommerce' ),
		'SK' => __( 'Sikkim', 'woocommerce' ),
		'TN' => __( 'Tamil Nadu', 'woocommerce' ),
		'TS' => __( '泰伦加纳', 'woocommerce' ),
		'TR' => __( 'Tripura', 'woocommerce' ),
		'UK' => __( '北阿坎德', 'woocommerce' ),
		'UP' => __( 'Uttar Pradesh', 'woocommerce' ),
		'WB' => __( '西弗吉尼亚州', 'woocommerce' ),
		'AN' => __( '特克斯和凯科斯群岛', 'woocommerce' ),
		'CH' => __( 'Chandigarh', 'woocommerce' ),
		'DN' => __( 'Dadar and Nagar Haveli', 'woocommerce' ),
		'DD' => __( '达曼和第乌', 'woocommerce' ),
		'DL' => __( 'Delhi', 'woocommerce' ),
		'LD' => __( 'Lakshadeep', 'woocommerce' ),
		'PY' => __( 'Pondicherry (Puducherry)', 'woocommerce' ),
	),
	'IR' => array( // Irania states.
		'KHZ' => __( 'Khuzestan (خوزستان)', 'woocommerce' ),
		'THR' => __( 'Tehran (تهران)', 'woocommerce' ),
		'ILM' => __( 'Ilaam (ایلام)', 'woocommerce' ),
		'BHR' => __( 'Bushehr (بوشهر)', 'woocommerce' ),
		'ADL' => __( 'Ardabil (اردبیل)', 'woocommerce' ),
		'ESF' => __( 'Isfahan (اصفهان)', 'woocommerce' ),
		'YZD' => __( 'Yazd (یزد)', 'woocommerce' ),
		'KRH' => __( 'Kermanshah (کرمانشاه)', 'woocommerce' ),
		'KRN' => __( 'Kerman (کرمان)', 'woocommerce' ),
		'HDN' => __( 'Hamadan (همدان)', 'woocommerce' ),
		'GZN' => __( 'Ghazvin (قزوین)', 'woocommerce' ),
		'ZJN' => __( 'Zanjan (زنجان)', 'woocommerce' ),
		'LRS' => __( 'Luristan (لرستان)', 'woocommerce' ),
		'ABZ' => __( 'Alborz (البرز)', 'woocommerce' ),
		'EAZ' => __( 'East Azarbaijan (آذربایجان شرقی)', 'woocommerce' ),
		'WAZ' => __( 'West Azarbaijan (آذربایجان غربی)', 'woocommerce' ),
		'CHB' => __( 'Chaharmahal and Bakhtiari (چهارمحال و بختیاری)', 'woocommerce' ),
		'SKH' => __( 'South Khorasan (خراسان جنوبی)', 'woocommerce' ),
		'RKH' => __( 'Razavi Khorasan (خراسان رضوی)', 'woocommerce' ),
		'NKH' => __( '北呼罗珊省 (خراسان جنوبی)', 'woocommerce' ),
		'SMN' => __( 'Semnan (سمنان)', 'woocommerce' ),
		'FRS' => __( 'Fars (فارس)', 'woocommerce' ),
		'QHM' => __( 'Qom (قم)', 'woocommerce' ),
		'KRD' => __( 'Kurdistan / کردستان)', 'woocommerce' ),
		'KBD' => __( 'Kohgiluyeh and BoyerAhmad (کهگیلوییه و بویراحمد)', 'woocommerce' ),
		'GLS' => __( 'Golestan (گلستان)', 'woocommerce' ),
		'GIL' => __( 'Gilan (گیلان)', 'woocommerce' ),
		'MZN' => __( 'Mazandaran (مازندران)', 'woocommerce' ),
		'MKZ' => __( 'Markazi (مرکزی)', 'woocommerce' ),
		'HRZ' => __( 'Hormozgan (هرمزگان)', 'woocommerce' ),
		'SBN' => __( 'Sistan and Baluchestan (سیستان و بلوچستان)', 'woocommerce' ),
	),
	'IS' => array(),
	'IT' => array( // Italian provinces.
		'AG' => __( 'Agrigento', 'woocommerce' ),
		'AL' => __( 'Alessandria', 'woocommerce' ),
		'AN' => __( 'Ancona', 'woocommerce' ),
		'AO' => __( 'Aosta', 'woocommerce' ),
		'AR' => __( 'Arezzo', 'woocommerce' ),
		'AP' => __( 'Ascoli Piceno', 'woocommerce' ),
		'AT' => __( 'Asti', 'woocommerce' ),
		'AV' => __( 'Avellino', 'woocommerce' ),
		'BA' => __( '巴里', 'woocommerce' ),
		'BT' => __( 'Barletta-Andria-Trani', 'woocommerce' ),
		'BL' => __( 'Belluno', 'woocommerce' ),
		'BN' => __( 'Benevento', 'woocommerce' ),
		'BG' => __( 'Bergamo', 'woocommerce' ),
		'BI' => __( 'Biella', 'woocommerce' ),
		'BO' => __( 'Bologna', 'woocommerce' ),
		'BZ' => __( 'Bolzano', 'woocommerce' ),
		'BS' => __( 'Brescia', 'woocommerce' ),
		'BR' => __( 'Brindisi', 'woocommerce' ),
		'CA' => __( 'Cagliari', 'woocommerce' ),
		'CL' => __( 'Caltanissetta', 'woocommerce' ),
		'CB' => __( 'Campobasso', 'woocommerce' ),
		'CE' => __( 'Caserta', 'woocommerce' ),
		'CT' => __( 'Catania', 'woocommerce' ),
		'CZ' => __( 'Catanzaro', 'woocommerce' ),
		'CH' => __( 'Chieti', 'woocommerce' ),
		'CO' => __( 'Como', 'woocommerce' ),
		'CS' => __( 'Cosenza', 'woocommerce' ),
		'CR' => __( 'Cremona', 'woocommerce' ),
		'KR' => __( 'Crotone', 'woocommerce' ),
		'CN' => __( 'Cuneo', 'woocommerce' ),
		'EN' => __( 'Enna', 'woocommerce' ),
		'FM' => __( 'Fermo', 'woocommerce' ),
		'FE' => __( 'Ferrara', 'woocommerce' ),
		'FI' => __( 'Firenze', 'woocommerce' ),
		'FG' => __( 'Foggia', 'woocommerce' ),
		'FC' => __( 'Forlì-Cesena', 'woocommerce' ),
		'FR' => __( 'Frosinone', 'woocommerce' ),
		'GE' => __( 'Genova', 'woocommerce' ),
		'GO' => __( 'Gorizia', 'woocommerce' ),
		'GR' => __( 'Grosseto', 'woocommerce' ),
		'IM' => __( 'Imperia', 'woocommerce' ),
		'IS' => __( 'Isernia', 'woocommerce' ),
		'SP' => __( 'La Spezia', 'woocommerce' ),
		'AQ' => __( "L&apos;Aquila", 'woocommerce' ),
		'LT' => __( 'Latina', 'woocommerce' ),
		'LE' => __( 'Lecce', 'woocommerce' ),
		'LC' => __( '莱科', 'woocommerce' ),
		'LI' => __( '利沃诺', 'woocommerce' ),
		'LO' => __( '洛迪', 'woocommerce' ),
		'LU' => __( '卢卡', 'woocommerce' ),
		'MC' => __( '马切拉塔', 'woocommerce' ),
		'MN' => __( '曼托瓦', 'woocommerce' ),
		'MS' => __( '马萨 - 卡拉拉', 'woocommerce' ),
		'MT' => __( '马泰拉', 'woocommerce' ),
		'ME' => __( '墨西拿', 'woocommerce' ),
		'MI' => __( 'Milano', 'woocommerce' ),
		'MO' => __( 'Modena', 'woocommerce' ),
		'MB' => __( 'Monza e della Brianza', 'woocommerce' ),
		'NA' => __( 'Napoli', 'woocommerce' ),
		'NO' => __( 'Novara', 'woocommerce' ),
		'NU' => __( 'Nuoro', 'woocommerce' ),
		'OR' => __( 'Oristano', 'woocommerce' ),
		'PD' => __( 'Padova', 'woocommerce' ),
		'PA' => __( 'Palermo', 'woocommerce' ),
		'PR' => __( 'Parma', 'woocommerce' ),
		'PV' => __( 'Pavia', 'woocommerce' ),
		'PG' => __( 'Perugia', 'woocommerce' ),
		'PU' => __( 'Pesaro e Urbino', 'woocommerce' ),
		'PE' => __( 'Pescara', 'woocommerce' ),
		'PC' => __( 'Piacenza', 'woocommerce' ),
		'PI' => __( 'Pisa', 'woocommerce' ),
		'PT' => __( 'Pistoia', 'woocommerce' ),
		'PN' => __( 'Pordenone', 'woocommerce' ),
		'PZ' => __( 'Potenza', 'woocommerce' ),
		'PO' => __( 'Prato', 'woocommerce' ),
		'RG' => __( 'Ragusa', 'woocommerce' ),
		'RA' => __( 'Ravenna', 'woocommerce' ),
		'RC' => __( 'Reggio Calabria', 'woocommerce' ),
		'RE' => __( 'Reggio Emilia', 'woocommerce' ),
		'RI' => __( 'Rieti', 'woocommerce' ),
		'RN' => __( 'Rimini', 'woocommerce' ),
		'RM' => __( 'Roma', 'woocommerce' ),
		'RO' => __( 'Rovigo', 'woocommerce' ),
		'SA' => __( 'Salerno', 'woocommerce' ),
		'SS' => __( 'Sassari', 'woocommerce' ),
		'SV' => __( 'Savona', 'woocommerce' ),
		'SI' => __( 'Siena', 'woocommerce' ),
		'SR' => __( 'Siracusa', 'woocommerce' ),
		'SO' => __( 'Sondrio', 'woocommerce' ),
		'SU' => __( '南撒丁岛', 'woocommerce' ),
		'TA' => __( 'Taranto', 'woocommerce' ),
		'TE' => __( 'Teramo', 'woocommerce' ),
		'TR' => __( 'Terni', 'woocommerce' ),
		'TO' => __( 'Torino', 'woocommerce' ),
		'TP' => __( 'Trapani', 'woocommerce' ),
		'TN' => __( 'Trento', 'woocommerce' ),
		'TV' => __( 'Treviso', 'woocommerce' ),
		'TS' => __( 'Trieste', 'woocommerce' ),
		'UD' => __( 'Udine', 'woocommerce' ),
		'VA' => __( 'Varese', 'woocommerce' ),
		'VE' => __( 'Venezia', 'woocommerce' ),
		'VB' => __( 'Verbano-Cusio-Ossola', 'woocommerce' ),
		'VC' => __( 'Vercelli', 'woocommerce' ),
		'VR' => __( 'Verona', 'woocommerce' ),
		'VV' => __( 'Vibo Valentia', 'woocommerce' ),
		'VI' => __( 'Vicenza', 'woocommerce' ),
		'VT' => __( 'Viterbo', 'woocommerce' ),
	),
	'IL' => array(),
	'IM' => array(),
	'JM' => array( // Jamaican parishes.
		'JM-01' => __( '金斯敦', 'woocommerce' ),
		'JM-02' => __( '圣安德鲁', 'woocommerce' ),
		'JM-03' => __( '波特兰', 'woocommerce' ),
		'JM-04' => __( '波特兰', 'woocommerce' ),
		'JM-05' => __( '圣玛丽', 'woocommerce' ),
		'JM-06' => __( '圣安娜', 'woocommerce' ),
		'JM-07' => __( '特里洛尼', 'woocommerce' ),
		'JM-08' => __( '圣雅各', 'woocommerce' ),
		'JM-09' => __( '汉诺威', 'woocommerce' ),
		'JM-10' => __( '韦斯特摩兰', 'woocommerce' ),
		'JM-11' => __( '圣伊丽莎白', 'woocommerce' ),
		'JM-12' => __( '曼彻斯特', 'woocommerce' ),
		'JM-13' => __( '克拉伦登', 'woocommerce' ),
		'JM-14' => __( '圣凯瑟琳', 'woocommerce' ),
	),

	/**
	 * Japanese states.
	 *
	 * English notation of prefectures conform to the notation of Japan Post.
	 * The suffix corresponds with the Japanese translation file.
	 */
	'JP' => array(
		'JP01' => __( 'Hokkaido', 'woocommerce' ),
		'JP02' => __( 'Aomori', 'woocommerce' ),
		'JP03' => __( 'Iwate', 'woocommerce' ),
		'JP04' => __( 'Miyagi', 'woocommerce' ),
		'JP05' => __( 'Akita', 'woocommerce' ),
		'JP06' => __( 'Yamagata', 'woocommerce' ),
		'JP07' => __( 'Fukushima', 'woocommerce' ),
		'JP08' => __( 'Ibaraki', 'woocommerce' ),
		'JP09' => __( 'Tochigi', 'woocommerce' ),
		'JP10' => __( 'Gunma', 'woocommerce' ),
		'JP11' => __( 'Saitama', 'woocommerce' ),
		'JP12' => __( 'Chiba', 'woocommerce' ),
		'JP13' => __( '东京', 'woocommerce' ),
		'JP14' => __( 'Kanagawa', 'woocommerce' ),
		'JP15' => __( 'Niigata', 'woocommerce' ),
		'JP16' => __( 'Toyama', 'woocommerce' ),
		'JP17' => __( 'Ishikawa', 'woocommerce' ),
		'JP18' => __( 'Fukui', 'woocommerce' ),
		'JP19' => __( 'Yamanashi', 'woocommerce' ),
		'JP20' => __( 'Nagano', 'woocommerce' ),
		'JP21' => __( 'Gifu', 'woocommerce' ),
		'JP22' => __( 'Shizuoka', 'woocommerce' ),
		'JP23' => __( 'Aichi', 'woocommerce' ),
		'JP24' => __( 'Mie', 'woocommerce' ),
		'JP25' => __( 'Shiga', 'woocommerce' ),
		'JP26' => __( '京都', 'woocommerce' ),
		'JP27' => __( 'Osaka', 'woocommerce' ),
		'JP28' => __( '兵库', 'woocommerce' ),
		'JP29' => __( 'Nara', 'woocommerce' ),
		'JP30' => __( 'Wakayama', 'woocommerce' ),
		'JP31' => __( 'Tottori', 'woocommerce' ),
		'JP32' => __( 'Shimane', 'woocommerce' ),
		'JP33' => __( 'Okayama', 'woocommerce' ),
		'JP34' => __( 'Hiroshima', 'woocommerce' ),
		'JP35' => __( 'Yamaguchi', 'woocommerce' ),
		'JP36' => __( 'Tokushima', 'woocommerce' ),
		'JP37' => __( 'Kagawa', 'woocommerce' ),
		'JP38' => __( 'Ehime', 'woocommerce' ),
		'JP39' => __( 'Kochi', 'woocommerce' ),
		'JP40' => __( 'Fukuoka', 'woocommerce' ),
		'JP41' => __( 'Saga', 'woocommerce' ),
		'JP42' => __( 'Nagasaki', 'woocommerce' ),
		'JP43' => __( 'Kumamoto', 'woocommerce' ),
		'JP44' => __( 'Oita', 'woocommerce' ),
		'JP45' => __( 'Miyazaki', 'woocommerce' ),
		'JP46' => __( 'Kagoshima', 'woocommerce' ),
		'JP47' => __( '冲绳岛', 'woocommerce' ),
	),
	'KE' => array( // Kenyan counties.
		'KE01' => __( '巴林戈', 'woocommerce' ),
		'KE02' => __( '博美特', 'woocommerce' ),
		'KE03' => __( '邦戈马', 'woocommerce' ),
		'KE04' => __( 'Busia', 'woocommerce' ),
		'KE05' => __( '埃尔格约-马拉奎特', 'woocommerce' ),
		'KE06' => __( '恩布', 'woocommerce' ),
		'KE07' => __( '加里萨', 'woocommerce' ),
		'KE08' => __( '霍马湾', 'woocommerce' ),
		'KE09' => __( '伊西奥洛', 'woocommerce' ),
		'KE10' => __( '卡贾多', 'woocommerce' ),
		'KE11' => __( '卡卡梅加', 'woocommerce' ),
		'KE12' => __( '凯里乔', 'woocommerce' ),
		'KE13' => __( '基安布', 'woocommerce' ),
		'KE14' => __( '基利菲', 'woocommerce' ),
		'KE15' => __( '基里尼亚加', 'woocommerce' ),
		'KE16' => __( '基西', 'woocommerce' ),
		'KE17' => __( '基苏木', 'woocommerce' ),
		'KE18' => __( '基土伊', 'woocommerce' ),
		'KE19' => __( '夸乐', 'woocommerce' ),
		'KE20' => __( '莱基皮亚', 'woocommerce' ),
		'KE21' => __( '拉谟', 'woocommerce' ),
		'KE22' => __( '马查科斯', 'woocommerce' ),
		'KE23' => __( '马瓜尼', 'woocommerce' ),
		'KE24' => __( '曼德拉', 'woocommerce' ),
		'KE25' => __( '马萨比特', 'woocommerce' ),
		'KE26' => __( '梅鲁', 'woocommerce' ),
		'KE27' => __( '米戈利', 'woocommerce' ),
		'KE28' => __( '蒙巴萨', 'woocommerce' ),
		'KE29' => __( '穆拉雅', 'woocommerce' ),
		'KE30' => __( '内罗毕郡', 'woocommerce' ),
		'KE31' => __( '纳库鲁', 'woocommerce' ),
		'KE32' => __( '南迪', 'woocommerce' ),
		'KE33' => __( '纳罗克', 'woocommerce' ),
		'KE34' => __( '尼亚米拉', 'woocommerce' ),
		'KE35' => __( '年达鲁阿', 'woocommerce' ),
		'KE36' => __( '涅里', 'woocommerce' ),
		'KE37' => __( '桑布鲁', 'woocommerce' ),
		'KE38' => __( '西阿亚', 'woocommerce' ),
		'KE39' => __( '泰塔塔维塔', 'woocommerce' ),
		'KE40' => __( '塔纳河', 'woocommerce' ),
		'KE41' => __( '塔拉卡尼迪', 'woocommerce' ),
		'KE42' => __( '特兰斯-恩佐亚', 'woocommerce' ),
		'KE43' => __( '图尔卡纳', 'woocommerce' ),
		'KE44' => __( '瓦辛吉苏', 'woocommerce' ),
		'KE45' => __( '韦希加', 'woocommerce' ),
		'KE46' => __( '瓦吉尔', 'woocommerce' ),
		'KE47' => __( '西波克特', 'woocommerce' ),
	),
	'KR' => array(),
	'KW' => array(),
	'LA' => array( // Laotian provinces.
		'AT' => __( '阿速坡', 'woocommerce' ),
		'BK' => __( '博胶', 'woocommerce' ),
		'BL' => __( '波里坎赛', 'woocommerce' ),
		'CH' => __( '占巴色', 'woocommerce' ),
		'HO' => __( '华潘', 'woocommerce' ),
		'KH' => __( '甘蒙', 'woocommerce' ),
		'LM' => __( '琅南塔', 'woocommerce' ),
		'LP' => __( '琅勃拉邦', 'woocommerce' ),
		'OU' => __( '乌多姆塞', 'woocommerce' ),
		'PH' => __( '丰沙里', 'woocommerce' ),
		'SL' => __( '沙拉湾', 'woocommerce' ),
		'SV' => __( '沙湾拿吉', 'woocommerce' ),
		'VI' => __( '万象省', 'woocommerce' ),
		'VT' => __( '万象', 'woocommerce' ),
		'XA' => __( '沙耶武里', 'woocommerce' ),
		'XE' => __( '塞公', 'woocommerce' ),
		'XI' => __( '川圹', 'woocommerce' ),
		'XS' => __( '赛宋奔', 'woocommerce' ),
	),
	'LB' => array(),
	'LR' => array( // Liberian provinces.
		'BM' => __( 'Bomi', 'woocommerce' ),
		'BN' => __( 'Bong', 'woocommerce' ),
		'GA' => __( 'Gbarpolu', 'woocommerce' ),
		'GB' => __( 'Grand Bassa', 'woocommerce' ),
		'GC' => __( 'Grand Cape Mount', 'woocommerce' ),
		'GG' => __( 'Grand Gedeh', 'woocommerce' ),
		'GK' => __( 'Grand Kru', 'woocommerce' ),
		'LO' => __( '洛法', 'woocommerce' ),
		'MA' => __( 'Margibi', 'woocommerce' ),
		'MY' => __( '马里兰', 'woocommerce' ),
		'MO' => __( 'Montserrado', 'woocommerce' ),
		'NM' => __( 'Nimba', 'woocommerce' ),
		'RV' => __( 'Rivercess', 'woocommerce' ),
		'RG' => __( 'River Gee', 'woocommerce' ),
		'SN' => __( 'Sinoe', 'woocommerce' ),
	),
	'LU' => array(),
	'MD' => array( // Moldovan states.
		'C'  => __( '基希讷乌', 'woocommerce' ),
		'BL' => __( '巴蒂', 'woocommerce' ),
		'AN' => __( 'Anenii Noi / 新阿内尼', 'woocommerce' ),
		'BS' => __( 'Basarabeasca', 'woocommerce' ),
		'BR' => __( 'Briceni / 布里切尼区', 'woocommerce' ),
		'CH' => __( 'Cahul / 卡胡尔', 'woocommerce' ),
		'CT' => __( 'Cantemir / 冈代米尔区', 'woocommerce' ),
		'CL' => __( '克勒拉希', 'woocommerce' ),
		'CS' => __( '克乌谢尼', 'woocommerce' ),
		'CM' => __( '奇米什利亚', 'woocommerce' ),
		'CR' => __( 'Criuleni', 'woocommerce' ),
		'DN' => __( '栋杜谢尼区', 'woocommerce' ),
		'DR' => __( 'Drochia', 'woocommerce' ),
		'DB' => __( '杜伯萨里', 'woocommerce' ),
		'ED' => __( '埃迪内茨', 'woocommerce' ),
		'FL' => __( '弗莱什蒂', 'woocommerce' ),
		'FR' => __( '弗洛雷什蒂', 'woocommerce' ),
		'GE' => __( '加告兹自治区', 'woocommerce' ),
		'GL' => __( 'Glodeni', 'woocommerce' ),
		'HN' => __( '亨切什蒂', 'woocommerce' ),
		'IL' => __( '亚洛韦尼', 'woocommerce' ),
		'LV' => __( '莱奥瓦', 'woocommerce' ),
		'NS' => __( '尼斯波雷尼', 'woocommerce' ),
		'OC' => __( '奥克尼察', 'woocommerce' ),
		'OR' => __( '奥尔黑', 'woocommerce' ),
		'RZ' => __( 'Rezina', 'woocommerce' ),
		'RS' => __( '雷什卡内', 'woocommerce' ),
		'SG' => __( '森杰雷', 'woocommerce' ),
		'SR' => __( '索罗卡', 'woocommerce' ),
		'ST' => __( '斯特勒谢尼', 'woocommerce' ),
		'SD' => __( '绍尔德内什蒂', 'woocommerce' ),
		'SV' => __( '斯特凡大公区', 'woocommerce' ),
		'TR' => __( '塔拉克利亚', 'woocommerce' ),
		'TL' => __( '泰莱内什蒂', 'woocommerce' ),
		'UN' => __( 'Ungheni', 'woocommerce' ),
	),
	'MQ' => array(),
	'MT' => array(),
	'MX' => array( // Mexican states.
		'DF' => __( '墨西哥城', 'woocommerce' ),
		'JA' => __( '哈利斯科', 'woocommerce' ),
		'NL' => __( '新莱昂', 'woocommerce' ),
		'AG' => __( 'Aguascalientes', 'woocommerce' ),
		'BC' => __( 'Baja California', 'woocommerce' ),
		'BS' => __( 'Baja California Sur', 'woocommerce' ),
		'CM' => __( 'Campeche', 'woocommerce' ),
		'CS' => __( 'Chiapas', 'woocommerce' ),
		'CH' => __( 'Chihuahua', 'woocommerce' ),
		'CO' => __( 'Coahuila', 'woocommerce' ),
		'CL' => __( 'Colima', 'woocommerce' ),
		'DG' => __( 'Durango', 'woocommerce' ),
		'GT' => __( 'Guanajuato', 'woocommerce' ),
		'GR' => __( 'Guerrero', 'woocommerce' ),
		'HG' => __( 'Hidalgo', 'woocommerce' ),
		'MX' => __( '墨西哥州', 'woocommerce' ),
		'MI' => __( 'Michoacán', 'woocommerce' ),
		'MO' => __( '莫雷洛斯', 'woocommerce' ),
		'NA' => __( '纳亚里特', 'woocommerce' ),
		'OA' => __( '瓦哈卡', 'woocommerce' ),
		'PU' => __( 'Puebla', 'woocommerce' ),
		'QT' => __( 'Puebla', 'woocommerce' ),
		'QR' => __( 'Quintana Roo', 'woocommerce' ),
		'SL' => __( 'San Luis Potosí', 'woocommerce' ),
		'SI' => __( 'Sinaloa', 'woocommerce' ),
		'SO' => __( 'Sonora', 'woocommerce' ),
		'TB' => __( 'Tabasco', 'woocommerce' ),
		'TM' => __( 'Tamaulipas', 'woocommerce' ),
		'TL' => __( 'Tlaxcala', 'woocommerce' ),
		'VE' => __( 'Veracruz', 'woocommerce' ),
		'YU' => __( 'Yucatán', 'woocommerce' ),
		'ZA' => __( 'Zacatecas', 'woocommerce' ),
	),
	'MY' => array( // Malaysian states.
		'JHR' => __( 'Johor', 'woocommerce' ),
		'KDH' => __( 'Kedah', 'woocommerce' ),
		'KTN' => __( 'Kelantan', 'woocommerce' ),
		'LBN' => __( '纳闽', 'woocommerce' ),
		'MLK' => __( '马六甲', 'woocommerce' ),
		'NSN' => __( 'Negeri Sembilan', 'woocommerce' ),
		'PHG' => __( 'Pahang', 'woocommerce' ),
		'PNG' => __( '槟城', 'woocommerce' ),
		'PRK' => __( 'Perak', 'woocommerce' ),
		'PLS' => __( 'Perlis', 'woocommerce' ),
		'SBH' => __( 'Sabah', 'woocommerce' ),
		'SWK' => __( 'Sarawak', 'woocommerce' ),
		'SGR' => __( 'Selangor', 'woocommerce' ),
		'TRG' => __( 'Terengganu', 'woocommerce' ),
		'PJY' => __( '布城', 'woocommerce' ),
		'KUL' => __( '吉隆坡', 'woocommerce' ),
	),
	'MZ' => array( // Mozambican provinces.
		'MZP'   => __( '德尔加杜角省', 'woocommerce' ),
		'MZG'   => __( '加沙', 'woocommerce' ),
		'MZI'   => __( '伊尼扬巴内', 'woocommerce' ),
		'MZB'   => __( '马尼卡', 'woocommerce' ),
		'MZL'   => __( '马普托省', 'woocommerce' ),
		'MZMPM' => __( '马普托', 'woocommerce' ),
		'MZN'   => __( '楠普拉', 'woocommerce' ),
		'MZA'   => __( '尼亚萨', 'woocommerce' ),
		'MZS'   => __( '索法拉省', 'woocommerce' ),
		'MZT'   => __( '太特省', 'woocommerce' ),
		'MZQ'   => __( '赞比西亚', 'woocommerce' ),
	),
	'NA' => array( // Namibian regions.
		'ER' => __( 'Erongo', 'woocommerce' ),
		'HA' => __( '哈达普', 'woocommerce' ),
		'KA' => __( '卡拉斯', 'woocommerce' ),
		'KE' => __( '东卡万戈', 'woocommerce' ),
		'KW' => __( '西卡万戈', 'woocommerce' ),
		'KH' => __( '克胡姆斯', 'woocommerce' ),
		'KU' => __( '库内内', 'woocommerce' ),
		'OW' => __( '奥汉圭纳', 'woocommerce' ),
		'OH' => __( '奥马赫科', 'woocommerce' ),
		'OS' => __( '奥姆沙蒂', 'woocommerce' ),
		'ON' => __( '奥沙纳', 'woocommerce' ),
		'OT' => __( '奥希科托', 'woocommerce' ),
		'OD' => __( '蒂约巴', 'woocommerce' ),
		'CA' => __( '赞比西', 'woocommerce' ),
	),
	'NG' => array( // Nigerian provinces.
		'AB' => __( '阿比亚', 'woocommerce' ),
		'FC' => __( '阿布贾', 'woocommerce' ),
		'AD' => __( '阿达马瓦', 'woocommerce' ),
		'AK' => __( '阿夸伊博姆', 'woocommerce' ),
		'AN' => __( '阿南布拉州', 'woocommerce' ),
		'BA' => __( '博契', 'woocommerce' ),
		'BY' => __( '巴耶尔萨', 'woocommerce' ),
		'BE' => __( '贝努埃', 'woocommerce' ),
		'BO' => __( '博尔诺', 'woocommerce' ),
		'CR' => __( '克罗斯河', 'woocommerce' ),
		'DE' => __( '增量', 'woocommerce' ),
		'EB' => __( '埃邦伊', 'woocommerce' ),
		'ED' => __( '江户', 'woocommerce' ),
		'EK' => __( '埃基蒂', 'woocommerce' ),
		'EN' => __( '埃努古', 'woocommerce' ),
		'GO' => __( '贡贝', 'woocommerce' ),
		'IM' => __( 'IMO', 'woocommerce' ),
		'JI' => __( '吉加瓦', 'woocommerce' ),
		'KD' => __( '卡杜纳', 'woocommerce' ),
		'KN' => __( '卡诺', 'woocommerce' ),
		'KT' => __( '卡齐纳', 'woocommerce' ),
		'KE' => __( '凯比', 'woocommerce' ),
		'KO' => __( '科吉', 'woocommerce' ),
		'KW' => __( '夸拉学院', 'woocommerce' ),
		'LA' => __( '拉各斯', 'woocommerce' ),
		'NA' => __( '纳萨拉瓦', 'woocommerce' ),
		'NI' => __( '尼日尔', 'woocommerce' ),
		'OG' => __( '奥贡', 'woocommerce' ),
		'ON' => __( '翁多', 'woocommerce' ),
		'OS' => __( '奥孙', 'woocommerce' ),
		'OY' => __( '奥约', 'woocommerce' ),
		'PL' => __( '高原', 'woocommerce' ),
		'RI' => __( '河流', 'woocommerce' ),
		'SO' => __( '索科托', 'woocommerce' ),
		'TA' => __( '塔拉巴', 'woocommerce' ),
		'YO' => __( '约贝', 'woocommerce' ),
		'ZA' => __( '赞法拉', 'woocommerce' ),
	),
	'NL' => array(),
	'NO' => array(),
	'NP' => array( // Nepalese zones.
		'BAG' => __( '巴格马提', 'woocommerce' ),
		'BHE' => __( '佩里', 'woocommerce' ),
		'DHA' => __( '道拉吉里', 'woocommerce' ),
		'GAN' => __( '甘达基', 'woocommerce' ),
		'JAN' => __( '贾纳克布尔', 'woocommerce' ),
		'KAR' => __( '格尔纳利', 'woocommerce' ),
		'KOS' => __( '戈西', 'woocommerce' ),
		'LUM' => __( '蓝毗尼', 'woocommerce' ),
		'MAH' => __( '摩诃迦利', 'woocommerce' ),
		'MEC' => __( '美琪', 'woocommerce' ),
		'NAR' => __( '纳拉亚尼', 'woocommerce' ),
		'RAP' => __( '拉普蒂', 'woocommerce' ),
		'SAG' => __( '萨加玛塔', 'woocommerce' ),
		'SET' => __( '瑟地', 'woocommerce' ),
	),
	'NI' => array( // Nicaraguan states.
		'NI-AN' => __( 'Atlántico Norte', 'woocommerce' ),
		'NI-AS' => __( 'Atlántico Sur', 'woocommerce' ),
		'NI-BO' => __( 'Boaco', 'woocommerce' ),
		'NI-CA' => __( 'Carazo', 'woocommerce' ),
		'NI-CI' => __( 'Chinandega', 'woocommerce' ),
		'NI-CO' => __( 'Chontales', 'woocommerce' ),
		'NI-ES' => __( 'Estelí', 'woocommerce' ),
		'NI-GR' => __( 'Granada', 'woocommerce' ),
		'NI-JI' => __( 'Jinotega', 'woocommerce' ),
		'NI-LE' => __( '利昂', 'woocommerce' ),
		'NI-MD' => __( 'Madriz', 'woocommerce' ),
		'NI-MN' => __( 'Managua', 'woocommerce' ),
		'NI-MS' => __( 'Masaya', 'woocommerce' ),
		'NI-MT' => __( 'Matagalpa', 'woocommerce' ),
		'NI-NS' => __( 'Nueva Segovia', 'woocommerce' ),
		'NI-RI' => __( 'Rivas', 'woocommerce' ),
		'NI-SJ' => __( 'Río San Juan', 'woocommerce' ),
	),
	'NZ' => array( // New Zealand states.
		'NL' => __( 'Northland', 'woocommerce' ),
		'AK' => __( 'Auckland', 'woocommerce' ),
		'WA' => __( 'Waikato', 'woocommerce' ),
		'BP' => __( 'Bay of Plenty', 'woocommerce' ),
		'TK' => __( 'Taranaki', 'woocommerce' ),
		'GI' => __( '吉斯伯恩', 'woocommerce' ),
		'HB' => __( '霍克湾大区', 'woocommerce' ),
		'MW' => __( 'Manawatu-Wanganui', 'woocommerce' ),
		'WE' => __( 'Wellington', 'woocommerce' ),
		'NS' => __( 'Nelson', 'woocommerce' ),
		'MB' => __( 'Marlborough', 'woocommerce' ),
		'TM' => __( 'Tasman', 'woocommerce' ),
		'WC' => __( '象牙海岸', 'woocommerce' ),
		'CT' => __( 'Canterbury', 'woocommerce' ),
		'OT' => __( 'Otago', 'woocommerce' ),
		'SL' => __( 'Southland', 'woocommerce' ),
	),
	'PA' => array( // Panamanian states.
		'PA-1' => __( 'Bocas del Toro', 'woocommerce' ),
		'PA-2' => __( 'Coclé', 'woocommerce' ),
		'PA-3' => __( 'Colón', 'woocommerce' ),
		'PA-4' => __( 'Chiriquí', 'woocommerce' ),
		'PA-5' => __( 'Darién', 'woocommerce' ),
		'PA-6' => __( 'Herrera', 'woocommerce' ),
		'PA-7' => __( 'Los Santos', 'woocommerce' ),
		'PA-8' => __( 'Panamá', 'woocommerce' ),
		'PA-9' => __( 'Veraguas', 'woocommerce' ),
		'PA-10' => __( 'West Panamá', 'woocommerce' ),
		'PA-EM' => __( 'Emberá', 'woocommerce' ),
		'PA-KY' => __( 'Guna Yala', 'woocommerce' ),
		'PA-NB' => __( 'Ngöbe-Buglé', 'woocommerce' ),
	),
	'PE' => array( // Peruvian states.
		'CAL' => __( 'El Callao', 'woocommerce' ),
		'LMA' => __( '首都利马市', 'woocommerce' ),
		'AMA' => __( '亚马逊', 'woocommerce' ),
		'ANC' => __( 'Ancash', 'woocommerce' ),
		'APU' => __( '阿普里马克', 'woocommerce' ),
		'ARE' => __( 'Arequipa', 'woocommerce' ),
		'AYA' => __( 'Ayacucho', 'woocommerce' ),
		'CAJ' => __( 'Cajamarca', 'woocommerce' ),
		'CUS' => __( 'Cusco', 'woocommerce' ),
		'HUV' => __( 'Huancavelica', 'woocommerce' ),
		'HUC' => __( '瓦努科', 'woocommerce' ),
		'ICA' => __( 'Ica', 'woocommerce' ),
		'JUN' => __( '胡宁', 'woocommerce' ),
		'LAL' => __( 'La Libertad', 'woocommerce' ),
		'LAM' => __( 'Lambayeque', 'woocommerce' ),
		'LIM' => __( 'Lima', 'woocommerce' ),
		'LOR' => __( 'Loreto', 'woocommerce' ),
		'MDD' => __( 'Madre de Dios', 'woocommerce' ),
		'MOQ' => __( 'Moquegua', 'woocommerce' ),
		'PAS' => __( 'Pasco', 'woocommerce' ),
		'PIU' => __( 'Piura', 'woocommerce' ),
		'PUN' => __( 'Puno', 'woocommerce' ),
		'SAM' => __( '圣马丁', 'woocommerce' ),
		'TAC' => __( 'Tacna', 'woocommerce' ),
		'TUM' => __( 'Tumbes', 'woocommerce' ),
		'UCA' => __( 'Ucayali', 'woocommerce' ),
	),
	'PH' => array( // Philippine provinces.
		'ABR' => __( '阿布拉', 'woocommerce' ),
		'AGN' => __( '北阿古桑', 'woocommerce' ),
		'AGS' => __( '南阿古桑', 'woocommerce' ),
		'AKL' => __( '阿克兰', 'woocommerce' ),
		'ALB' => __( '阿尔拜省', 'woocommerce' ),
		'ANT' => __( '安蒂克', 'woocommerce' ),
		'APA' => __( '阿巴尧', 'woocommerce' ),
		'AUR' => __( '奥罗拉', 'woocommerce' ),
		'BAS' => __( '巴斯兰', 'woocommerce' ),
		'BAN' => __( '巴丹', 'woocommerce' ),
		'BTN' => __( '巴丹', 'woocommerce' ),
		'BTG' => __( '八打雁', 'woocommerce' ),
		'BEN' => __( '本格特', 'woocommerce' ),
		'BIL' => __( '比利兰', 'woocommerce' ),
		'BOH' => __( '保和', 'woocommerce' ),
		'BUK' => __( '布基农', 'woocommerce' ),
		'BUL' => __( '布拉参', 'woocommerce' ),
		'CAG' => __( '卡加延', 'woocommerce' ),
		'CAN' => __( '北甘马粦', 'woocommerce' ),
		'CAS' => __( '南甘马粦', 'woocommerce' ),
		'CAM' => __( '卡米金', 'woocommerce' ),
		'CAP' => __( '卡皮兹', 'woocommerce' ),
		'CAT' => __( '卡坦端内斯', 'woocommerce' ),
		'CAV' => __( '甲米地', 'woocommerce' ),
		'CEB' => __( '宿雾', 'woocommerce' ),
		'COM' => __( '康波斯特拉谷', 'woocommerce' ),
		'NCO' => __( '哥打巴托', 'woocommerce' ),
		'DAV' => __( '北达沃', 'woocommerce' ),
		'DAS' => __( '南达沃', 'woocommerce' ),
		'DAC' => __( '西达沃', 'woocommerce' ),
		'DAO' => __( '东达沃', 'woocommerce' ),
		'DIN' => __( '迪纳加特群岛', 'woocommerce' ),
		'EAS' => __( '东萨马', 'woocommerce' ),
		'GUI' => __( '吉马拉斯', 'woocommerce' ),
		'IFU' => __( '伊富高', 'woocommerce' ),
		'ILN' => __( '北伊罗戈', 'woocommerce' ),
		'ILS' => __( '南伊罗戈', 'woocommerce' ),
		'ILI' => __( '伊洛伊洛', 'woocommerce' ),
		'ISA' => __( '伊莎贝拉', 'woocommerce' ),
		'KAL' => __( '卡林阿', 'woocommerce' ),
		'LUN' => __( '拉允隆', 'woocommerce' ),
		'LAG' => __( '拉古那', 'woocommerce' ),
		'LAN' => __( '北拉瑙', 'woocommerce' ),
		'LAS' => __( '南拉瑙', 'woocommerce' ),
		'LEY' => __( '莱特岛', 'woocommerce' ),
		'MAG' => __( '马京达瑙', 'woocommerce' ),
		'MAD' => __( '马林杜克', 'woocommerce' ),
		'MAS' => __( '马斯巴特', 'woocommerce' ),
		'MSC' => __( '西米萨米斯', 'woocommerce' ),
		'MSR' => __( '东米萨米斯', 'woocommerce' ),
		'MOU' => __( '高山省', 'woocommerce' ),
		'NEC' => __( '西内格罗', 'woocommerce' ),
		'NER' => __( '东内格罗', 'woocommerce' ),
		'NSA' => __( '北萨', 'woocommerce' ),
		'NUE' => __( '新怡诗夏', 'woocommerce' ),
		'NUV' => __( '新比斯开', 'woocommerce' ),
		'MDC' => __( '西民都洛', 'woocommerce' ),
		'MDR' => __( '东民都洛', 'woocommerce' ),
		'PLW' => __( '巴拉望', 'woocommerce' ),
		'PAM' => __( '邦板牙', 'woocommerce' ),
		'PAN' => __( '邦阿西楠', 'woocommerce' ),
		'QUE' => __( '奎松', 'woocommerce' ),
		'QUI' => __( '季里诺', 'woocommerce' ),
		'RIZ' => __( '黎刹', 'woocommerce' ),
		'ROM' => __( '朗布隆', 'woocommerce' ),
		'WSA' => __( '萨马', 'woocommerce' ),
		'SAR' => __( '萨兰加尼', 'woocommerce' ),
		'SIQ' => __( '锡基霍尔', 'woocommerce' ),
		'SOR' => __( '索索贡', 'woocommerce' ),
		'SCO' => __( '南哥打巴托', 'woocommerce' ),
		'SLE' => __( '南莱特', 'woocommerce' ),
		'SUK' => __( '苏丹库达拉', 'woocommerce' ),
		'SLU' => __( '苏禄', 'woocommerce' ),
		'SUN' => __( '北苏里高', 'woocommerce' ),
		'SUR' => __( '南苏里高', 'woocommerce' ),
		'TAR' => __( '打拉', 'woocommerce' ),
		'TAW' => __( '塔威塔威', 'woocommerce' ),
		'ZMB' => __( '三描礼士', 'woocommerce' ),
		'ZAN' => __( '北三宝颜卡', 'woocommerce' ),
		'ZAS' => __( '南三宝颜卡', 'woocommerce' ),
		'ZSI' => __( '三宝颜锡布格', 'woocommerce' ),
		'00'  => __( '马尼拉大都会', 'woocommerce' ),
	),
	'PK' => array( // Pakistani states.
		'JK' => __( '阿扎德克什米尔', 'woocommerce' ),
		'BA' => __( '俾路支省', 'woocommerce' ),
		'TA' => __( 'FATA', 'woocommerce' ),
		'GB' => __( '吉尔吉特地区', 'woocommerce' ),
		'IS' => __( '伊斯兰堡首都区', 'woocommerce' ),
		'KP' => __( '普赫图赫瓦省', 'woocommerce' ),
		'PB' => __( 'Punjab', 'woocommerce' ),
		'SD' => __( '信德省', 'woocommerce' ),
	),
	'PL' => array(),
	'PR' => array(),
	'PT' => array(),
	'PY' => array( // Paraguayan states.
		'PY-ASU' => __( '亚松森', 'woocommerce' ),
		'PY-1'   => __( '康塞普西翁', 'woocommerce' ),
		'PY-2'   => __( '圣佩德罗', 'woocommerce' ),
		'PY-3'   => __( '科迪勒拉', 'woocommerce' ),
		'PY-4'   => __( '瓜伊拉省', 'woocommerce' ),
		'PY-5'   => __( '卡瓜苏省', 'woocommerce' ),
		'PY-6'   => __( '卡萨帕省', 'woocommerce' ),
		'PY-7'   => __( '伊塔普阿省', 'woocommerce' ),
		'PY-8'   => __( '米西奥内斯', 'woocommerce' ),
		'PY-9'   => __( '巴拉瓜里省', 'woocommerce' ),
		'PY-10'  => __( '上巴拉那省', 'woocommerce' ),
		'PY-11'  => __( '中央省', 'woocommerce' ),
		'PY-12'  => __( '涅恩布库省', 'woocommerce' ),
		'PY-13'  => __( '阿曼拜省', 'woocommerce' ),
		'PY-14'  => __( '卡宁德尤省', 'woocommerce' ),
		'PY-15'  => __( '阿耶斯总统省', 'woocommerce' ),
		'PY-16'  => __( '上巴拉圭省', 'woocommerce' ),
		'PY-17'  => __( '博克龙省', 'woocommerce' ),
	),
	'RE' => array(),
	'RO' => array( // Romanian states.
		'AB' => __( '阿尔巴', 'woocommerce' ),
		'AR' => __( '阿拉德', 'woocommerce' ),
		'AG' => __( '阿尔杰什县', 'woocommerce' ),
		'BC' => __( 'Bacău', 'woocommerce' ),
		'BH' => __( '比霍尔', 'woocommerce' ),
		'BN' => __( '比斯特里察-讷瑟乌德县', 'woocommerce' ),
		'BT' => __( 'Botoșani', 'woocommerce' ),
		'BR' => __( 'Brăila', 'woocommerce' ),
		'BV' => __( 'Brașov', 'woocommerce' ),
		'B'  => __( 'București', 'woocommerce' ),
		'BZ' => __( 'Buzău', 'woocommerce' ),
		'CL' => __( '克勒拉希', 'woocommerce' ),
		'CS' => __( '卡拉什-塞维林', 'woocommerce' ),
		'CJ' => __( '克卢日', 'woocommerce' ),
		'CT' => __( 'Constanța。', 'woocommerce' ),
		'CV' => __( '科瓦斯纳', 'woocommerce' ),
		'DB' => __( '登博维察河', 'woocommerce' ),
		'DJ' => __( '多尔日', 'woocommerce' ),
		'GL' => __( 'Galați', 'woocommerce' ),
		'GR' => __( '久尔久', 'woocommerce' ),
		'GJ' => __( '戈尔日', 'woocommerce' ),
		'HR' => __( '哈尔吉塔', 'woocommerce' ),
		'HD' => __( '胡内多阿拉', 'woocommerce' ),
		'IL' => __( '雅洛米察县', 'woocommerce' ),
		'IS' => __( '雅西', 'woocommerce' ),
		'IF' => __( '伊尔福夫', 'woocommerce' ),
		'MM' => __( '马拉穆列什县', 'woocommerce' ),
		'MH' => __( '梅赫丁茨县', 'woocommerce' ),
		'MS' => __( '穆列什县', 'woocommerce' ),
		'NT' => __( '尼亚姆茨县', 'woocommerce' ),
		'OT' => __( '奥尔特', 'woocommerce' ),
		'PH' => __( '普拉霍瓦', 'woocommerce' ),
		'SJ' => __( '瑟拉日县', 'woocommerce' ),
		'SM' => __( '萨图马雷', 'woocommerce' ),
		'SB' => __( '锡比乌', 'woocommerce' ),
		'SV' => __( '苏恰瓦', 'woocommerce' ),
		'TR' => __( '特列奥尔曼', 'woocommerce' ),
		'TM' => __( '蒂米什县', 'woocommerce' ),
		'TL' => __( '图尔恰', 'woocommerce' ),
		'VL' => __( '瓦尔恰', 'woocommerce' ),
		'VS' => __( '瓦斯卢伊', 'woocommerce' ),
		'VN' => __( '弗朗恰', 'woocommerce' ),
	),
	'SG' => array(),
	'SK' => array(),
	'SI' => array(),
	'SV' => array( // Salvadoran states.
		'SV-AH' => __( 'Ahuachapán', 'woocommerce' ),
		'SV-CA' => __( 'Cabañas', 'woocommerce' ),
		'SV-CH' => __( 'Chalatenango', 'woocommerce' ),
		'SV-CU' => __( 'Cuscatlán', 'woocommerce' ),
		'SV-LI' => __( 'La Libertad', 'woocommerce' ),
		'SV-MO' => __( 'Morazán', 'woocommerce' ),
		'SV-PA' => __( '拉巴斯', 'woocommerce' ),
		'SV-SA' => __( 'Santa Ana', 'woocommerce' ),
		'SV-SM' => __( 'San Miguel', 'woocommerce' ),
		'SV-SO' => __( 'Sonsonate', 'woocommerce' ),
		'SV-SS' => __( 'San Salvador', 'woocommerce' ),
		'SV-SV' => __( 'San Vicente', 'woocommerce' ),
		'SV-UN' => __( 'La Unión', 'woocommerce' ),
		'SV-US' => __( 'Usulután', 'woocommerce' ),
	),
	'TH' => array( // Thai states.
		'TH-37' => __( 'Amnat Charoen', 'woocommerce' ),
		'TH-15' => __( 'Ang Thong', 'woocommerce' ),
		'TH-14' => __( 'Ayutthaya', 'woocommerce' ),
		'TH-10' => __( 'Bangkok', 'woocommerce' ),
		'TH-38' => __( 'Bueng Kan', 'woocommerce' ),
		'TH-31' => __( 'Buri Ram', 'woocommerce' ),
		'TH-24' => __( 'Chachoengsao', 'woocommerce' ),
		'TH-18' => __( 'Chai Nat', 'woocommerce' ),
		'TH-36' => __( '柴亚普姆', 'woocommerce' ),
		'TH-22' => __( '尖竹汶府', 'woocommerce' ),
		'TH-50' => __( '清迈', 'woocommerce' ),
		'TH-57' => __( '清莱', 'woocommerce' ),
		'TH-20' => __( '春武里府', 'woocommerce' ),
		'TH-86' => __( '春蓬', 'woocommerce' ),
		'TH-46' => __( '卡拉辛', 'woocommerce' ),
		'TH-62' => __( 'Kamphaeng Phet', 'woocommerce' ),
		'TH-71' => __( 'Kanchanaburi', 'woocommerce' ),
		'TH-40' => __( 'Khon Kaen', 'woocommerce' ),
		'TH-81' => __( 'Krabi', 'woocommerce' ),
		'TH-52' => __( 'Lampang', 'woocommerce' ),
		'TH-51' => __( 'Lamphun', 'woocommerce' ),
		'TH-42' => __( 'Loei', 'woocommerce' ),
		'TH-16' => __( 'Lopburi', 'woocommerce' ),
		'TH-58' => __( 'Mae Hong Son', 'woocommerce' ),
		'TH-44' => __( 'Maha Sarakham', 'woocommerce' ),
		'TH-49' => __( 'Mukdahan', 'woocommerce' ),
		'TH-26' => __( 'Nakhon Nayok', 'woocommerce' ),
		'TH-73' => __( 'Nakhon Pathom', 'woocommerce' ),
		'TH-48' => __( 'Nakhon Phanom', 'woocommerce' ),
		'TH-30' => __( 'Nakhon Ratchasima', 'woocommerce' ),
		'TH-60' => __( 'Nakhon Sawan', 'woocommerce' ),
		'TH-80' => __( 'Nakhon Si Thammarat', 'woocommerce' ),
		'TH-55' => __( 'Nan', 'woocommerce' ),
		'TH-96' => __( 'Narathiwat', 'woocommerce' ),
		'TH-39' => __( 'Nong Bua Lam Phu', 'woocommerce' ),
		'TH-43' => __( 'Nong Khai', 'woocommerce' ),
		'TH-12' => __( 'Nonthaburi', 'woocommerce' ),
		'TH-13' => __( 'Pathum Thani', 'woocommerce' ),
		'TH-94' => __( 'Pattani', 'woocommerce' ),
		'TH-82' => __( 'Phang Nga', 'woocommerce' ),
		'TH-93' => __( 'Phatthalung', 'woocommerce' ),
		'TH-56' => __( 'Phayao', 'woocommerce' ),
		'TH-67' => __( 'Phetchabun', 'woocommerce' ),
		'TH-76' => __( 'Phetchaburi', 'woocommerce' ),
		'TH-66' => __( 'Phichit', 'woocommerce' ),
		'TH-65' => __( 'Phitsanulok', 'woocommerce' ),
		'TH-54' => __( 'Phrae', 'woocommerce' ),
		'TH-83' => __( 'Phuket', 'woocommerce' ),
		'TH-25' => __( 'Prachin Buri', 'woocommerce' ),
		'TH-77' => __( 'Prachuap Khiri Khan', 'woocommerce' ),
		'TH-85' => __( 'Ranong', 'woocommerce' ),
		'TH-70' => __( 'Ratchaburi', 'woocommerce' ),
		'TH-21' => __( 'Rayong', 'woocommerce' ),
		'TH-45' => __( 'Roi Et', 'woocommerce' ),
		'TH-27' => __( 'Sa Kaeo', 'woocommerce' ),
		'TH-47' => __( 'Sakon Nakhon', 'woocommerce' ),
		'TH-11' => __( 'Samut Prakan', 'woocommerce' ),
		'TH-74' => __( 'Samut Sakhon', 'woocommerce' ),
		'TH-75' => __( 'Samut Songkhram', 'woocommerce' ),
		'TH-19' => __( 'Saraburi', 'woocommerce' ),
		'TH-91' => __( 'Satun', 'woocommerce' ),
		'TH-17' => __( 'Sing Buri', 'woocommerce' ),
		'TH-33' => __( 'Sisaket', 'woocommerce' ),
		'TH-90' => __( 'Songkhla', 'woocommerce' ),
		'TH-64' => __( 'Sukhothai', 'woocommerce' ),
		'TH-72' => __( 'Suphan Buri', 'woocommerce' ),
		'TH-84' => __( '素叻他尼', 'woocommerce' ),
		'TH-32' => __( '素林', 'woocommerce' ),
		'TH-63' => __( 'Tak', 'woocommerce' ),
		'TH-92' => __( 'Trang', 'woocommerce' ),
		'TH-23' => __( '特拉', 'woocommerce' ),
		'TH-34' => __( '乌汶叻差他尼', 'woocommerce' ),
		'TH-41' => __( '乌隆他尼', 'woocommerce' ),
		'TH-61' => __( '乌泰他尼', 'woocommerce' ),
		'TH-53' => __( '乌塔拉迪特', 'woocommerce' ),
		'TH-95' => __( '亚拉', 'woocommerce' ),
		'TH-35' => __( '亚索通', 'woocommerce' ),
	),
	'TR' => array( // Turkish states.
		'TR01' => __( 'Adana', 'woocommerce' ),
		'TR02' => __( '阿德亚曼', 'woocommerce' ),
		'TR03' => __( 'Afyon', 'woocommerce' ),
		'TR04' => __( '阿勒', 'woocommerce' ),
		'TR05' => __( 'Amasya', 'woocommerce' ),
		'TR06' => __( 'Ankara', 'woocommerce' ),
		'TR07' => __( 'Antalya', 'woocommerce' ),
		'TR08' => __( 'Artvin', 'woocommerce' ),
		'TR09' => __( '艾登', 'woocommerce' ),
		'TR10' => __( '巴勒克西尔', 'woocommerce' ),
		'TR11' => __( 'Bilecik', 'woocommerce' ),
		'TR12' => __( '宾格尔', 'woocommerce' ),
		'TR13' => __( 'Bitlis', 'woocommerce' ),
		'TR14' => __( 'Bolu', 'woocommerce' ),
		'TR15' => __( 'Burdur', 'woocommerce' ),
		'TR16' => __( 'Bursa', 'woocommerce' ),
		'TR17' => __( '恰纳卡莱', 'woocommerce' ),
		'TR18' => __( '昌克勒', 'woocommerce' ),
		'TR19' => __( '乔鲁姆', 'woocommerce' ),
		'TR20' => __( 'Denizli', 'woocommerce' ),
		'TR21' => __( '迪亚巴克尔', 'woocommerce' ),
		'TR22' => __( 'Edirne', 'woocommerce' ),
		'TR23' => __( '埃拉泽', 'woocommerce' ),
		'TR24' => __( 'Erzincan', 'woocommerce' ),
		'TR25' => __( 'Erzurum', 'woocommerce' ),
		'TR26' => __( '埃斯基谢希尔', 'woocommerce' ),
		'TR27' => __( 'Gaziantep', 'woocommerce' ),
		'TR28' => __( 'Giresun', 'woocommerce' ),
		'TR29' => __( '居米什哈内', 'woocommerce' ),
		'TR30' => __( 'Hakkari', 'woocommerce' ),
		'TR31' => __( 'Hatay', 'woocommerce' ),
		'TR32' => __( 'Isparta', 'woocommerce' ),
		'TR33' => __( '伊塞尔', 'woocommerce' ),
		'TR34' => __( '伊斯坦布尔', 'woocommerce' ),
		'TR35' => __( '伊兹密尔', 'woocommerce' ),
		'TR36' => __( 'Kars', 'woocommerce' ),
		'TR37' => __( 'Kastamonu', 'woocommerce' ),
		'TR38' => __( 'Kayseri', 'woocommerce' ),
		'TR39' => __( '克尔克拉雷利', 'woocommerce' ),
		'TR40' => __( '克尔谢希尔', 'woocommerce' ),
		'TR41' => __( 'Kocaeli', 'woocommerce' ),
		'TR42' => __( 'Konya', 'woocommerce' ),
		'TR43' => __( '屈塔希亚', 'woocommerce' ),
		'TR44' => __( 'Malatya', 'woocommerce' ),
		'TR45' => __( 'Manisa', 'woocommerce' ),
		'TR46' => __( '卡赫拉曼马什拉', 'woocommerce' ),
		'TR47' => __( 'Mardin', 'woocommerce' ),
		'TR48' => __( '穆拉', 'woocommerce' ),
		'TR49' => __( '穆什', 'woocommerce' ),
		'TR50' => __( '内夫谢希尔', 'woocommerce' ),
		'TR51' => __( '尼代', 'woocommerce' ),
		'TR52' => __( '奥尔杜', 'woocommerce' ),
		'TR53' => __( '泽省', 'woocommerce' ),
		'TR54' => __( '萨卡里亚', 'woocommerce' ),
		'TR55' => __( '萨姆松', 'woocommerce' ),
		'TR56' => __( '锡尔特', 'woocommerce' ),
		'TR57' => __( '锡诺普', 'woocommerce' ),
		'TR58' => __( '锡瓦斯', 'woocommerce' ),
		'TR59' => __( '泰基尔达', 'woocommerce' ),
		'TR60' => __( '托卡特', 'woocommerce' ),
		'TR61' => __( '特拉布宗', 'woocommerce' ),
		'TR62' => __( '通杰利省', 'woocommerce' ),
		'TR63' => __( '尚勒乌尔法', 'woocommerce' ),
		'TR64' => __( '乌沙克', 'woocommerce' ),
		'TR65' => __( '凡城', 'woocommerce' ),
		'TR66' => __( '约兹加特', 'woocommerce' ),
		'TR67' => __( '宗古尔达克', 'woocommerce' ),
		'TR68' => __( '阿克萨拉伊', 'woocommerce' ),
		'TR69' => __( '巴伊布尔特', 'woocommerce' ),
		'TR70' => __( '卡拉曼', 'woocommerce' ),
		'TR71' => __( '克鲁兹卡雷', 'woocommerce' ),
		'TR72' => __( '巴特曼', 'woocommerce' ),
		'TR73' => __( '舍尔纳克', 'woocommerce' ),
		'TR74' => __( '巴尔滕', 'woocommerce' ),
		'TR75' => __( 'Ardahan', 'woocommerce' ),
		'TR76' => __( '厄德尔', 'woocommerce' ),
		'TR77' => __( '亚洛瓦', 'woocommerce' ),
		'TR78' => __( '卡拉比克', 'woocommerce' ),
		'TR79' => __( '基利斯', 'woocommerce' ),
		'TR80' => __( '奥斯曼尼耶', 'woocommerce' ),
		'TR81' => __( '迪兹杰', 'woocommerce' ),
	),
	'TZ' => array( // Tanzanian states.
		'TZ01' => __( '阿鲁沙', 'woocommerce' ),
		'TZ02' => __( '达累斯萨拉姆', 'woocommerce' ),
		'TZ03' => __( '多多马', 'woocommerce' ),
		'TZ04' => __( '伊林加', 'woocommerce' ),
		'TZ05' => __( '卡盖拉', 'woocommerce' ),
		'TZ06' => __( '奔巴北部', 'woocommerce' ),
		'TZ07' => __( '桑给巴尔北部', 'woocommerce' ),
		'TZ08' => __( '基戈马', 'woocommerce' ),
		'TZ09' => __( '乞力马扎罗', 'woocommerce' ),
		'TZ10' => __( '奔巴南部', 'woocommerce' ),
		'TZ11' => __( '桑给巴尔南部', 'woocommerce' ),
		'TZ12' => __( '林迪', 'woocommerce' ),
		'TZ13' => __( '马拉', 'woocommerce' ),
		'TZ14' => __( '姆贝亚', 'woocommerce' ),
		'TZ15' => __( '桑给巴尔西部', 'woocommerce' ),
		'TZ16' => __( 'Morogoro / 莫洛戈罗', 'woocommerce' ),
		'TZ17' => __( 'Mtwara / 姆特瓦拉', 'woocommerce' ),
		'TZ18' => __( 'Mwanza / 姆万扎', 'woocommerce' ),
		'TZ19' => __( 'Coast', 'woocommerce' ),
		'TZ20' => __( 'Rukwa / 鲁夸区', 'woocommerce' ),
		'TZ21' => __( 'Ruvuma / 鲁伍马', 'woocommerce' ),
		'TZ22' => __( 'Shinyanga / 希尼安加', 'woocommerce' ),
		'TZ23' => __( 'Singida / 辛吉达', 'woocommerce' ),
		'TZ24' => __( 'Tabora / 塔波拉', 'woocommerce' ),
		'TZ25' => __( 'Tanga', 'woocommerce' ),
		'TZ26' => __( 'Manyara / 曼亚拉区', 'woocommerce' ),
		'TZ27' => __( '盖塔', 'woocommerce' ),
		'TZ28' => __( '卡塔维', 'woocommerce' ),
		'TZ29' => __( 'Njombe / 恩琼贝区', 'woocommerce' ),
		'TZ30' => __( 'Simiyu/锡米尤区', 'woocommerce' ),
	),
	'LK' => array(),
	'RS' => array( // Serbian districts.
		'RS00' => _x( '贝尔格莱德', 'district', 'woocommerce' ),
		'RS14' => _x( '博尔', 'district', 'woocommerce' ),
		'RS11' => _x( 'Braničevo', 'district', 'woocommerce' ),
		'RS02' => _x( '中巴纳特', 'district', 'woocommerce' ),
		'RS10' => _x( '多瑙河', 'district', 'woocommerce' ),
		'RS23' => _x( 'Jablanica', 'district', 'woocommerce' ),
		'RS09' => _x( 'Kolubara', 'district', 'woocommerce' ),
		'RS08' => _x( 'Mačva', 'district', 'woocommerce' ),
		'RS17' => _x( '莫拉瓦', 'district', 'woocommerce' ),
		'RS20' => _x( '尼沙瓦', 'district', 'woocommerce' ),
		'RS01' => _x( '北巴奇卡', 'district', 'woocommerce' ),
		'RS03' => _x( '北巴纳特', 'district', 'woocommerce' ),
		'RS24' => _x( 'Pčinja', 'district', 'woocommerce' ),
		'RS22' => _x( '皮罗特', 'district', 'woocommerce' ),
		'RS13' => _x( 'Pomoravlje', 'district', 'woocommerce' ),
		'RS19' => _x( 'Rasina', 'district', 'woocommerce' ),
		'RS18' => _x( '拉什卡', 'district', 'woocommerce' ),
		'RS06' => _x( '南巴卡', 'district', 'woocommerce' ),
		'RS04' => _x( '南巴纳特', 'district', 'woocommerce' ),
		'RS07' => _x( 'Srem', 'district', 'woocommerce' ),
		'RS12' => _x( 'Šumadija', 'district', 'woocommerce' ),
		'RS21' => _x( 'Toplica', 'district', 'woocommerce' ),
		'RS05' => _x( '西巴奇卡', 'district', 'woocommerce' ),
		'RS15' => _x( 'Zaječar', 'district', 'woocommerce' ),
		'RS16' => _x( 'Zlatibor', 'district', 'woocommerce' ),
		'RS25' => _x( '科索沃', 'district', 'woocommerce' ),
		'RS26' => _x( '佩奇', 'district', 'woocommerce' ),
		'RS27' => _x( '普里兹伦', 'district', 'woocommerce' ),
		'RS28' => _x( '科索夫斯卡-米特罗维察', 'district', 'woocommerce' ),
		'RS29' => _x( '科索沃-波莫拉夫列', 'district', 'woocommerce' ),
		'RSKM' => _x( '科索沃-梅托希亚', 'district', 'woocommerce' ),
		'RSVO' => _x( '伏伊伏丁那', 'district', 'woocommerce' ),
	),
	'SE' => array(),
	'UA' => array( // Ukrainian oblasts.
		'VN' => __( 'Vinnytsia Oblast', 'woocommerce' ),
		'VL' => __( 'Volyn Oblast', 'woocommerce' ),
		'DP' => __( 'Dnipropetrovsk Oblast', 'woocommerce' ),
		'DT' => __( 'Donetsk Oblast', 'woocommerce' ),
		'ZT' => __( 'Zhytomyr Oblast', 'woocommerce' ),
		'ZK' => __( 'Zakarpattia Oblast', 'woocommerce' ),
		'ZP' => __( 'Zaporizhzhia Oblast', 'woocommerce' ),
		'IF' => __( 'Ivano-Frankivsk Oblast', 'woocommerce' ),
		'KV' => __( 'Kyiv Oblast', 'woocommerce' ),
		'KH' => __( 'Kirovohrad Oblast', 'woocommerce' ),
		'LH' => __( 'Luhansk Oblast', 'woocommerce' ),
		'LV' => __( 'Lviv Oblast', 'woocommerce' ),
		'MY' => __( 'Mykolaiv Oblast', 'woocommerce' ),
		'OD' => __( 'Odessa Oblast', 'woocommerce' ),
		'PL' => __( 'Poltava Oblast', 'woocommerce' ),
		'RV' => __( 'Rivne Oblast', 'woocommerce' ),
		'SM' => __( 'Sumy Oblast', 'woocommerce' ),
		'TP' => __( 'Ternopil Oblast', 'woocommerce' ),
		'KK' => __( 'Kharkiv Oblast', 'woocommerce' ),
		'KS' => __( 'Kherson Oblast', 'woocommerce' ),
		'KM' => __( 'Khmelnytskyi Oblast', 'woocommerce' ),
		'CK' => __( 'Cherkasy Oblast', 'woocommerce' ),
		'CH' => __( 'Chernihiv Oblast', 'woocommerce' ),
		'CV' => __( 'Chernivtsi Oblast', 'woocommerce' ),
	),
	'UG' => array( // Ugandan districts.
		'UG314' => __( 'Abim', 'woocommerce' ),
		'UG301' => __( 'Adjumani', 'woocommerce' ),
		'UG322' => __( 'Agago', 'woocommerce' ),
		'UG323' => __( 'Alebtong', 'woocommerce' ),
		'UG315' => __( 'Amolatar', 'woocommerce' ),
		'UG324' => __( 'Amudat', 'woocommerce' ),
		'UG216' => __( 'Amuria', 'woocommerce' ),
		'UG316' => __( 'Amuru', 'woocommerce' ),
		'UG302' => __( 'Apac', 'woocommerce' ),
		'UG303' => __( 'Arua', 'woocommerce' ),
		'UG217' => __( 'Budaka', 'woocommerce' ),
		'UG218' => __( 'Bududa', 'woocommerce' ),
		'UG201' => __( 'Bugiri', 'woocommerce' ),
		'UG235' => __( 'Bugweri', 'woocommerce' ),
		'UG420' => __( 'Buhweju', 'woocommerce' ),
		'UG117' => __( 'Buikwe', 'woocommerce' ),
		'UG219' => __( 'Bukedea', 'woocommerce' ),
		'UG118' => __( 'Bukomansimbi', 'woocommerce' ),
		'UG220' => __( 'Bukwa', 'woocommerce' ),
		'UG225' => __( 'Bulambuli', 'woocommerce' ),
		'UG416' => __( 'Buliisa', 'woocommerce' ),
		'UG401' => __( 'Bundibugyo', 'woocommerce' ),
		'UG430' => __( 'Bunyangabu', 'woocommerce' ),
		'UG402' => __( 'Bushenyi', 'woocommerce' ),
		'UG202' => __( 'Busia', 'woocommerce' ),
		'UG221' => __( 'Butaleja', 'woocommerce' ),
		'UG119' => __( 'Butambala', 'woocommerce' ),
		'UG233' => __( 'Butebo', 'woocommerce' ),
		'UG120' => __( 'Buvuma', 'woocommerce' ),
		'UG226' => __( 'Buyende', 'woocommerce' ),
		'UG317' => __( 'Dokolo', 'woocommerce' ),
		'UG121' => __( 'Gomba', 'woocommerce' ),
		'UG304' => __( 'Gulu', 'woocommerce' ),
		'UG403' => __( 'Hoima', 'woocommerce' ),
		'UG417' => __( 'Ibanda', 'woocommerce' ),
		'UG203' => __( 'Iganga', 'woocommerce' ),
		'UG418' => __( 'Isingiro', 'woocommerce' ),
		'UG204' => __( 'Jinja', 'woocommerce' ),
		'UG318' => __( 'Kaabong', 'woocommerce' ),
		'UG404' => __( 'Kabale', 'woocommerce' ),
		'UG405' => __( 'Kabarole', 'woocommerce' ),
		'UG213' => __( 'Kaberamaido', 'woocommerce' ),
		'UG427' => __( 'Kagadi', 'woocommerce' ),
		'UG428' => __( 'Kakumiro', 'woocommerce' ),
		'UG101' => __( 'Kalangala', 'woocommerce' ),
		'UG222' => __( 'Kaliro', 'woocommerce' ),
		'UG122' => __( 'Kalungu', 'woocommerce' ),
		'UG102' => __( 'Kampala', 'woocommerce' ),
		'UG205' => __( 'Kamuli', 'woocommerce' ),
		'UG413' => __( 'Kamwenge', 'woocommerce' ),
		'UG414' => __( 'Kanungu', 'woocommerce' ),
		'UG206' => __( 'Kapchorwa', 'woocommerce' ),
		'UG236' => __( 'Kapelebyong', 'woocommerce' ),
		'UG126' => __( 'Kasanda', 'woocommerce' ),
		'UG406' => __( 'Kasese', 'woocommerce' ),
		'UG207' => __( 'Katakwi', 'woocommerce' ),
		'UG112' => __( 'Kayunga', 'woocommerce' ),
		'UG407' => __( 'Kibaale', 'woocommerce' ),
		'UG103' => __( 'Kiboga', 'woocommerce' ),
		'UG227' => __( 'Kibuku', 'woocommerce' ),
		'UG432' => __( 'Kikuube', 'woocommerce' ),
		'UG419' => __( 'Kiruhura', 'woocommerce' ),
		'UG421' => __( 'Kiryandongo', 'woocommerce' ),
		'UG408' => __( 'Kisoro', 'woocommerce' ),
		'UG305' => __( 'Kitgum', 'woocommerce' ),
		'UG319' => __( 'Koboko', 'woocommerce' ),
		'UG325' => __( 'Kole', 'woocommerce' ),
		'UG306' => __( 'Kotido', 'woocommerce' ),
		'UG208' => __( 'Kumi', 'woocommerce' ),
		'UG333' => __( 'Kwania', 'woocommerce' ),
		'UG228' => __( 'Kween', 'woocommerce' ),
		'UG123' => __( 'Kyankwanzi', 'woocommerce' ),
		'UG422' => __( 'Kyegegwa', 'woocommerce' ),
		'UG415' => __( 'Kyenjojo', 'woocommerce' ),
		'UG125' => __( 'Kyotera', 'woocommerce' ),
		'UG326' => __( 'Lamwo', 'woocommerce' ),
		'UG307' => __( 'Lira', 'woocommerce' ),
		'UG229' => __( 'Luuka', 'woocommerce' ),
		'UG104' => __( 'Luwero', 'woocommerce' ),
		'UG124' => __( 'Lwengo', 'woocommerce' ),
		'UG114' => __( 'Lyantonde', 'woocommerce' ),
		'UG223' => __( 'Manafwa', 'woocommerce' ),
		'UG320' => __( 'Maracha', 'woocommerce' ),
		'UG105' => __( 'Masaka', 'woocommerce' ),
		'UG409' => __( 'Masindi', 'woocommerce' ),
		'UG214' => __( 'Mayuge', 'woocommerce' ),
		'UG209' => __( 'Mbale', 'woocommerce' ),
		'UG410' => __( 'Mbarara', 'woocommerce' ),
		'UG423' => __( 'Mitooma', 'woocommerce' ),
		'UG115' => __( 'Mityana', 'woocommerce' ),
		'UG308' => __( 'Moroto', 'woocommerce' ),
		'UG309' => __( 'Moyo', 'woocommerce' ),
		'UG106' => __( 'Mpigi', 'woocommerce' ),
		'UG107' => __( 'Mubende', 'woocommerce' ),
		'UG108' => __( 'Mukono', 'woocommerce' ),
		'UG334' => __( 'Nabilatuk', 'woocommerce' ),
		'UG311' => __( 'Nakapiripirit', 'woocommerce' ),
		'UG116' => __( 'Nakaseke', 'woocommerce' ),
		'UG109' => __( 'Nakasongola', 'woocommerce' ),
		'UG230' => __( 'Namayingo', 'woocommerce' ),
		'UG234' => __( 'Namisindwa', 'woocommerce' ),
		'UG224' => __( 'Namutumba', 'woocommerce' ),
		'UG327' => __( 'Napak', 'woocommerce' ),
		'UG310' => __( 'Nebbi', 'woocommerce' ),
		'UG231' => __( 'Ngora', 'woocommerce' ),
		'UG424' => __( 'Ntoroko', 'woocommerce' ),
		'UG411' => __( 'Ntungamo', 'woocommerce' ),
		'UG328' => __( 'Nwoya', 'woocommerce' ),
		'UG331' => __( 'Omoro', 'woocommerce' ),
		'UG329' => __( 'Otuke', 'woocommerce' ),
		'UG321' => __( 'Oyam', 'woocommerce' ),
		'UG312' => __( 'Pader', 'woocommerce' ),
		'UG332' => __( 'Pakwach', 'woocommerce' ),
		'UG210' => __( 'Pallisa', 'woocommerce' ),
		'UG110' => __( 'Rakai', 'woocommerce' ),
		'UG429' => __( 'Rubanda', 'woocommerce' ),
		'UG425' => __( 'Rubirizi', 'woocommerce' ),
		'UG431' => __( 'Rukiga', 'woocommerce' ),
		'UG412' => __( 'Rukungiri', 'woocommerce' ),
		'UG111' => __( 'Sembabule', 'woocommerce' ),
		'UG232' => __( 'Serere', 'woocommerce' ),
		'UG426' => __( 'Sheema', 'woocommerce' ),
		'UG215' => __( 'Sironko', 'woocommerce' ),
		'UG211' => __( 'Soroti', 'woocommerce' ),
		'UG212' => __( 'Tororo', 'woocommerce' ),
		'UG113' => __( 'Wakiso', 'woocommerce' ),
		'UG313' => __( 'Yumbe', 'woocommerce' ),
		'UG330' => __( 'Zombo', 'woocommerce' ),
	),
	'UM' => array(
		'81' => __( '贝克岛', 'woocommerce' ),
		'84' => __( '豪兰岛', 'woocommerce' ),
		'86' => __( '贾维斯岛', 'woocommerce' ),
		'67' => __( '约翰斯顿环礁', 'woocommerce' ),
		'89' => __( '金曼礁', 'woocommerce' ),
		'71' => __( '中途岛', 'woocommerce' ),
		'76' => __( '纳瓦萨岛', 'woocommerce' ),
		'95' => __( '巴尔米拉环礁', 'woocommerce' ),
		'79' => __( '威克岛', 'woocommerce' ),
	),
	'US' => array( // U.S. states.
		'AL' => __( '阿拉巴马州', 'woocommerce' ),
		'AK' => __( '阿拉斯加州', 'woocommerce' ),
		'AZ' => __( '亚利桑那', 'woocommerce' ),
		'AR' => __( '阿肯色州', 'woocommerce' ),
		'CA' => __( '加州', 'woocommerce' ),
		'CO' => __( '科罗拉多州', 'woocommerce' ),
		'CT' => __( '康涅狄格', 'woocommerce' ),
		'DE' => __( '特拉华州', 'woocommerce' ),
		'DC' => __( '哥伦比亚特区', 'woocommerce' ),
		'FL' => __( '佛罗里达', 'woocommerce' ),
		'GA' => _x( '格鲁吉亚', 'US state of Georgia', 'woocommerce' ),
		'HI' => __( '夏威夷', 'woocommerce' ),
		'ID' => __( '爱达荷州', 'woocommerce' ),
		'IL' => __( '伊利诺伊州', 'woocommerce' ),
		'IN' => __( '印地安那', 'woocommerce' ),
		'IA' => __( '爱荷华州', 'woocommerce' ),
		'KS' => __( '堪萨斯', 'woocommerce' ),
		'KY' => __( '肯塔基州', 'woocommerce' ),
		'LA' => __( '路易斯安那州', 'woocommerce' ),
		'ME' => __( '缅因州', 'woocommerce' ),
		'MD' => __( '马里兰', 'woocommerce' ),
		'MA' => __( '美国马萨诸塞州', 'woocommerce' ),
		'MI' => __( '密歇根', 'woocommerce' ),
		'MN' => __( '明尼苏达州', 'woocommerce' ),
		'MS' => __( '密西西比河', 'woocommerce' ),
		'MO' => __( '密苏里州', 'woocommerce' ),
		'MT' => __( '蒙大拿', 'woocommerce' ),
		'NE' => __( '内布拉斯加州', 'woocommerce' ),
		'NV' => __( '内华达州', 'woocommerce' ),
		'NH' => __( '新罕布什尔州', 'woocommerce' ),
		'NJ' => __( '新泽西', 'woocommerce' ),
		'NM' => __( '新墨西哥', 'woocommerce' ),
		'NY' => __( '纽约', 'woocommerce' ),
		'NC' => __( '北卡罗莱纳州', 'woocommerce' ),
		'ND' => __( '北达科他州', 'woocommerce' ),
		'OH' => __( '俄亥俄州', 'woocommerce' ),
		'OK' => __( '俄克拉何马', 'woocommerce' ),
		'OR' => __( '俄勒冈州', 'woocommerce' ),
		'PA' => __( '宾夕法尼亚州', 'woocommerce' ),
		'RI' => __( '罗德岛', 'woocommerce' ),
		'SC' => __( '南卡罗来纳州', 'woocommerce' ),
		'SD' => __( '南达科他州', 'woocommerce' ),
		'TN' => __( '田纳西州', 'woocommerce' ),
		'TX' => __( '得克萨斯州', 'woocommerce' ),
		'UT' => __( '犹他州', 'woocommerce' ),
		'VT' => __( '佛蒙特', 'woocommerce' ),
		'VA' => __( '弗吉尼亚州', 'woocommerce' ),
		'WA' => __( '华盛顿', 'woocommerce' ),
		'WV' => __( '西弗吉尼亚州', 'woocommerce' ),
		'WI' => __( '威斯康星州', 'woocommerce' ),
		'WY' => __( '怀俄明州', 'woocommerce' ),
		'AA' => __( '美国武装部队', 'woocommerce' ),
		'AE' => __( '美国武装部队', 'woocommerce' ),
		'AP' => __( '美国武装部队', 'woocommerce' ),
	),
	'UY' => array( // Uruguayan states.
		'UY-AR' => __( 'Artigas', 'woocommerce' ),
		'UY-CA' => __( 'Canelones', 'woocommerce' ),
		'UY-CL' => __( 'Cerro Largo', 'woocommerce' ),
		'UY-CO' => __( 'Colonia', 'woocommerce' ),
		'UY-DU' => __( 'Durazno', 'woocommerce' ),
		'UY-FS' => __( 'Flores', 'woocommerce' ),
		'UY-FD' => __( '佛罗里达', 'woocommerce' ),
		'UY-LA' => __( 'Lavalleja', 'woocommerce' ),
		'UY-MA' => __( 'Maldonado', 'woocommerce' ),
		'UY-MO' => __( 'Montevideo', 'woocommerce' ),
		'UY-PA' => __( 'Paysandú', 'woocommerce' ),
		'UY-RN' => __( '内格罗河省', 'woocommerce' ),
		'UY-RV' => __( 'Rivera', 'woocommerce' ),
		'UY-RO' => __( 'Rocha', 'woocommerce' ),
		'UY-SA' => __( 'Salto', 'woocommerce' ),
		'UY-SJ' => __( 'San José', 'woocommerce' ),
		'UY-SO' => __( 'Soriano', 'woocommerce' ),
		'UY-TA' => __( 'Tacuarembó', 'woocommerce' ),
		'UY-TT' => __( 'Treinta y Tres', 'woocommerce' ),
	),
	'VE' => array( // Venezuelan states.
		'VE-A' => __( '首都', 'woocommerce' ),
		'VE-B' => __( '安索阿特吉', 'woocommerce' ),
		'VE-C' => __( '阿普雷河', 'woocommerce' ),
		'VE-D' => __( '阿拉瓜', 'woocommerce' ),
		'VE-E' => __( '巴里纳斯', 'woocommerce' ),
		'VE-F' => __( '玻利瓦尔', 'woocommerce' ),
		'VE-G' => __( '卡拉沃沃', 'woocommerce' ),
		'VE-H' => __( '科赫德斯', 'woocommerce' ),
		'VE-I' => __( '法尔孔', 'woocommerce' ),
		'VE-J' => __( '瓜里科', 'woocommerce' ),
		'VE-K' => __( '拉腊', 'woocommerce' ),
		'VE-L' => __( '梅里达', 'woocommerce' ),
		'VE-M' => __( '米兰达', 'woocommerce' ),
		'VE-N' => __( '莫纳加斯', 'woocommerce' ),
		'VE-O' => __( '新埃斯帕塔', 'woocommerce' ),
		'VE-P' => __( '波图格萨', 'woocommerce' ),
		'VE-R' => __( '苏克雷', 'woocommerce' ),
		'VE-S' => __( '塔奇拉', 'woocommerce' ),
		'VE-T' => __( '特鲁希略', 'woocommerce' ),
		'VE-U' => __( '亚拉奎', 'woocommerce' ),
		'VE-V' => __( '苏利亚', 'woocommerce' ),
		'VE-W' => __( '联邦属地', 'woocommerce' ),
		'VE-X' => __( 'La Guaira (Vargas)', 'woocommerce' ),
		'VE-Y' => __( '阿马库罗三角洲', 'woocommerce' ),
		'VE-Z' => __( '亚马逊', 'woocommerce' ),
	),
	'VN' => array(),
	'YT' => array(),
	'ZA' => array( // South African states.
		'EC'  => __( '佛得角', 'woocommerce' ),
		'FS'  => __( '地区/县', 'woocommerce' ),
		'GP'  => __( '豪登省', 'woocommerce' ),
		'KZN' => __( '夸祖鲁-纳塔尔省', 'woocommerce' ),
		'LP'  => __( '林波波省', 'woocommerce' ),
		'MP'  => __( '普马兰加', 'woocommerce' ),
		'NC'  => __( '佛得角', 'woocommerce' ),
		'NW'  => __( '西弗吉尼亚州', 'woocommerce' ),
		'WC'  => __( '佛得角', 'woocommerce' ),
	),
	'ZM' => array( // Zambian provinces.
		'ZM-01' => __( '西部', 'woocommerce' ),
		'ZM-02' => __( '中央省', 'woocommerce' ),
		'ZM-03' => __( '东部', 'woocommerce' ),
		'ZM-04' => __( '卢阿普拉省', 'woocommerce' ),
		'ZM-05' => __( '北部', 'woocommerce' ),
		'ZM-06' => __( '西北部', 'woocommerce' ),
		'ZM-07' => __( '南部', 'woocommerce' ),
		'ZM-08' => __( '铜带', 'woocommerce' ),
		'ZM-09' => __( '卢萨卡', 'woocommerce' ),
		'ZM-10' => __( '穆钦加', 'woocommerce' ),
	),
);
