<?php
/**
 * Load assets
 *
 * @package WooCommerce\Admin
 * @version 3.7.0
 */

use Automattic\Jetpack\Constants;

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WC_Admin_Assets', false ) ) :

	/**
	 * WC_Admin_Assets Class.
	 */
	class WC_Admin_Assets {

		/**
		 * Hook in tabs.
		 */
		public function __construct() {
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_styles' ) );
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_scripts' ) );
		}

		/**
		 * Enqueue styles.
		 */
		public function admin_styles() {
			global $gc_scripts;

			$version   = Constants::get_constant( 'WC_VERSION' );
			$screen    = get_current_screen();
			$screen_id = $screen ? $screen->id : '';

			// Register admin styles.
			gc_register_style( 'woocommerce_admin_menu_styles', WC()->plugin_url() . '/assets/css/menu.css', array(), $version );
			gc_register_style( 'woocommerce_admin_styles', WC()->plugin_url() . '/assets/css/admin.css', array(), $version );
			gc_register_style( 'jquery-ui-style', WC()->plugin_url() . '/assets/css/jquery-ui/jquery-ui.min.css', array(), $version );
			gc_register_style( 'woocommerce_admin_dashboard_styles', WC()->plugin_url() . '/assets/css/dashboard.css', array(), $version );
			gc_register_style( 'woocommerce_admin_print_reports_styles', WC()->plugin_url() . '/assets/css/reports-print.css', array(), $version, 'print' );
			gc_register_style( 'woocommerce_admin_marketplace_styles', WC()->plugin_url() . '/assets/css/marketplace-suggestions.css', array(), $version );
			gc_register_style( 'woocommerce_admin_privacy_styles', WC()->plugin_url() . '/assets/css/privacy.css', array(), $version );

			// Add RTL support for admin styles.
			gc_style_add_data( 'woocommerce_admin_menu_styles', 'rtl', 'replace' );
			gc_style_add_data( 'woocommerce_admin_styles', 'rtl', 'replace' );
			gc_style_add_data( 'woocommerce_admin_dashboard_styles', 'rtl', 'replace' );
			gc_style_add_data( 'woocommerce_admin_print_reports_styles', 'rtl', 'replace' );
			gc_style_add_data( 'woocommerce_admin_marketplace_styles', 'rtl', 'replace' );
			gc_style_add_data( 'woocommerce_admin_privacy_styles', 'rtl', 'replace' );

			if ( $screen && $screen->is_block_editor() ) {
				gc_register_style( 'woocommerce-general', WC()->plugin_url() . '/assets/css/woocommerce.css', array(), $version );
				gc_style_add_data( 'woocommerce-general', 'rtl', 'replace' );
			}

			// Sitewide menu CSS.
			gc_enqueue_style( 'woocommerce_admin_menu_styles' );

			// Admin styles for WC pages only.
			if ( in_array( $screen_id, wc_get_screen_ids() ) ) {
				gc_enqueue_style( 'woocommerce_admin_styles' );
				gc_enqueue_style( 'jquery-ui-style' );
				gc_enqueue_style( 'gc-color-picker' );
			}

			if ( in_array( $screen_id, array( 'dashboard' ) ) ) {
				gc_enqueue_style( 'woocommerce_admin_dashboard_styles' );
			}

			if ( in_array( $screen_id, array( 'woocommerce_page_wc-reports', 'toplevel_page_wc-reports' ) ) ) {
				gc_enqueue_style( 'woocommerce_admin_print_reports_styles' );
			}

			// Privacy Policy Guide css for back-compat.
			if ( isset( $_GET['gc-privacy-policy-guide'] ) || in_array( $screen_id, array( 'privacy-policy-guide' ) ) ) {
				gc_enqueue_style( 'woocommerce_admin_privacy_styles' );
			}

			// @deprecated 2.3.
			if ( has_action( 'woocommerce_admin_css' ) ) {
				do_action( 'woocommerce_admin_css' );
				wc_deprecated_function( 'The woocommerce_admin_css action', '2.3', 'admin_enqueue_scripts' );
			}

			if ( WC_Marketplace_Suggestions::show_suggestions_for_screen( $screen_id ) ) {
				gc_enqueue_style( 'woocommerce_admin_marketplace_styles' );
			}
		}


		/**
		 * Enqueue scripts.
		 */
		public function admin_scripts() {
			global $gc_query, $post;

			$screen       = get_current_screen();
			$screen_id    = $screen ? $screen->id : '';
			$wc_screen_id = sanitize_title( __( '商店', 'woocommerce' ) );
			$suffix       = Constants::is_true( 'SCRIPT_DEBUG' ) ? '' : '.min';
			$version      = Constants::get_constant( 'WC_VERSION' );

			// Register scripts.
			gc_register_script( 'woocommerce_admin', WC()->plugin_url() . '/assets/js/admin/woocommerce_admin' . $suffix . '.js', array( 'jquery', 'jquery-blockui', 'jquery-ui-sortable', 'jquery-ui-widget', 'jquery-ui-core', 'jquery-tiptip' ), $version );
			gc_register_script( 'jquery-blockui', WC()->plugin_url() . '/assets/js/jquery-blockui/jquery.blockUI' . $suffix . '.js', array( 'jquery' ), '2.70', true );
			gc_register_script( 'jquery-tiptip', WC()->plugin_url() . '/assets/js/jquery-tiptip/jquery.tipTip' . $suffix . '.js', array( 'jquery' ), $version, true );
			gc_register_script( 'round', WC()->plugin_url() . '/assets/js/round/round' . $suffix . '.js', array( 'jquery' ), $version );
			gc_register_script( 'wc-admin-meta-boxes', WC()->plugin_url() . '/assets/js/admin/meta-boxes' . $suffix . '.js', array( 'jquery', 'jquery-ui-datepicker', 'jquery-ui-sortable', 'accounting', 'round', 'wc-enhanced-select', 'plupload-all', 'stupidtable', 'jquery-tiptip' ), $version );
			gc_register_script( 'qrcode', WC()->plugin_url() . '/assets/js/jquery-qrcode/jquery.qrcode' . $suffix . '.js', array( 'jquery' ), $version );
			gc_register_script( 'stupidtable', WC()->plugin_url() . '/assets/js/stupidtable/stupidtable' . $suffix . '.js', array( 'jquery' ), $version );
			gc_register_script( 'serializejson', WC()->plugin_url() . '/assets/js/jquery-serializejson/jquery.serializejson' . $suffix . '.js', array( 'jquery' ), '2.8.1' );
			gc_register_script( 'flot', WC()->plugin_url() . '/assets/js/jquery-flot/jquery.flot' . $suffix . '.js', array( 'jquery' ), $version );
			gc_register_script( 'flot-resize', WC()->plugin_url() . '/assets/js/jquery-flot/jquery.flot.resize' . $suffix . '.js', array( 'jquery', 'flot' ), $version );
			gc_register_script( 'flot-time', WC()->plugin_url() . '/assets/js/jquery-flot/jquery.flot.time' . $suffix . '.js', array( 'jquery', 'flot' ), $version );
			gc_register_script( 'flot-pie', WC()->plugin_url() . '/assets/js/jquery-flot/jquery.flot.pie' . $suffix . '.js', array( 'jquery', 'flot' ), $version );
			gc_register_script( 'flot-stack', WC()->plugin_url() . '/assets/js/jquery-flot/jquery.flot.stack' . $suffix . '.js', array( 'jquery', 'flot' ), $version );
			gc_register_script( 'wc-settings-tax', WC()->plugin_url() . '/assets/js/admin/settings-views-html-settings-tax' . $suffix . '.js', array( 'jquery', 'gc-util', 'underscore', 'backbone', 'jquery-blockui' ), $version );
			gc_register_script( 'wc-backbone-modal', WC()->plugin_url() . '/assets/js/admin/backbone-modal' . $suffix . '.js', array( 'underscore', 'backbone', 'gc-util' ), $version );
			gc_register_script( 'wc-shipping-zones', WC()->plugin_url() . '/assets/js/admin/wc-shipping-zones' . $suffix . '.js', array( 'jquery', 'gc-util', 'underscore', 'backbone', 'jquery-ui-sortable', 'wc-enhanced-select', 'wc-backbone-modal' ), $version );
			gc_register_script( 'wc-shipping-zone-methods', WC()->plugin_url() . '/assets/js/admin/wc-shipping-zone-methods' . $suffix . '.js', array( 'jquery', 'gc-util', 'underscore', 'backbone', 'jquery-ui-sortable', 'wc-backbone-modal' ), $version );
			gc_register_script( 'wc-shipping-classes', WC()->plugin_url() . '/assets/js/admin/wc-shipping-classes' . $suffix . '.js', array( 'jquery', 'gc-util', 'underscore', 'backbone' ), $version );
			gc_register_script( 'wc-clipboard', WC()->plugin_url() . '/assets/js/admin/wc-clipboard' . $suffix . '.js', array( 'jquery' ), $version );
			gc_register_script( 'select2', WC()->plugin_url() . '/assets/js/select2/select2.full' . $suffix . '.js', array( 'jquery' ), '4.0.3' );
			gc_register_script( 'selectWoo', WC()->plugin_url() . '/assets/js/selectWoo/selectWoo.full' . $suffix . '.js', array( 'jquery' ), '1.0.6' );
			gc_register_script( 'wc-enhanced-select', WC()->plugin_url() . '/assets/js/admin/wc-enhanced-select' . $suffix . '.js', array( 'jquery', 'selectWoo' ), $version );
			gc_register_script( 'js-cookie', WC()->plugin_url() . '/assets/js/js-cookie/js.cookie' . $suffix . '.js', array(), '2.1.4', true );

			gc_localize_script(
				'wc-enhanced-select',
				'wc_enhanced_select_params',
				array(
					'i18n_no_matches'           => _x( '没有匹配项', 'enhanced select', 'woocommerce' ),
					'i18n_ajax_error'           => _x( '加载失败', 'enhanced select', 'woocommerce' ),
					'i18n_input_too_short_1'    => _x( '请输入至少一个字符', 'enhanced select', 'woocommerce' ),
					'i18n_input_too_short_n'    => _x( '请至少输入%qty%个字符', 'enhanced select', 'woocommerce' ),
					'i18n_input_too_long_1'     => _x( '请删除1个字符', 'enhanced select', 'woocommerce' ),
					'i18n_input_too_long_n'     => _x( '请删除%qty%个字符', 'enhanced select', 'woocommerce' ),
					'i18n_selection_too_long_1' => _x( '您只能选择1项', 'enhanced select', 'woocommerce' ),
					'i18n_selection_too_long_n' => _x( '您只能选择%qty%项', 'enhanced select', 'woocommerce' ),
					'i18n_load_more'            => _x( '载入更多结果&hellip;', 'enhanced select', 'woocommerce' ),
					'i18n_searching'            => _x( '搜索中&hellip;', 'enhanced select', 'woocommerce' ),
					'ajax_url'                  => admin_url( 'admin-ajax.php' ),
					'search_products_nonce'     => gc_create_nonce( 'search-products' ),
					'search_customers_nonce'    => gc_create_nonce( 'search-customers' ),
					'search_categories_nonce'   => gc_create_nonce( 'search-categories' ),
					'search_pages_nonce'        => gc_create_nonce( 'search-pages' ),
				)
			);

			gc_register_script( 'accounting', WC()->plugin_url() . '/assets/js/accounting/accounting' . $suffix . '.js', array( 'jquery' ), '0.4.2' );
			gc_localize_script(
				'accounting',
				'accounting_params',
				array(
					'mon_decimal_point' => wc_get_price_decimal_separator(),
				)
			);

			gc_register_script( 'wc-orders', WC()->plugin_url() . '/assets/js/admin/wc-orders' . $suffix . '.js', array( 'jquery', 'gc-util', 'underscore', 'backbone', 'jquery-blockui' ), $version );
			gc_localize_script(
				'wc-orders',
				'wc_orders_params',
				array(
					'ajax_url'      => admin_url( 'admin-ajax.php' ),
					'preview_nonce' => gc_create_nonce( 'woocommerce-preview-order' ),
				)
			);

			// WooCommerce admin pages.
			if ( in_array( $screen_id, wc_get_screen_ids() ) ) {
				gc_enqueue_script( 'iris' );
				gc_enqueue_script( 'woocommerce_admin' );
				gc_enqueue_script( 'wc-enhanced-select' );
				gc_enqueue_script( 'jquery-ui-sortable' );
				gc_enqueue_script( 'jquery-ui-autocomplete' );

				$locale  = localeconv();
				$decimal_point = isset( $locale['decimal_point'] ) ? $locale['decimal_point'] : '.';
				$decimal = ( ! empty( wc_get_price_decimal_separator() ) ) ? wc_get_price_decimal_separator() : $decimal_point;

				$params = array(
					/* translators: %s: decimal */
					'i18n_decimal_error'                => sprintf( __( '请输入带有一位小数的值 (%s)，不包含千位分隔符。', 'woocommerce' ), $decimal ),
					/* translators: %s: price decimal separator */
					'i18n_mon_decimal_error'            => sprintf( __( '请输入带有一位小数的值 (%s)，不要使用千分符和货币符号。', 'woocommerce' ), wc_get_price_decimal_separator() ),
					'i18n_country_iso_error'            => __( '请输入两个字母组成的国家/地区代码.', 'woocommerce' ),
					'i18n_sale_less_than_regular_error' => __( '请输入一项小于常规价格的值。', 'woocommerce' ),
					'i18n_delete_product_notice'        => __( '这个产品已发生了销售行为并且可能被关联到已有订单了。确定要删除吗？', 'woocommerce' ),
					'i18n_remove_personal_data_notice'  => __( '此操作无法撤销。确认您要抹除所选的订单的个人信息吗？', 'woocommerce' ),
					'i18n_confirm_delete'               => __( '是否确定要删除此项？', 'woocommerce' ),
					'decimal_point'                     => $decimal,
					'mon_decimal_point'                 => wc_get_price_decimal_separator(),
					'ajax_url'                          => admin_url( 'admin-ajax.php' ),
					'strings'                           => array(
						'import_products' => __( '导入', 'woocommerce' ),
						'export_products' => __( '导出', 'woocommerce' ),
					),
					'nonces'                            => array(
						'gateway_toggle' => gc_create_nonce( 'woocommerce-toggle-payment-gateway-enabled' ),
					),
					'urls'                              => array(
						'import_products' => current_user_can( 'import' ) ? esc_url_raw( admin_url( 'edit.php?post_type=product&page=product_importer' ) ) : null,
						'export_products' => current_user_can( 'export' ) ? esc_url_raw( admin_url( 'edit.php?post_type=product&page=product_exporter' ) ) : null,
					),
				);

				gc_localize_script( 'woocommerce_admin', 'woocommerce_admin', $params );
			}

			// Edit product category pages.
			if ( in_array( $screen_id, array( 'edit-product_cat' ) ) ) {
				gc_enqueue_media();
			}

			// Products.
			if ( in_array( $screen_id, array( 'edit-product' ) ) ) {
				gc_enqueue_script( 'woocommerce_quick-edit', WC()->plugin_url() . '/assets/js/admin/quick-edit' . $suffix . '.js', array( 'jquery', 'woocommerce_admin' ), $version );

				$params = array(
					'strings' => array(
						'allow_reviews' => esc_js( __( '允许评价', 'woocommerce' ) ),
					),
				);

				gc_localize_script( 'woocommerce_quick-edit', 'woocommerce_quick_edit', $params );
			}

			// Meta boxes.
			if ( in_array( $screen_id, array( 'product', 'edit-product' ) ) ) {
				gc_enqueue_media();
				gc_register_script( 'wc-admin-product-meta-boxes', WC()->plugin_url() . '/assets/js/admin/meta-boxes-product' . $suffix . '.js', array( 'wc-admin-meta-boxes', 'media-models' ), $version );
				gc_register_script( 'wc-admin-variation-meta-boxes', WC()->plugin_url() . '/assets/js/admin/meta-boxes-product-variation' . $suffix . '.js', array( 'wc-admin-meta-boxes', 'serializejson', 'media-models' ), $version );

				gc_enqueue_script( 'wc-admin-product-meta-boxes' );
				gc_enqueue_script( 'wc-admin-variation-meta-boxes' );

				$params = array(
					'post_id'                             => isset( $post->ID ) ? $post->ID : '',
					'plugin_url'                          => WC()->plugin_url(),
					'ajax_url'                            => admin_url( 'admin-ajax.php' ),
					'woocommerce_placeholder_img_src'     => wc_placeholder_img_src(),
					'add_variation_nonce'                 => gc_create_nonce( 'add-variation' ),
					'link_variation_nonce'                => gc_create_nonce( 'link-variations' ),
					'delete_variations_nonce'             => gc_create_nonce( 'delete-variations' ),
					'load_variations_nonce'               => gc_create_nonce( 'load-variations' ),
					'save_variations_nonce'               => gc_create_nonce( 'save-variations' ),
					'bulk_edit_variations_nonce'          => gc_create_nonce( 'bulk-edit-variations' ),
					/* translators: %d: Number of variations */
					'i18n_link_all_variations'            => esc_js( sprintf( __( '您确定您要连接所有变量吗？这将为每一个可变属性可能的组合创建一个新的变量产品，（每圈最大 %d ）。', 'woocommerce' ), Constants::is_defined( 'WC_MAX_LINKED_VARIATIONS' ) ? Constants::get_constant( 'WC_MAX_LINKED_VARIATIONS' ) : 50 ) ),
					'i18n_enter_a_value'                  => esc_js( __( '输入一个值', 'woocommerce' ) ),
					'i18n_enter_menu_order'               => esc_js( __( '变量菜单位置(确定变量在列表中的位置)', 'woocommerce' ) ),
					'i18n_enter_a_value_fixed_or_percent' => esc_js( __( '输入一个值(固定值或 %)', 'woocommerce' ) ),
					'i18n_delete_all_variations'          => esc_js( __( '您确定要删除全部变更？此项操作不能恢复。', 'woocommerce' ) ),
					'i18n_last_warning'                   => esc_js( __( '最后警告，您确定吗？', 'woocommerce' ) ),
					'i18n_choose_image'                   => esc_js( __( '选择图像', 'woocommerce' ) ),
					'i18n_set_image'                      => esc_js( __( '设为特色图像', 'woocommerce' ) ),
					'i18n_variation_added'                => esc_js( __( '变量已添加', 'woocommerce' ) ),
					'i18n_variations_added'               => esc_js( __( '变量已添加', 'woocommerce' ) ),
					'i18n_no_variations_added'            => esc_js( __( '未添加变量', 'woocommerce' ) ),
					'i18n_remove_variation'               => esc_js( __( '确定要删除此变量？', 'woocommerce' ) ),
					'i18n_scheduled_sale_start'           => esc_js( __( '销售开始日期 (YYYY-MM-DD 格式或留空)', 'woocommerce' ) ),
					'i18n_scheduled_sale_end'             => esc_js( __( '销售截止日期(YYYY-MM-DD 格式或留空)', 'woocommerce' ) ),
					'i18n_edited_variations'              => esc_js( __( '离开前保存更改?', 'woocommerce' ) ),
					'i18n_variation_count_single'         => esc_js( __( '%qty% 变量', 'woocommerce' ) ),
					'i18n_variation_count_plural'         => esc_js( __( '%qty% 变量', 'woocommerce' ) ),
					'variations_per_page'                 => absint( apply_filters( 'woocommerce_admin_meta_boxes_variations_per_page', 15 ) ),
				);

				gc_localize_script( 'wc-admin-variation-meta-boxes', 'woocommerce_admin_meta_boxes_variations', $params );
			}
			if ( in_array( str_replace( 'edit-', '', $screen_id ), wc_get_order_types( 'order-meta-boxes' ) ) ) {
				$default_location = wc_get_customer_default_location();

				gc_enqueue_script( 'wc-admin-order-meta-boxes', WC()->plugin_url() . '/assets/js/admin/meta-boxes-order' . $suffix . '.js', array( 'wc-admin-meta-boxes', 'wc-backbone-modal', 'selectWoo', 'wc-clipboard' ), $version );
				gc_localize_script(
					'wc-admin-order-meta-boxes',
					'woocommerce_admin_meta_boxes_order',
					array(
						'countries'              => gc_json_encode( array_merge( WC()->countries->get_allowed_country_states(), WC()->countries->get_shipping_country_states() ) ),
						'i18n_select_state_text' => esc_attr__( '选择一个选项&hellip;', 'woocommerce' ),
						'default_country'        => isset( $default_location['country'] ) ? $default_location['country'] : '',
						'default_state'          => isset( $default_location['state'] ) ? $default_location['state'] : '',
						'placeholder_name'       => esc_attr__( '称呼(必需)', 'woocommerce' ),
						'placeholder_value'      => esc_attr__( '值(必需)', 'woocommerce' ),
					)
				);
			}
			if ( in_array( $screen_id, array( 'shop_coupon', 'edit-shop_coupon' ) ) ) {
				gc_enqueue_script( 'wc-admin-coupon-meta-boxes', WC()->plugin_url() . '/assets/js/admin/meta-boxes-coupon' . $suffix . '.js', array( 'wc-admin-meta-boxes' ), $version );
				gc_localize_script(
					'wc-admin-coupon-meta-boxes',
					'woocommerce_admin_meta_boxes_coupon',
					array(
						'generate_button_text' => esc_html__( '生成优惠券代码', 'woocommerce' ),
						'characters'           => apply_filters( 'woocommerce_coupon_code_generator_characters', 'ABCDEFGHJKMNPQRSTUVWXYZ23456789' ),
						'char_length'          => apply_filters( 'woocommerce_coupon_code_generator_character_length', 8 ),
						'prefix'               => apply_filters( 'woocommerce_coupon_code_generator_prefix', '' ),
						'suffix'               => apply_filters( 'woocommerce_coupon_code_generator_suffix', '' ),
					)
				);
			}
			if ( in_array( str_replace( 'edit-', '', $screen_id ), array_merge( array( 'shop_coupon', 'product' ), wc_get_order_types( 'order-meta-boxes' ) ) ) ) {
				$post_id                = isset( $post->ID ) ? $post->ID : '';
				$currency               = '';
				$remove_item_notice     = __( '是否确定要删除所选项目？', 'woocommerce' );
				$remove_fee_notice      = __( '是否确定要删除所选费用？', 'woocommerce' );
				$remove_shipping_notice = __( '是否确定要删除所选配送？', 'woocommerce' );

				if ( $post_id && in_array( get_post_type( $post_id ), wc_get_order_types( 'order-meta-boxes' ) ) ) {
					$order = wc_get_order( $post_id );
					if ( $order ) {
						$currency = $order->get_currency();

						if ( ! $order->has_status( array( 'pending', 'failed', 'cancelled' ) ) ) {
							$remove_item_notice = $remove_item_notice . ' ' . __( "您可能需要手动恢复项目的库存。", 'woocommerce' );
						}
					}
				}

				$params = array(
					'remove_item_notice'            => $remove_item_notice,
					'remove_fee_notice'             => $remove_fee_notice,
					'remove_shipping_notice'        => $remove_shipping_notice,
					'i18n_select_items'             => __( '请选择一些物品。', 'woocommerce' ),
					'i18n_do_refund'                => __( '是否确认要执行此项退款？ 本操作无法取消。', 'woocommerce' ),
					'i18n_delete_refund'            => __( '是否确定要删除退款？ 本操作无法取消。', 'woocommerce' ),
					'i18n_delete_tax'               => __( '是否确定要删除此项税额? 本操作无法取消。', 'woocommerce' ),
					'remove_item_meta'              => __( '删除这个项目标签？', 'woocommerce' ),
					'remove_attribute'              => __( '删除这个属性？', 'woocommerce' ),
					'name_label'                    => __( '名称', 'woocommerce' ),
					'remove_label'                  => __( '删除', 'woocommerce' ),
					'click_to_toggle'               => __( '点击切换', 'woocommerce' ),
					'values_label'                  => __( '属性值', 'woocommerce' ),
					'text_attribute_tip'            => __( '输入一些文字或某些属性，使用竖线 (|) 分隔值。', 'woocommerce' ),
					'visible_label'                 => __( '在产品页可见', 'woocommerce' ),
					'used_for_variations_label'     => __( '用于变量', 'woocommerce' ),
					'new_attribute_prompt'          => __( '输入一个新的属性项的名称：', 'woocommerce' ),
					'calc_totals'                   => __( '重新计算总价？将根据客户所在国家/地区（或商店所在国家/地区）计算税费并更新总价。', 'woocommerce' ),
					'copy_billing'                  => __( '将帐单信息复制到配送信息？此操作将移除当前输入的所有配送信息。', 'woocommerce' ),
					'load_billing'                  => __( "加载客户的账单信息？将会删除当前输入的所有帐单信息。", 'woocommerce' ),
					'load_shipping'                 => __( "加载客户的配送信息？这将删除当前输入的所有配送信息。", 'woocommerce' ),
					'featured_label'                => __( '精选', 'woocommerce' ),
					'prices_include_tax'            => esc_attr( get_option( 'woocommerce_prices_include_tax' ) ),
					'tax_based_on'                  => esc_attr( get_option( 'woocommerce_tax_based_on' ) ),
					'round_at_subtotal'             => esc_attr( get_option( 'woocommerce_tax_round_at_subtotal' ) ),
					'no_customer_selected'          => __( '未选择客户', 'woocommerce' ),
					'plugin_url'                    => WC()->plugin_url(),
					'ajax_url'                      => admin_url( 'admin-ajax.php' ),
					'order_item_nonce'              => gc_create_nonce( 'order-item' ),
					'add_attribute_nonce'           => gc_create_nonce( 'add-attribute' ),
					'save_attributes_nonce'         => gc_create_nonce( 'save-attributes' ),
					'calc_totals_nonce'             => gc_create_nonce( 'calc-totals' ),
					'get_customer_details_nonce'    => gc_create_nonce( 'get-customer-details' ),
					'search_products_nonce'         => gc_create_nonce( 'search-products' ),
					'grant_access_nonce'            => gc_create_nonce( 'grant-access' ),
					'revoke_access_nonce'           => gc_create_nonce( 'revoke-access' ),
					'add_order_note_nonce'          => gc_create_nonce( 'add-order-note' ),
					'delete_order_note_nonce'       => gc_create_nonce( 'delete-order-note' ),
					'calendar_image'                => WC()->plugin_url() . '/assets/images/calendar.png',
					'post_id'                       => isset( $post->ID ) ? $post->ID : '',
					'base_country'                  => WC()->countries->get_base_country(),
					'currency_format_num_decimals'  => wc_get_price_decimals(),
					'currency_format_symbol'        => get_woocommerce_currency_symbol( $currency ),
					'currency_format_decimal_sep'   => esc_attr( wc_get_price_decimal_separator() ),
					'currency_format_thousand_sep'  => esc_attr( wc_get_price_thousand_separator() ),
					'currency_format'               => esc_attr( str_replace( array( '%1$s', '%2$s' ), array( '%s', '%v' ), get_woocommerce_price_format() ) ), // For accounting JS.
					'rounding_precision'            => wc_get_rounding_precision(),
					'tax_rounding_mode'             => wc_get_tax_rounding_mode(),
					'product_types'                 => array_unique( array_merge( array( 'simple', 'grouped', 'variable', 'external' ), array_keys( wc_get_product_types() ) ) ),
					'i18n_download_permission_fail' => __( '无法授权 - 该用户要么已经拥有权限要么账单邮箱末设置。请确认账单邮箱已设置并保存订单。', 'woocommerce' ),
					'i18n_permission_revoke'        => __( '您确定要撤销访问此下载？', 'woocommerce' ),
					'i18n_tax_rate_already_exists'  => __( '您不能重复输入相同的税率!', 'woocommerce' ),
					'i18n_delete_note'              => __( '确定要删除此备注？此操作不可撤销。', 'woocommerce' ),
					'i18n_apply_coupon'             => __( '输入要应用的优惠券代码。折扣适用于税前总金额。', 'woocommerce' ),
					'i18n_add_fee'                  => __( '输入固定金额或百分比作为费用金额。', 'woocommerce' ),
				);

				gc_localize_script( 'wc-admin-meta-boxes', 'woocommerce_admin_meta_boxes', $params );
			}

			// Term ordering - only when sorting by term_order.
			if ( ( strstr( $screen_id, 'edit-pa_' ) || ( ! empty( $_GET['taxonomy'] ) && in_array( gc_unslash( $_GET['taxonomy'] ), apply_filters( 'woocommerce_sortable_taxonomies', array( 'product_cat' ) ) ) ) ) && ! isset( $_GET['orderby'] ) ) {

				gc_register_script( 'woocommerce_term_ordering', WC()->plugin_url() . '/assets/js/admin/term-ordering' . $suffix . '.js', array( 'jquery-ui-sortable' ), $version );
				gc_enqueue_script( 'woocommerce_term_ordering' );

				$taxonomy = isset( $_GET['taxonomy'] ) ? wc_clean( gc_unslash( $_GET['taxonomy'] ) ) : '';

				$woocommerce_term_order_params = array(
					'taxonomy' => $taxonomy,
				);

				gc_localize_script( 'woocommerce_term_ordering', 'woocommerce_term_ordering_params', $woocommerce_term_order_params );
			}

			// Product sorting - only when sorting by menu order on the products page.
			if ( current_user_can( 'edit_others_pages' ) && 'edit-product' === $screen_id && isset( $gc_query->query['orderby'] ) && 'menu_order title' === $gc_query->query['orderby'] ) {
				gc_register_script( 'woocommerce_product_ordering', WC()->plugin_url() . '/assets/js/admin/product-ordering' . $suffix . '.js', array( 'jquery-ui-sortable' ), $version, true );
				gc_enqueue_script( 'woocommerce_product_ordering' );
			}

			// Reports Pages.
			if ( in_array( $screen_id, apply_filters( 'woocommerce_reports_screen_ids', array( $wc_screen_id . '_page_wc-reports', 'toplevel_page_wc-reports', 'dashboard' ) ) ) ) {
				gc_register_script( 'wc-reports', WC()->plugin_url() . '/assets/js/admin/reports' . $suffix . '.js', array( 'jquery', 'jquery-ui-datepicker' ), $version );

				gc_enqueue_script( 'wc-reports' );
				gc_enqueue_script( 'flot' );
				gc_enqueue_script( 'flot-resize' );
				gc_enqueue_script( 'flot-time' );
				gc_enqueue_script( 'flot-pie' );
				gc_enqueue_script( 'flot-stack' );
			}

			// API settings.
			if ( $wc_screen_id . '_page_wc-settings' === $screen_id && isset( $_GET['section'] ) && 'keys' == $_GET['section'] ) {
				gc_register_script( 'wc-api-keys', WC()->plugin_url() . '/assets/js/admin/api-keys' . $suffix . '.js', array( 'jquery', 'woocommerce_admin', 'underscore', 'backbone', 'gc-util', 'qrcode', 'wc-clipboard' ), $version, true );
				gc_enqueue_script( 'wc-api-keys' );
				gc_localize_script(
					'wc-api-keys',
					'woocommerce_admin_api_keys',
					array(
						'ajax_url'         => admin_url( 'admin-ajax.php' ),
						'update_api_nonce' => gc_create_nonce( 'update-api-key' ),
						'clipboard_failed' => esc_html__( '复制到剪贴板失败，请按 Ctrl/Cmd+C 键来复制。', 'woocommerce' ),
					)
				);
			}

			// System status.
			if ( $wc_screen_id . '_page_wc-status' === $screen_id ) {
				gc_register_script( 'wc-admin-system-status', WC()->plugin_url() . '/assets/js/admin/system-status' . $suffix . '.js', array( 'wc-clipboard' ), $version );
				gc_enqueue_script( 'wc-admin-system-status' );
				gc_localize_script(
					'wc-admin-system-status',
					'woocommerce_admin_system_status',
					array(
						'delete_log_confirmation' => esc_js( __( '是否确定要删除此日志？', 'woocommerce' ) ),
						'run_tool_confirmation'   => esc_js( __( '您确定要运行此工具吗？', 'woocommerce' ) ),
					)
				);
			}

			if ( in_array( $screen_id, array( 'user-edit', 'profile' ) ) ) {
				gc_register_script( 'wc-users', WC()->plugin_url() . '/assets/js/admin/users' . $suffix . '.js', array( 'jquery', 'wc-enhanced-select', 'selectWoo' ), $version, true );
				gc_enqueue_script( 'wc-users' );
				gc_localize_script(
					'wc-users',
					'wc_users_params',
					array(
						'countries'              => gc_json_encode( array_merge( WC()->countries->get_allowed_country_states(), WC()->countries->get_shipping_country_states() ) ),
						'i18n_select_state_text' => esc_attr__( '选择一个选项&hellip;', 'woocommerce' ),
					)
				);
			}

			if ( WC_Marketplace_Suggestions::show_suggestions_for_screen( $screen_id ) ) {
				$active_plugin_slugs = array_map( 'dirname', get_option( 'active_plugins' ) );
				gc_register_script(
					'marketplace-suggestions',
					WC()->plugin_url() . '/assets/js/admin/marketplace-suggestions' . $suffix . '.js',
					array( 'jquery', 'underscore', 'js-cookie' ),
					$version,
					true
				);
				gc_localize_script(
					'marketplace-suggestions',
					'marketplace_suggestions',
					array(
						'dismiss_suggestion_nonce' => gc_create_nonce( 'add_dismissed_marketplace_suggestion' ),
						'active_plugins'           => $active_plugin_slugs,
						'dismissed_suggestions'    => WC_Marketplace_Suggestions::get_dismissed_suggestions(),
						'suggestions_data'         => WC_Marketplace_Suggestions::get_suggestions_api_data(),
						'manage_suggestions_url'   => admin_url( 'admin.php?page=wc-settings&tab=advanced&section=woocommerce_com' ),
						'in_app_purchase_params'   => WC_Admin_Addons::get_in_app_purchase_url_params(),
						'i18n_marketplace_suggestions_default_cta'
							=> esc_html__( '了解更多', 'woocommerce' ),
						'i18n_marketplace_suggestions_dismiss_tooltip'
							=> esc_attr__( '忽略此建议', 'woocommerce' ),
						'i18n_marketplace_suggestions_manage_suggestions'
							=> esc_html__( '管理建议', 'woocommerce' ),
					)
				);
				gc_enqueue_script( 'marketplace-suggestions' );
			}

		}

	}

endif;

return new WC_Admin_Assets();
