<?php
/**
 * Add some content to the help tab
 *
 * @package     WooCommerce\Admin
 * @version     2.1.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( class_exists( 'WC_Admin_Help', false ) ) {
	return new WC_Admin_Help();
}

/**
 * WC_Admin_Help Class.
 */
class WC_Admin_Help {

	/**
	 * Hook in tabs.
	 */
	public function __construct() {
		add_action( 'current_screen', array( $this, 'add_tabs' ), 50 );
	}

	/**
	 * Add help tabs.
	 */
	public function add_tabs() {
		$screen = get_current_screen();

		if ( ! $screen || ! in_array( $screen->id, wc_get_screen_ids() ) ) {
			return;
		}

		$screen->add_help_tab(
			array(
				'id'      => 'woocommerce_support_tab',
				'title'   => __( '帮助 &amp; 支持', 'woocommerce' ),
				'content' =>
					'<h2>' . __( '帮助 &amp; 支持', 'woocommerce' ) . '</h2>' .
					'<p>' . sprintf(
						/* translators: %s: Documentation URL */
						__( '如果您需要在理解、使用或者扩展WooCommerce时需要帮助，<a href=\"%s\">请查看我们的文档</a>。您将会找到包括代码片段、教程等在内的各种资源。', 'woocommerce' ),
						'https://docs.woocommerce.com/documentation/plugins/woocommerce/?utm_source=helptab&utm_medium=product&utm_content=docs&utm_campaign=woocommerceplugin'
					) . '</p>' .
					'<p>' . sprintf(
						/* translators: %s: Forum URL */
						__( '有关 WooCommerce 核心的更多帮助，请访问<a href=\"%1$s\">社区论坛</a>。有关 WooCommerce.com 上出售的高级扩展程序的帮助，请<a href=\"%2$s\">在 WooCommerce.com 上提交支持请求</a>。', 'woocommerce' ),
						'https://www.gechiui.com/support/plugin/woocommerce',
						'https://woocommerce.com/my-account/create-a-ticket/?utm_source=helptab&utm_medium=product&utm_content=tickets&utm_campaign=woocommerceplugin'
					) . '</p>' .
					'<p>' . __( '在寻求帮助之前，我们建议您检查系统状态页面，以确定您的配置是否有什么问题。', 'woocommerce' ) . '</p>' .
					'<p><a href="' . admin_url( 'admin.php?page=wc-status' ) . '" class="button button-primary">' . __( '系统状态', 'woocommerce' ) . '</a> <a href="https://www.gechiui.com/support/plugin/woocommerce" class="button">' . __( '社区论坛 ', 'woocommerce' ) . '</a> <a href="https://woocommerce.com/my-account/create-a-ticket/?utm_source=helptab&utm_medium=product&utm_content=tickets&utm_campaign=woocommerceplugin" class="button">' . __( 'WooCommerce.com 支持', 'woocommerce' ) . '</a></p>',
			)
		);

		$screen->add_help_tab(
			array(
				'id'      => 'woocommerce_bugs_tab',
				'title'   => __( '找到一个 bug?', 'woocommerce' ),
				'content' =>
					'<h2>' . __( '找到一个 bug?', 'woocommerce' ) . '</h2>' .
					/* translators: 1: GitHub issues URL 2: GitHub contribution guide URL 3: System status report URL */
					'<p>' . sprintf( __( '如果您发现 WooCommerce 核心中存在错误，可以通过 <a href=\"%1$s\">GitHub 问题</a>创建工单。 在提交报告之前，请确保已阅读<a href=\"%2$s\">贡献指南</a>。 为帮助我们解决您的问题，请尽可能提供详细描述，并附上您的<a href=\"%3$s\">系统状态报告</a>。', 'woocommerce' ), 'https://github.com/woocommerce/woocommerce/issues?state=open', 'https://github.com/woocommerce/woocommerce/blob/trunk/.github/CONTRIBUTING.md', admin_url( 'admin.php?page=wc-status' ) ) . '</p>' .
					'<p><a href="https://github.com/woocommerce/woocommerce/issues/new?assignees=&labels=&template=1-bug-report.yml" class="button button-primary">' . __( 'BUG报告', 'woocommerce' ) . '</a> <a href="' . admin_url( 'admin.php?page=wc-status' ) . '" class="button">' . __( '系统状态', 'woocommerce' ) . '</a></p>',

			)
		);

		$screen->set_help_sidebar(
			'<p><strong>' . __( '欲了解更多信息：', 'woocommerce' ) . '</strong></p>' .
			'<p><a href="https://woocommerce.com/?utm_source=helptab&utm_medium=product&utm_content=about&utm_campaign=woocommerceplugin" target="_blank">' . __( '关于 WooCommerce', 'woocommerce' ) . '</a></p>' .
			'<p><a href="https://www.gechiui.com/plugins/woocommerce/" target="_blank">' . __( 'www.GeChiUI.com项目', 'woocommerce' ) . '</a></p>' .
			'<p><a href="https://github.com/woocommerce/woocommerce/" target="_blank">' . __( 'GitHub 项目', 'woocommerce' ) . '</a></p>' .
			'<p><a href="https://woocommerce.com/storefront/?utm_source=helptab&utm_medium=product&utm_content=wcthemes&utm_campaign=woocommerceplugin" target="_blank">' . __( '官方主题', 'woocommerce' ) . '</a></p>' .
			'<p><a href="https://woocommerce.com/product-category/woocommerce-extensions/?utm_source=helptab&utm_medium=product&utm_content=wcextensions&utm_campaign=woocommerceplugin" target="_blank">' . __( '官方扩展', 'woocommerce' ) . '</a></p>'
		);
	}
}

return new WC_Admin_Help();
