<?php
/**
 * Adds and controls pointers for contextual help/tutorials
 *
 * @package WooCommerce\Admin\Pointers
 * @version 2.4.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * WC_Admin_Pointers Class.
 */
class WC_Admin_Pointers {

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'admin_enqueue_scripts', array( $this, 'setup_pointers_for_screen' ) );
	}

	/**
	 * Setup pointers for screen.
	 */
	public function setup_pointers_for_screen() {
		$screen = get_current_screen();

		if ( ! $screen ) {
			return;
		}

		switch ( $screen->id ) {
			case 'product':
				$this->create_product_tutorial();
				break;
		}
	}

	/**
	 * Pointers for creating a product.
	 */
	public function create_product_tutorial() {
		if ( ! isset( $_GET['tutorial'] ) || ! current_user_can( 'manage_options' ) ) { // phpcs:ignore GeChiUI.Security.NonceVerification.Recommended
			return;
		}

		// These pointers will chain - they will not be shown at once.
		$pointers = array(
			'pointers' => array(
				'title'          => array(
					'target'       => '#title',
					'next'         => 'content',
					'next_trigger' => array(
						'target' => '#title',
						'event'  => 'input',
					),
					'options'      => array(
						'content'  => '<h3>' . esc_html__( '产品名称', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( '在此处为您的新产品命名。 这是必填字段，将是您的客户将在商店中看到的内容。', 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'top',
							'align' => 'left',
						),
					),
				),
				'content'        => array(
					'target'       => '#gc-content-editor-container',
					'next'         => 'product-type',
					'next_trigger' => array(),
					'options'      => array(
						'content'  => '<h3>' . esc_html__( '产品描述', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( '这里是您的产品的内容描述，您可在此写下您的产品详情。', 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'bottom',
							'align' => 'middle',
						),
					),
				),
				'product-type'   => array(
					'target'       => '#product-type',
					'next'         => 'virtual',
					'next_trigger' => array(
						'target' => '#product-type',
						'event'  => 'change blur click',
					),
					'options'      => array(
						'content'  => '<h3>' . esc_html__( '选择产品类型', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( '选择一种产品类型。简单产品适用于大多数实物和服务销售(我们推荐您现在设置为简单产品)。', 'woocommerce' ) . '</p>' .
										'<p>' . esc_html__( '可变产品适用于比较复杂的产品例如有多种尺寸的T恤衫。', 'woocommerce' ) . '</p>' .
										'<p>' . esc_html__( '成组产品适用于将多个简单产品打包成一个。', 'woocommerce' ) . '</p>' .
										'<p>' . esc_html__( '最后,联锁产品适用于链接到您网站外的产品。', 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'bottom',
							'align' => 'middle',
						),
					),
				),
				'virtual'        => array(
					'target'       => '#_virtual',
					'next'         => 'downloadable',
					'next_trigger' => array(
						'target' => '#_virtual',
						'event'  => 'change',
					),
					'options'      => array(
						'content'  => '<h3>' . esc_html__( '虚拟产品', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( '如果是不需要物流的虚拟产品，例如服务，可选中\"虚拟\"。', 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'bottom',
							'align' => 'middle',
						),
					),
				),
				'downloadable'   => array(
					'target'       => '#_downloadable',
					'next'         => 'regular_price',
					'next_trigger' => array(
						'target' => '#_downloadable',
						'event'  => 'change',
					),
					'options'      => array(
						'content'  => '<h3>' . esc_html__( '可下载产品', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( '如果购买此产品后给客户访问可下载的文件，例如软件，请选中此框。', 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'bottom',
							'align' => 'middle',
						),
					),
				),
				'regular_price'  => array(
					'target'       => '#_regular_price',
					'next'         => 'postexcerpt',
					'next_trigger' => array(
						'target' => '#_regular_price',
						'event'  => 'input',
					),
					'options'      => array(
						'content'  => '<h3>' . esc_html__( '价格', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( '下一步您需要给您的产品确定一个价格。', 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'bottom',
							'align' => 'middle',
						),
					),
				),
				'postexcerpt'    => array(
					'target'       => '#postexcerpt',
					'next'         => 'postimagediv',
					'next_trigger' => array(
						'target' => '#postexcerpt',
						'event'  => 'input',
					),
					'options'      => array(
						'content'  => '<h3>' . esc_html__( '产品简短描述', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( '在此添加一个产品简述，它将会出现在产品页面的产品名称下面。', 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'bottom',
							'align' => 'middle',
						),
					),
				),
				'postimagediv'   => array(
					'target'  => '#postimagediv',
					'next'    => 'product_tag',
					'options' => array(
						'content'  => '<h3>' . esc_html__( '产品图片', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( "在此为您的产品上传或指定一张图片，此图片将会显示在商店的图片目录中。", 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'right',
							'align' => 'middle',
						),
					),
				),
				'product_tag'    => array(
					'target'  => '#tagsdiv-product_tag',
					'next'    => 'product_catdiv',
					'options' => array(
						'content'  => '<h3>' . esc_html__( '产品标签', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( '您可以选择在此处“标记”您的产品。标签是一种不错的标记产品方法，以便客户更容易找到它们。', 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'right',
							'align' => 'middle',
						),
					),
				),
				'product_catdiv' => array(
					'target'  => '#product_catdiv',
					'next'    => 'submitdiv',
					'options' => array(
						'content'  => '<h3>' . esc_html__( '产品类别', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( '可选地为您的产品指定分类，以便于它们能更方便地被找到和浏览。', 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'right',
							'align' => 'middle',
						),
					),
				),
				'submitdiv'      => array(
					'target'  => '#submitdiv',
					'next'    => '',
					'options' => array(
						'content'  => '<h3>' . esc_html__( '发布您的产品！', 'woocommerce' ) . '</h3>' .
										'<p>' . esc_html__( '当您完成了图片的编辑时，点击\"发布\"按钮就可以将您的图片发布到您的商店了。', 'woocommerce' ) . '</p>',
						'position' => array(
							'edge'  => 'right',
							'align' => 'middle',
						),
					),
				),
			),
		);

		$this->enqueue_pointers( $pointers );
	}

	/**
	 * Enqueue pointers and add script to page.
	 *
	 * @param array $pointers Pointers data.
	 */
	public function enqueue_pointers( $pointers ) {
		$pointers = rawurlencode( gc_json_encode( $pointers ) );
		gc_enqueue_style( 'gc-pointer' );
		gc_enqueue_script( 'gc-pointer' );
		wc_enqueue_js(
			"jQuery( function( $ ) {
				var wc_pointers = JSON.parse( decodeURIComponent( '{$pointers}' ) );

				setTimeout( init_wc_pointers, 800 );

				function init_wc_pointers() {
					$.each( wc_pointers.pointers, function( i ) {
						show_wc_pointer( i );
						return false;
					});
				}

				function show_wc_pointer( id ) {
					var pointer = wc_pointers.pointers[ id ];
					var options = $.extend( pointer.options, {
						pointerClass: 'gc-pointer wc-pointer',
						close: function() {
							if ( pointer.next ) {
								show_wc_pointer( pointer.next );
							}
						},
						buttons: function( event, t ) {
							var close   = '" . esc_js( __( '忽略', 'woocommerce' ) ) . "',
								next    = '" . esc_js( __( '下一个', 'woocommerce' ) ) . "',
								button  = $( '<a class=\"close\" href=\"#\">' + close + '</a>' ),
								button2 = $( '<a class=\"button button-primary\" href=\"#\">' + next + '</a>' ),
								wrapper = $( '<div class=\"wc-pointer-buttons\" />' );

							button.on( 'click.pointer', function(e) {
								e.preventDefault();
								t.element.pointer('destroy');
							});

							button2.on( 'click.pointer', function(e) {
								e.preventDefault();
								t.element.pointer('close');
							});

							wrapper.append( button );
							wrapper.append( button2 );

							return wrapper;
						},
					} );
					var this_pointer = $( pointer.target ).pointer( options );
					this_pointer.pointer( 'open' );

					if ( pointer.next_trigger ) {
						$( pointer.next_trigger.target ).on( pointer.next_trigger.event, function() {
							setTimeout( function() { this_pointer.pointer( 'close' ); }, 400 );
						});
					}
				}
			});"
		);
	}
}

new WC_Admin_Pointers();
