<?php
/**
 * Default mappings
 *
 * @package WooCommerce\Admin\Importers
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Importer current locale.
 *
 * @since 3.1.0
 * @return string
 */
function wc_importer_current_locale() {
	$locale = get_locale();
	if ( function_exists( 'get_user_locale' ) ) {
		$locale = get_user_locale();
	}

	return $locale;
}

/**
 * Add English mapping placeholders when not using English as current language.
 *
 * @since 3.1.0
 * @param array $mappings Importer columns mappings.
 * @return array
 */
function wc_importer_default_english_mappings( $mappings ) {
	if ( 'en_US' === wc_importer_current_locale() ) {
		return $mappings;
	}

	$weight_unit    = get_option( 'woocommerce_weight_unit' );
	$dimension_unit = get_option( 'woocommerce_dimension_unit' );
	$new_mappings   = array(
		'ID'                                      => 'id',
		'Type'                                    => 'type',
		'SKU'                                     => 'sku',
		'Name'                                    => 'name',
		'Published'                               => 'published',
		'是推荐产品？'                            => 'featured',
		'在列表页可见'                   => 'catalog_visibility',
		'简短描述'                       => 'short_description',
		'Description'                             => 'description',
		'促销开始日期'                  => 'date_on_sale_from',
		'促销截止日期'                    => 'date_on_sale_to',
		'税状态'                              => 'tax_status',
		'税类'                               => 'tax_class',
		'有货？'                               => 'stock_status',
		'Stock'                                   => 'stock_quantity',
		'允许缺货下单？'                     => 'backorders',
		'库存不足'                        => 'low_stock_amount',
		'单独出售？'                      => 'sold_individually',
		sprintf( '重量(%s)', $weight_unit )    => 'weight',
		sprintf( '长度(%s)', $dimension_unit ) => 'length',
		sprintf( '宽度 (%s)', $dimension_unit )  => 'width',
		sprintf( '高度 (%s)', $dimension_unit ) => 'height',
		'允许客户评价？'                 => 'reviews_allowed',
		'购物备注'                           => 'purchase_note',
		'促销价格'                              => 'sale_price',
		'常规售价'                           => 'regular_price',
		'Categories'                              => 'category_ids',
		'Tags'                                    => 'tag_ids',
		'运费类'                          => 'shipping_class_id',
		'Images'                                  => 'images',
		'下载限制'                          => 'download_limit',
		'下载的过期天数'                    => 'download_expiry',
		'Parent'                                  => 'parent_id',
		'Upsells'                                 => 'upsell_ids',
		'Cross-sells'                             => 'cross_sell_ids',
		'分组产品'                        => 'grouped_products',
		'外部链接'                            => 'product_url',
		'按钮文本'                             => 'button_text',
		'Position'                                => 'menu_order',
	);

	return array_merge( $mappings, $new_mappings );
}
add_filter( 'woocommerce_csv_product_import_mapping_default_columns', 'wc_importer_default_english_mappings', 100 );

/**
 * Add English special mapping placeholders when not using English as current language.
 *
 * @since 3.1.0
 * @param array $mappings Importer columns mappings.
 * @return array
 */
function wc_importer_default_special_english_mappings( $mappings ) {
	if ( 'en_US' === wc_importer_current_locale() ) {
		return $mappings;
	}

	$new_mappings = array(
		'属性 %d 名称'     => 'attributes:name',
		'属性 %d 值' => 'attributes:value',
		'属性 %d 可见'  => 'attributes:visible',
		'属性 %d  的全局'   => 'attributes:taxonomy',
		'属性 %d  的默认值'  => 'attributes:default',
		'下载 %d ID'        => 'downloads:id',
		'下载 %d 的名称'      => 'downloads:name',
		'下载 %d 的链接'       => 'downloads:url',
		'元数据：%s'              => 'meta:',
	);

	return array_merge( $mappings, $new_mappings );
}
add_filter( 'woocommerce_csv_product_import_mapping_special_columns', 'wc_importer_default_special_english_mappings', 100 );
