<?php
/**
 * Product data variations
 *
 * @package WooCommerce\Admin\Metaboxes\Views
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}
?>
<div id="variable_product_options" class="panel wc-metaboxes-wrapper hidden">
	<div id="variable_product_options_inner">

		<?php if ( ! count( $variation_attributes ) ) : ?>

			<div id="message" class="inline notice woocommerce-message">
				<p><?php echo gc_kses_post( __( '在您可以添加一个变量之前您需要在<strong>属性</strong> 选项卡添加一些变量属性。', 'woocommerce' ) ); ?></p>
				<p><a class="button-primary" href="<?php echo esc_url( apply_filters( 'woocommerce_docs_url', 'https://docs.woocommerce.com/document/variable-product/', 'product-variations' ) ); ?>" target="_blank"><?php esc_html_e( '了解更多', 'woocommerce' ); ?></a></p>
			</div>

		<?php else : ?>

			<div class="toolbar toolbar-variations-defaults">
				<div class="variations-defaults">
					<strong><?php esc_html_e( '默认的表单值', 'woocommerce' ); ?>: <?php echo wc_help_tip( __( '这些是将会在前端被预选定的属性。', 'woocommerce' ) ); ?></strong>
					<?php
					foreach ( $variation_attributes as $attribute ) {
						$selected_value = isset( $default_attributes[ sanitize_title( $attribute->get_name() ) ] ) ? $default_attributes[ sanitize_title( $attribute->get_name() ) ] : '';
						?>
						<select name="default_attribute_<?php echo esc_attr( sanitize_title( $attribute->get_name() ) ); ?>" data-current="<?php echo esc_attr( $selected_value ); ?>">
							<?php /* translators: WooCommerce attribute label */ ?>
							<option value=""><?php echo esc_html( sprintf( __( '无默认%s&hellip;', 'woocommerce' ), wc_attribute_label( $attribute->get_name() ) ) ); ?></option>
							<?php if ( $attribute->is_taxonomy() ) : ?>
								<?php foreach ( $attribute->get_terms() as $option ) : ?>
									<option <?php selected( $selected_value, $option->slug ); ?> value="<?php echo esc_attr( $option->slug ); ?>"><?php echo esc_html( apply_filters( 'woocommerce_variation_option_name', $option->name, $option, $attribute->get_name(), $product_object ) ); ?></option>
								<?php endforeach; ?>
							<?php else : ?>
								<?php foreach ( $attribute->get_options() as $option ) : ?>
									<option <?php selected( $selected_value, $option ); ?> value="<?php echo esc_attr( $option ); ?>"><?php echo esc_html( apply_filters( 'woocommerce_variation_option_name', $option, null, $attribute->get_name(), $product_object ) ); ?></option>
								<?php endforeach; ?>
							<?php endif; ?>
						</select>
						<?php
					}
					?>
				</div>
				<div class="clear"></div>
			</div>

			<?php do_action( 'woocommerce_variable_product_before_variations' ); ?>

			<div class="toolbar toolbar-top">
				<select id="field_to_edit" class="variation_actions">
					<option data-global="true" value="add_variation"><?php esc_html_e( '添加变量', 'woocommerce' ); ?></option>
					<option data-global="true" value="link_all_variations"><?php esc_html_e( '为全部属性创建变量', 'woocommerce' ); ?></option>
					<option value="delete_all"><?php esc_html_e( '链接所有变更', 'woocommerce' ); ?></option>
					<optgroup label="<?php esc_attr_e( '状态', 'woocommerce' ); ?>">
						<option value="toggle_enabled"><?php esc_html_e( '切换绝对定位状态', 'woocommerce' ); ?></option>
						<option value="toggle_downloadable"><?php esc_html_e( '电子邮件地址：', 'woocommerce' ); ?></option>
						<option value="toggle_virtual"><?php esc_html_e( '切换绝对定位状态', 'woocommerce' ); ?></option>
					</optgroup>
					<optgroup label="<?php esc_attr_e( '价格', 'woocommerce' ); ?>">
						<option value="variable_regular_price"><?php esc_html_e( '设置常规价格', 'woocommerce' ); ?></option>
						<option value="variable_regular_price_increase"><?php esc_html_e( '提高常规价格(固定金额或者百分比)', 'woocommerce' ); ?></option>
						<option value="variable_regular_price_decrease"><?php esc_html_e( '降低常规价格(固定金额或者百分比)', 'woocommerce' ); ?></option>
						<option value="variable_sale_price"><?php esc_html_e( '设置促销价格', 'woocommerce' ); ?></option>
						<option value="variable_sale_price_increase"><?php esc_html_e( '提高促销价格(固定金额或百分比)', 'woocommerce' ); ?></option>
						<option value="variable_sale_price_decrease"><?php esc_html_e( '降低促销价格(固定金额或百分比)', 'woocommerce' ); ?></option>
						<option value="variable_sale_schedule"><?php esc_html_e( '设置促销计划', 'woocommerce' ); ?></option>
					</optgroup>
					<optgroup label="<?php esc_attr_e( '库存', 'woocommerce' ); ?>">
						<option value="toggle_manage_stock"><?php esc_html_e( '切换 &quot;管理库存&quot;', 'woocommerce' ); ?></option>
						<option value="variable_stock"><?php esc_html_e( '库存', 'woocommerce' ); ?></option>
						<option value="variable_stock_status_instock"><?php esc_html_e( '设置状态 - 现货', 'woocommerce' ); ?></option>
						<option value="variable_stock_status_outofstock"><?php esc_html_e( '设置状态 - 售罄', 'woocommerce' ); ?></option>
						<option value="variable_stock_status_onbackorder"><?php esc_html_e( '设置状态 - 在延迟交货', 'woocommerce' ); ?></option>
						<option value="variable_low_stock_amount"><?php esc_html_e( '库存不足的最低值', 'woocommerce' ); ?></option>
					</optgroup>
					<optgroup label="<?php esc_attr_e( '配送', 'woocommerce' ); ?>">
						<option value="variable_length"><?php esc_html_e( '长度', 'woocommerce' ); ?></option>
						<option value="variable_width"><?php esc_html_e( '宽度', 'woocommerce' ); ?></option>
						<option value="variable_height"><?php esc_html_e( '高度', 'woocommerce' ); ?></option>
						<option value="variable_weight"><?php esc_html_e( '重量', 'woocommerce' ); ?></option>
					</optgroup>
					<optgroup label="<?php esc_attr_e( '可下载产品', 'woocommerce' ); ?>">
						<option value="variable_download_limit"><?php esc_html_e( '下载限制', 'woocommerce' ); ?></option>
						<option value="variable_download_expiry"><?php esc_html_e( '下载到期', 'woocommerce' ); ?></option>
					</optgroup>
					<?php do_action( 'woocommerce_variable_product_bulk_edit_actions' ); ?>
				</select>
				<a class="button bulk_edit do_variation_action"><?php esc_html_e( '确定', 'woocommerce' ); ?></a>

				<div class="variations-pagenav">
					<?php /* translators: variations count */ ?>
					<span class="displaying-num"><?php echo esc_html( sprintf( _n( '%s 项目', '%s 件物品', $variations_count, 'woocommerce' ), $variations_count ) ); ?></span>
					<span class="expand-close">
						(<a href="#" class="expand_all"><?php esc_html_e( '展开', 'woocommerce' ); ?></a> / <a href="#" class="close_all"><?php esc_html_e( '关闭', 'woocommerce' ); ?></a>)
					</span>
					<span class="pagination-links">
						<a class="first-page disabled" title="<?php esc_attr_e( '到第一页', 'woocommerce' ); ?>" href="#">&laquo;</a>
						<a class="prev-page disabled" title="<?php esc_attr_e( '到上一页', 'woocommerce' ); ?>" href="#">&lsaquo;</a>
						<span class="paging-select">
							<label for="current-page-selector-1" class="screen-reader-text"><?php esc_html_e( '选择页面', 'woocommerce' ); ?></label>
							<select class="page-selector" id="current-page-selector-1" title="<?php esc_attr_e( '当前页', 'woocommerce' ); ?>">
								<?php for ( $i = 1; $i <= $variations_total_pages; $i++ ) : ?>
									<option value="<?php echo $i; // GCCS: XSS ok. ?>"><?php echo $i; // GCCS: XSS ok. ?></option>
								<?php endfor; ?>
							</select>
							<?php echo esc_html_x( '/', 'number of pages', 'woocommerce' ); ?> <span class="total-pages"><?php echo esc_html( $variations_total_pages ); ?></span>
						</span>
						<a class="next-page" title="<?php esc_attr_e( '到下一页', 'woocommerce' ); ?>" href="#">&rsaquo;</a>
						<a class="last-page" title="<?php esc_attr_e( '到末页', 'woocommerce' ); ?>" href="#">&raquo;</a>
					</span>
				</div>
				<div class="clear"></div>
			</div>

			<div class="woocommerce_variations wc-metaboxes" data-attributes="<?php echo wc_esc_json( gc_json_encode( wc_list_pluck( $variation_attributes, 'get_data' ) ) ); // GCCS: XSS ok. ?>" data-total="<?php echo esc_attr( $variations_count ); ?>" data-total_pages="<?php echo esc_attr( $variations_total_pages ); ?>" data-page="1" data-edited="false"></div>

			<div class="toolbar">
				<button type="button" class="button-primary save-variation-changes" disabled="disabled"><?php esc_html_e( '保存更改', 'woocommerce' ); ?></button>
				<button type="button" class="button cancel-variation-changes" disabled="disabled"><?php esc_html_e( '取消', 'woocommerce' ); ?></button>

				<div class="variations-pagenav">
					<?php /* translators: variations count*/ ?>
					<span class="displaying-num"><?php echo esc_html( sprintf( _n( '%s 项目', '%s 件物品', $variations_count, 'woocommerce' ), $variations_count ) ); ?></span>
					<span class="expand-close">
						(<a href="#" class="expand_all"><?php esc_html_e( '展开', 'woocommerce' ); ?></a> / <a href="#" class="close_all"><?php esc_html_e( '关闭', 'woocommerce' ); ?></a>)
					</span>
					<span class="pagination-links">
						<a class="first-page disabled" title="<?php esc_attr_e( '到第一页', 'woocommerce' ); ?>" href="#">&laquo;</a>
						<a class="prev-page disabled" title="<?php esc_attr_e( '到上一页', 'woocommerce' ); ?>" href="#">&lsaquo;</a>
						<span class="paging-select">
							<label for="current-page-selector-1" class="screen-reader-text"><?php esc_html_e( '选择页面', 'woocommerce' ); ?></label>
							<select class="page-selector" id="current-page-selector-1" title="<?php esc_attr_e( '当前页', 'woocommerce' ); ?>">
								<?php for ( $i = 1; $i <= $variations_total_pages; $i++ ) : ?>
									<option value="<?php echo $i; // GCCS: XSS ok. ?>"><?php echo $i; // GCCS: XSS ok. ?></option>
								<?php endfor; ?>
							</select>
							<?php echo esc_html_x( '/', 'number of pages', 'woocommerce' ); ?> <span class="total-pages"><?php echo esc_html( $variations_total_pages ); ?></span>
						</span>
						<a class="next-page" title="<?php esc_attr_e( '到下一页', 'woocommerce' ); ?>" href="#">&rsaquo;</a>
						<a class="last-page" title="<?php esc_attr_e( '到末页', 'woocommerce' ); ?>" href="#">&raquo;</a>
					</span>
				</div>
				<div class="clear"></div>
			</div>

		<?php endif; ?>
	</div>
</div>
