<?php
/**
 * WooCommerce General Settings
 *
 * @package WooCommerce\Admin
 */

defined( 'ABSPATH' ) || exit;

if ( class_exists( 'WC_Settings_General', false ) ) {
	return new WC_Settings_General();
}

/**
 * WC_Admin_Settings_General.
 */
class WC_Settings_General extends WC_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'general';
		$this->label = __( '常规', 'woocommerce' );

		parent::__construct();
	}

	/**
	 * Get settings or the default section.
	 *
	 * @return array
	 */
	protected function get_settings_for_default_section() {

		$currency_code_options = get_woocommerce_currencies();

		foreach ( $currency_code_options as $code => $name ) {
			$currency_code_options[ $code ] = $name . ' (' . get_woocommerce_currency_symbol( $code ) . ')';
		}

		$settings =
			array(

				array(
					'title' => __( '商店地址', 'woocommerce' ),
					'type'  => 'title',
					'desc'  => __( '适用于税率和运费将的业务所在地地址。', 'woocommerce' ),
					'id'    => 'store_address',
				),

				array(
					'title'    => __( '地址行1', 'woocommerce' ),
					'desc'     => __( '您业务所在地的街道地址。', 'woocommerce' ),
					'id'       => 'woocommerce_store_address',
					'default'  => '',
					'type'     => 'text',
					'desc_tip' => true,
				),

				array(
					'title'    => __( '地址行2', 'woocommerce' ),
					'desc'     => __( '您的商家位置附加的可选地址行。', 'woocommerce' ),
					'id'       => 'woocommerce_store_address_2',
					'default'  => '',
					'type'     => 'text',
					'desc_tip' => true,
				),

				array(
					'title'    => __( '城市', 'woocommerce' ),
					'desc'     => __( '您所在的城市。', 'woocommerce' ),
					'id'       => 'woocommerce_store_city',
					'default'  => '',
					'type'     => 'text',
					'desc_tip' => true,
				),

				array(
					'title'    => __( '国家/地区', 'woocommerce' ),
					'desc'     => __( '您业务所在地的国家/地区和省级区域，如果有的话。', 'woocommerce' ),
					'id'       => 'woocommerce_default_country',
					'default'  => 'US:CA',
					'type'     => 'single_select_country',
					'desc_tip' => true,
				),

				array(
					'title'    => __( '邮政编码', 'woocommerce' ),
					'desc'     => __( '您业务所在地的邮政编码（如果有的话）', 'woocommerce' ),
					'id'       => 'woocommerce_store_postcode',
					'css'      => 'min-width:50px;',
					'default'  => '',
					'type'     => 'text',
					'desc_tip' => true,
				),

				array(
					'type' => 'sectionend',
					'id'   => 'store_address',
				),

				array(
					'title' => __( '综合选项', 'woocommerce' ),
					'type'  => 'title',
					'desc'  => '',
					'id'    => 'general_options',
				),

				array(
					'title'    => __( '销售位置', 'woocommerce' ),
					'desc'     => __( '此选项让您可以限制您想出售物品到哪些国家/地区。', 'woocommerce' ),
					'id'       => 'woocommerce_allowed_countries',
					'default'  => 'all',
					'type'     => 'select',
					'class'    => 'wc-enhanced-select',
					'css'      => 'min-width: 350px;',
					'desc_tip' => true,
					'options'  => array(
						'all'        => __( '销售到全部国家/地区', 'woocommerce' ),
						'all_except' => __( '销售到全部国家/地区，除了&hellip;', 'woocommerce' ),
						'specific'   => __( '销售到特定的国家/地区', 'woocommerce' ),
					),
				),

				array(
					'title'   => __( '销售到全部国家/地区，除了&hellip;', 'woocommerce' ),
					'desc'    => '',
					'id'      => 'woocommerce_all_except_countries',
					'css'     => 'min-width: 350px;',
					'default' => '',
					'type'    => 'multi_select_countries',
				),

				array(
					'title'   => __( '销售到特定的国家/地区', 'woocommerce' ),
					'desc'    => '',
					'id'      => 'woocommerce_specific_allowed_countries',
					'css'     => 'min-width: 350px;',
					'default' => '',
					'type'    => 'multi_select_countries',
				),

				array(
					'title'    => __( '可配送的区域', 'woocommerce' ),
					'desc'     => __( '选择您可以配送的国家/地区，或者选择可配送到全部销售区域。', 'woocommerce' ),
					'id'       => 'woocommerce_ship_to_countries',
					'default'  => '',
					'type'     => 'select',
					'class'    => 'wc-enhanced-select',
					'desc_tip' => true,
					'options'  => array(
						''         => __( '配送到所有您销售地区', 'woocommerce' ),
						'all'      => __( '配送到全部国家/地区', 'woocommerce' ),
						'specific' => __( '只配送到特定的国家/地区', 'woocommerce' ),
						'disabled' => __( '禁用 配送  &amp; 运费计算功能', 'woocommerce' ),
					),
				),

				array(
					'title'   => __( '配送到特定的国家/地区', 'woocommerce' ),
					'desc'    => '',
					'id'      => 'woocommerce_specific_ship_to_countries',
					'css'     => '',
					'default' => '',
					'type'    => 'multi_select_countries',
				),

				array(
					'title'    => __( '默认客户位置', 'woocommerce' ),
					'id'       => 'woocommerce_default_customer_address',
					'desc_tip' => __( '此选项确定客户的默认位置。如果使用地理定位，MaxMind GeoLite 数据库将定期下载到您的 gc-content 目录。', 'woocommerce' ),
					'default'  => 'base',
					'type'     => 'select',
					'class'    => 'wc-enhanced-select',
					'options'  => array(
						''                 => __( '无默认位置', 'woocommerce' ),
						'base'             => __( '店铺所在的国家/地区', 'woocommerce' ),
						'geolocation'      => __( '据IP确定位置', 'woocommerce' ),
						'geolocation_ajax' => __( '据IP确定位置(支持页面缓存)', 'woocommerce' ),
					),
				),

				array(
					'title'    => __( '启用“税收”功能', 'woocommerce' ),
					'desc'     => __( '启用税率和计算', 'woocommerce' ),
					'id'       => 'woocommerce_calc_taxes',
					'default'  => 'no',
					'type'     => 'checkbox',
					'desc_tip' => __( '税率可进行配置，并且税款将在结账时计算。', 'woocommerce' ),
				),

				array(
					'title'           => __( '使用优惠券', 'woocommerce' ),
					'desc'            => __( '启用优惠代码的使用', 'woocommerce' ),
					'id'              => 'woocommerce_enable_coupons',
					'default'         => 'yes',
					'type'            => 'checkbox',
					'checkboxgroup'   => 'start',
					'show_if_checked' => 'option',
					'desc_tip'        => __( '可以从购物车和结帐页面应用优惠券。', 'woocommerce' ),
				),

				array(
					'desc'            => __( '顺序计算优惠券折扣', 'woocommerce' ),
					'id'              => 'woocommerce_calc_discounts_sequentially',
					'default'         => 'no',
					'type'            => 'checkbox',
					'desc_tip'        => __( '当应用多个优惠券，应用第一个优惠券的全价和第二优待券的折扣价格等。', 'woocommerce' ),
					'show_if_checked' => 'yes',
					'checkboxgroup'   => 'end',
					'autoload'        => false,
				),

				array(
					'type' => 'sectionend',
					'id'   => 'general_options',
				),

				array(
					'title' => __( '币种选项', 'woocommerce' ),
					'type'  => 'title',
					'desc'  => __( '下列选项影响价格在前端如何显示。', 'woocommerce' ),
					'id'    => 'pricing_options',
				),

				array(
					'title'    => __( '货币', 'woocommerce' ),
					'desc'     => __( '控制在类别中的货币价格列出的将支付的货币网关。', 'woocommerce' ),
					'id'       => 'woocommerce_currency',
					'default'  => 'USD',
					'type'     => 'select',
					'class'    => 'wc-enhanced-select',
					'desc_tip' => true,
					'options'  => $currency_code_options,
				),

				array(
					'title'    => __( '币种的位置', 'woocommerce' ),
					'desc'     => __( '这控制货币符号的位置。', 'woocommerce' ),
					'id'       => 'woocommerce_currency_pos',
					'class'    => 'wc-enhanced-select',
					'default'  => 'left',
					'type'     => 'select',
					'options'  => array(
						'left'        => __( '左', 'woocommerce' ),
						'right'       => __( '右', 'woocommerce' ),
						'left_space'  => __( '左侧留空', 'woocommerce' ),
						'right_space' => __( '右侧留空', 'woocommerce' ),
					),
					'desc_tip' => true,
				),

				array(
					'title'    => __( '千位分隔符', 'woocommerce' ),
					'desc'     => __( '这设置显示为千位分隔符的价格。', 'woocommerce' ),
					'id'       => 'woocommerce_price_thousand_sep',
					'css'      => 'width:50px;',
					'default'  => ',',
					'type'     => 'text',
					'desc_tip' => true,
				),

				array(
					'title'    => __( '小数分隔符', 'woocommerce' ),
					'desc'     => __( '这设置显示小数点分隔符的价格。', 'woocommerce' ),
					'id'       => 'woocommerce_price_decimal_sep',
					'css'      => 'width:50px;',
					'default'  => '.',
					'type'     => 'text',
					'desc_tip' => true,
				),

				array(
					'title'             => __( '小数点后的位数', 'woocommerce' ),
					'desc'              => __( '这设置显示价格中的小数点的位数。', 'woocommerce' ),
					'id'                => 'woocommerce_price_num_decimals',
					'css'               => 'width:50px;',
					'default'           => '2',
					'desc_tip'          => true,
					'type'              => 'number',
					'custom_attributes' => array(
						'min'  => 0,
						'step' => 1,
					),
				),

				array(
					'type' => 'sectionend',
					'id'   => 'pricing_options',
				),
			);

		return apply_filters( 'woocommerce_general_settings', $settings );
	}

	/**
	 * Output a color picker input box.
	 *
	 * @param mixed  $name Name of input.
	 * @param string $id ID of input.
	 * @param mixed  $value Value of input.
	 * @param string $desc (default: '') Description for input.
	 */
	public function color_picker( $name, $id, $value, $desc = '' ) {
		echo '<div class="color_box">' . wc_help_tip( $desc ) . '
			<input name="' . esc_attr( $id ) . '" id="' . esc_attr( $id ) . '" type="text" value="' . esc_attr( $value ) . '" class="colorpick" /> <div id="colorPickerDiv_' . esc_attr( $id ) . '" class="colorpickdiv"></div>
		</div>';
	}
}

return new WC_Settings_General();
