<?php
/**
 * Tax settings.
 *
 * @package WooCommerce\Admin\Settings.
 */

defined( 'ABSPATH' ) || exit;

$settings = array(

	array(
		'title' => __( '税相关的选项', 'woocommerce' ),
		'type'  => 'title',
		'desc'  => '',
		'id'    => 'tax_options',
	),

	array(
		'title'    => __( '输入的价格含税', 'woocommerce' ),
		'id'       => 'woocommerce_prices_include_tax',
		'default'  => 'no',
		'type'     => 'radio',
		'desc_tip' => __( '这个选项很重要，因为它会影响到您如何输入价格，修改此项不会更新已有产品的价格。', 'woocommerce' ),
		'options'  => array(
			'yes' => __( '是的，我要输入含税产品价格', 'woocommerce' ),
			'no'  => __( '不，我要输入不含税的产品价格', 'woocommerce' ),
		),
	),

	array(
		'title'    => __( '计算税费基于', 'woocommerce' ),
		'id'       => 'woocommerce_tax_based_on',
		'desc_tip' => __( '此选项决定使用哪个地址来计税。', 'woocommerce' ),
		'default'  => 'shipping',
		'type'     => 'select',
		'class'    => 'wc-enhanced-select',
		'options'  => array(
			'shipping' => __( '客户配送地址', 'woocommerce' ),
			'billing'  => __( '客户账单地址', 'woocommerce' ),
			'base'     => __( '商店基本地址', 'woocommerce' ),
		),
	),

	'shipping-tax-class' => array(
		'title'    => __( '配送税类型', 'woocommerce' ),
		'desc'     => __( '可选的配送税类型设置，或者留空以购物车内的物品计算配送税。', 'woocommerce' ),
		'id'       => 'woocommerce_shipping_tax_class',
		'css'      => 'min-width:150px;',
		'default'  => 'inherit',
		'type'     => 'select',
		'class'    => 'wc-enhanced-select',
		'options'  => array( 'inherit' => __( '配送税类型基于购物车的物品', 'woocommerce' ) ) + wc_get_product_tax_class_options(),
		'desc_tip' => true,
	),

	array(
		'title'   => __( '四舍五入', 'woocommerce' ),
		'desc'    => __( '在小计税的时候四舍五入,而不是每行都四舍五入', 'woocommerce' ),
		'id'      => 'woocommerce_tax_round_at_subtotal',
		'default' => 'no',
		'type'    => 'checkbox',
	),

	array(
		'title'     => __( '附加税类', 'woocommerce' ),
		'desc_tip'  => __( '在下面列出您需要的额外税种（每行 1 种，例如“减税税率”）。这些是除默认存在的“标准税率”外的税种。', 'woocommerce' ),
		'id'        => 'woocommerce_tax_classes',
		'css'       => 'height: 65px;',
		'type'      => 'textarea',
		'default'   => '',
		'is_option' => false,
		'value'     => implode( "\n", WC_Tax::get_tax_classes() ),
	),

	array(
		'title'   => __( '在商店显示价格', 'woocommerce' ),
		'id'      => 'woocommerce_tax_display_shop',
		'default' => 'excl',
		'type'    => 'select',
		'class'   => 'wc-enhanced-select',
		'options' => array(
			'incl' => __( '含税', 'woocommerce' ),
			'excl' => __( '不含税', 'woocommerce' ),
		),
	),

	array(
		'title'   => __( '在购物和结帐期间显示价格', 'woocommerce' ),
		'id'      => 'woocommerce_tax_display_cart',
		'default' => 'excl',
		'type'    => 'select',
		'class'   => 'wc-enhanced-select',
		'options' => array(
			'incl' => __( '含税', 'woocommerce' ),
			'excl' => __( '不含税', 'woocommerce' ),
		),
	),

	array(
		'title'       => __( '价格显示前缀', 'woocommerce' ),
		'id'          => 'woocommerce_price_display_suffix',
		'default'     => '',
		'placeholder' => __( 'N/A', 'woocommerce' ),
		'type'        => 'text',
		'desc_tip'    => __( '定义您的产品价格后显示的文本。这可能是，例如，“INC增值税”来解释您的定价。您也可以使用下列之一来取代这里的价格：{price_including_tax}，{} price_excluding_tax。', 'woocommerce' ),
	),

	array(
		'title'    => __( '显示税费总计', 'woocommerce' ),
		'id'       => 'woocommerce_tax_total_display',
		'default'  => 'itemized',
		'type'     => 'select',
		'class'    => 'wc-enhanced-select',
		'options'  => array(
			'single'   => __( '作为一个单独的小计', 'woocommerce' ),
			'itemized' => __( '分项', 'woocommerce' ),
		),
		'autoload' => false,
	),

	array(
		'type' => 'sectionend',
		'id'   => 'tax_options',
	),

);

if ( ! wc_shipping_enabled() ) {
	unset( $settings['shipping-tax-class'] );
}

return apply_filters( 'woocommerce_tax_settings', $settings );
