<?php
/**
 * Settings for PayPal Standard Gateway.
 *
 * @package WooCommerce\Classes\Payment
 */

defined( 'ABSPATH' ) || exit;

return array(
	'enabled'               => array(
		'title'   => __( '启用/禁用', 'woocommerce' ),
		'type'    => 'checkbox',
		'label'   => __( '启用 PayPal 标准版', 'woocommerce' ),
		'default' => 'no',
	),
	'title'                 => array(
		'title'       => __( '标题', 'woocommerce' ),
		'type'        => 'safe_text',
		'description' => __( '这控制用户在结帐时看到的标题。', 'woocommerce' ),
		'default'     => __( 'PayPal', 'woocommerce' ),
		'desc_tip'    => true,
	),
	'description'           => array(
		'title'       => __( '描述', 'woocommerce' ),
		'type'        => 'text',
		'desc_tip'    => true,
		'description' => __( '控制用户在结帐时看到的描述。', 'woocommerce' ),
		'default'     => __( "通过PayPal支付；如果您没有PayPal账户，您也可以使用您的信用卡进行支付。", 'woocommerce' ),
	),
	'email'                 => array(
		'title'       => __( 'PayPal  Email', 'woocommerce' ),
		'type'        => 'email',
		'description' => __( '请输入您的PayPal账户email 地址；这是为订单付款所必须的。', 'woocommerce' ),
		'default'     => get_option( 'admin_email' ),
		'desc_tip'    => true,
		'placeholder' => 'you@youremail.com',
	),
	'advanced'              => array(
		'title'       => __( '高级选项', 'woocommerce' ),
		'type'        => 'title',
		'description' => '',
	),
	'testmode'              => array(
		'title'       => __( 'PayPal 沙盒', 'woocommerce' ),
		'type'        => 'checkbox',
		'label'       => __( '启用 PayPal 沙盒', 'woocommerce' ),
		'default'     => 'no',
		/* translators: %s: URL */
		'description' => sprintf( __( 'PayPal 沙箱可用于测试支付，注册个<a href=\"%s\">开发者账户</a>吧.', 'woocommerce' ), 'https://developer.paypal.com/' ),
	),
	'debug'                 => array(
		'title'       => __( '调试日志', 'woocommerce' ),
		'type'        => 'checkbox',
		'label'       => __( '启用日志记录', 'woocommerce' ),
		'default'     => 'no',
		/* translators: %s: URL */
		'description' => sprintf( __( '记录 PayPal 事件，如 IPN 请求，在 %s 内。注意：这可能会记录个人信息。我们建议此操作仅用于调试，并在完成后删除日志。', 'woocommerce' ), '<code>' . WC_Log_Handler_File::get_log_file_path( 'paypal' ) . '</code>' ),
	),
	'ipn_notification'      => array(
		'title'       => __( 'IPN 电子邮件通知', 'woocommerce' ),
		'type'        => 'checkbox',
		'label'       => __( '启用IPN电邮通知', 'woocommerce' ),
		'default'     => 'yes',
		'description' => __( '当收到PayPal 的退款、退款和取消IPN时，发送通知。', 'woocommerce' ),
	),
	'receiver_email'        => array(
		'title'       => __( '收件人电邮', 'woocommerce' ),
		'type'        => 'email',
		'description' => __( '如果您的主要PayPal电子邮件与上面输入的PayPal电子邮件不同，请在此处输入您的PayPal帐户的主要收件人电子邮件。 这用于验证IPN请求。', 'woocommerce' ),
		'default'     => '',
		'desc_tip'    => true,
		'placeholder' => 'you@youremail.com',
	),
	'identity_token'        => array(
		'title'       => __( 'PayPal 身份识别 Token', 'woocommerce' ),
		'type'        => 'text',
		'description' => __( '可以选择启用 \"Payment Data Transfer\"(配置文件 > 网站付款首选项)，然后将复制您的身份令牌在这里。这将允许的款项，而无需 PayPal IPN 验证。', 'woocommerce' ),
		'default'     => '',
		'desc_tip'    => true,
		'placeholder' => '',
	),
	'invoice_prefix'        => array(
		'title'       => __( '收据的前缀', 'woocommerce' ),
		'type'        => 'text',
		'description' => __( '请输入您的帐单前缀。如果您使用PayPal帐户为多个商店，确保这前缀是unqiue的，因为PayPal将不会允许相同的编号的订单前缀。', 'woocommerce' ),
		'default'     => 'WC-',
		'desc_tip'    => true,
	),
	'send_shipping'         => array(
		'title'       => __( '配送详情', 'woocommerce' ),
		'type'        => 'checkbox',
		'label'       => __( '发送配送详情到PayPal而不是账单。', 'woocommerce' ),
		'description' => __( '使用 PayPal，我们会发送一个地址。如果您使用 PayPal 支付配送标签费用，则您可能希望发送收货地址而不是帐单地址。关闭此选项可能将无法享受 PayPal Seller 保护。', 'woocommerce' ),
		'default'     => 'yes',
	),
	'address_override'      => array(
		'title'       => __( '地址覆盖', 'woocommerce' ),
		'type'        => 'checkbox',
		'label'       => __( '启用\"address_override\"以防止被更改的地址信息。', 'woocommerce' ),
		'description' => __( 'PayPal验证地址，此设置可能会导致错误（我们建议保持禁用它）。', 'woocommerce' ),
		'default'     => 'no',
	),
	'paymentaction'         => array(
		'title'       => __( '支付操作', 'woocommerce' ),
		'type'        => 'select',
		'class'       => 'wc-enhanced-select',
		'description' => __( '选择您是要马上扣款还是先预授权', 'woocommerce' ),
		'default'     => 'sale',
		'desc_tip'    => true,
		'options'     => array(
			'sale'          => __( '扣款', 'woocommerce' ),
			'authorization' => __( '授权', 'woocommerce' ),
		),
	),
	'image_url'             => array(
		'title'       => __( '图片链接', 'woocommerce' ),
		'type'        => 'text',
		'description' => __( '您可以输入一个 150x50px 的图片 URL，作为 Logo 显示在 PayPal 结账页面的左上角。', 'woocommerce' ),
		'default'     => '',
		'desc_tip'    => true,
		'placeholder' => __( '公司（可选）', 'woocommerce' ),
	),
	'api_details'           => array(
		'title'       => __( 'API凭证', 'woocommerce' ),
		'type'        => 'title',
		/* translators: %s: URL */
		'description' => sprintf( __( '输入您的 PayPal API 凭证以通过 PayPal 处理退款。 了解如何访问您的<a href=\"%s\"> PayPal API 凭证</a>。', 'woocommerce' ), 'https://developer.paypal.com/webapps/developer/docs/classic/api/apiCredentials/#create-an-api-signature' ),
	),
	'api_username'          => array(
		'title'       => __( '在线API用户名', 'woocommerce' ),
		'type'        => 'text',
		'description' => __( '获得来自PayPal的API证书。', 'woocommerce' ),
		'default'     => '',
		'desc_tip'    => true,
		'placeholder' => __( '公司（可选）', 'woocommerce' ),
	),
	'api_password'          => array(
		'title'       => __( '在线API密码', 'woocommerce' ),
		'type'        => 'password',
		'description' => __( '获得来自PayPal的API证书。', 'woocommerce' ),
		'default'     => '',
		'desc_tip'    => true,
		'placeholder' => __( '公司（可选）', 'woocommerce' ),
	),
	'api_signature'         => array(
		'title'       => __( '在线API签名', 'woocommerce' ),
		'type'        => 'password',
		'description' => __( '获得来自PayPal的API证书。', 'woocommerce' ),
		'default'     => '',
		'desc_tip'    => true,
		'placeholder' => __( '公司（可选）', 'woocommerce' ),
	),
	'sandbox_api_username'  => array(
		'title'       => __( '沙箱API用户名', 'woocommerce' ),
		'type'        => 'text',
		'description' => __( '获得来自PayPal的API证书。', 'woocommerce' ),
		'default'     => '',
		'desc_tip'    => true,
		'placeholder' => __( '公司（可选）', 'woocommerce' ),
	),
	'sandbox_api_password'  => array(
		'title'       => __( '沙箱API密码', 'woocommerce' ),
		'type'        => 'password',
		'description' => __( '获得来自PayPal的API证书。', 'woocommerce' ),
		'default'     => '',
		'desc_tip'    => true,
		'placeholder' => __( '公司（可选）', 'woocommerce' ),
	),
	'sandbox_api_signature' => array(
		'title'       => __( '沙箱API签名', 'woocommerce' ),
		'type'        => 'password',
		'description' => __( '获得来自PayPal的API证书。', 'woocommerce' ),
		'default'     => '',
		'desc_tip'    => true,
		'placeholder' => __( '公司（可选）', 'woocommerce' ),
	),
);
