<?php
/**
 * Settings for flat rate shipping.
 *
 * @package WooCommerce\Classes\Shipping
 */

defined( 'ABSPATH' ) || exit;

$cost_desc = __( '请输入一个成本(不含税)或总和，例如 <code>10.00 * [qty]</code>。', 'woocommerce' ) . '<br/><br/>' . __( '使用 <code>[qty]</code> 表示物品的数量，<br/><code>[cost]</code> 表示物品的总额，<code>[fee percent=\"10\" min_fee=\"20\" max_fee=\"\"]</code>表示基于百分比的费用。', 'woocommerce' );

$settings = array(
	'title'      => array(
		'title'       => __( '方法名称', 'woocommerce' ),
		'type'        => 'text',
		'description' => __( '这控制用户在结帐时看到的标题。', 'woocommerce' ),
		'default'     => __( '统一费率', 'woocommerce' ),
		'desc_tip'    => true,
	),
	'tax_status' => array(
		'title'   => __( '税状态', 'woocommerce' ),
		'type'    => 'select',
		'class'   => 'wc-enhanced-select',
		'default' => 'taxable',
		'options' => array(
			'taxable' => __( '应纳税', 'woocommerce' ),
			'none'    => _x( '无', '税状态', 'woocommerce' ),
		),
	),
	'cost'       => array(
		'title'             => __( '成本', 'woocommerce' ),
		'type'              => 'text',
		'placeholder'       => '',
		'description'       => $cost_desc,
		'default'           => '0',
		'desc_tip'          => true,
		'sanitize_callback' => array( $this, 'sanitize_cost' ),
	),
);

$shipping_classes = WC()->shipping()->get_shipping_classes();

if ( ! empty( $shipping_classes ) ) {
	$settings['class_costs'] = array(
		'title'       => __( '配送类型的费用', 'woocommerce' ),
		'type'        => 'title',
		'default'     => '',
		/* translators: %s: URL for link. */
		'description' => sprintf( __( '这些成本可选地可添加到<a href=\"%s\">产品物流费用类</a>。', 'woocommerce' ), admin_url( 'admin.php?page=wc-settings&tab=shipping&section=classes' ) ),
	);
	foreach ( $shipping_classes as $shipping_class ) {
		if ( ! isset( $shipping_class->term_id ) ) {
			continue;
		}
		$settings[ 'class_cost_' . $shipping_class->term_id ] = array(
			/* translators: %s: shipping class name */
			'title'             => sprintf( __( '\"%s\" 配送类型收费', 'woocommerce' ), esc_html( $shipping_class->name ) ),
			'type'              => 'text',
			'placeholder'       => __( 'N/A', 'woocommerce' ),
			'description'       => $cost_desc,
			'default'           => $this->get_option( 'class_cost_' . $shipping_class->slug ), // Before 2.5.0, we used slug here which caused issues with long setting names.
			'desc_tip'          => true,
			'sanitize_callback' => array( $this, 'sanitize_cost' ),
		);
	}

	$settings['no_class_cost'] = array(
		'title'             => __( '无需配送类型的费用', 'woocommerce' ),
		'type'              => 'text',
		'placeholder'       => __( 'N/A', 'woocommerce' ),
		'description'       => $cost_desc,
		'default'           => '',
		'desc_tip'          => true,
		'sanitize_callback' => array( $this, 'sanitize_cost' ),
	);

	$settings['type'] = array(
		'title'   => __( '计算方式', 'woocommerce' ),
		'type'    => 'select',
		'class'   => 'wc-enhanced-select',
		'default' => 'class',
		'options' => array(
			'class' => __( '每个配送类型：每个配送类型单独收费', 'woocommerce' ),
			'order' => __( '每个订单：按最贵的配送类型进行收费。', 'woocommerce' ),
		),
	);
}

return $settings;
