<?php
/**
 * Legacy flat rate settings.
 *
 * @package WooCommerce\Shipping
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

$cost_desc = __( '请输入一个成本(不含税)或总和，例如 <code>10.00 * [qty]</code>。', 'woocommerce' ) . '<br/>' . __( '支持以下占位符：<code>[qty]</code> = 项目数量，<code>[cost]</code> = 项目成本，<code>[fee percent=\"10\" min_fee=\"20\"]</code> = 基于百分比收费。', 'woocommerce' );

/**
 * Settings for flat rate shipping.
 */
$settings = array(
	'enabled'      => array(
		'title'   => __( '启用/禁用', 'woocommerce' ),
		'type'    => 'checkbox',
		'label'   => __( '一旦停用，此传统方式将不再可用。', 'woocommerce' ),
		'default' => 'no',
	),
	'title'        => array(
		'title'       => __( '方法名称', 'woocommerce' ),
		'type'        => 'text',
		'description' => __( '这控制用户在结帐时看到的标题。', 'woocommerce' ),
		'default'     => __( '统一费率', 'woocommerce' ),
		'desc_tip'    => true,
	),
	'availability' => array(
		'title'   => __( '可用性', 'woocommerce' ),
		'type'    => 'select',
		'default' => 'all',
		'class'   => 'availability wc-enhanced-select',
		'options' => array(
			'all'      => __( '全部允许的国家/地区', 'woocommerce' ),
			'specific' => __( '特定的国家/地区', 'woocommerce' ),
		),
	),
	'countries'    => array(
		'title'             => __( '特定的国家或地区', 'woocommerce' ),
		'type'              => 'multiselect',
		'class'             => 'wc-enhanced-select',
		'css'               => 'width: 400px;',
		'default'           => '',
		'options'           => WC()->countries->get_shipping_countries(),
		'custom_attributes' => array(
			'data-placeholder' => __( '选择国家/地区', 'woocommerce' ),
		),
	),
	'tax_status'   => array(
		'title'   => __( '税状态', 'woocommerce' ),
		'type'    => 'select',
		'class'   => 'wc-enhanced-select',
		'default' => 'taxable',
		'options' => array(
			'taxable' => __( '应纳税', 'woocommerce' ),
			'none'    => _x( '无', '税状态', 'woocommerce' ),
		),
	),
	'cost'         => array(
		'title'       => __( '成本', 'woocommerce' ),
		'type'        => 'text',
		'placeholder' => '',
		'description' => $cost_desc,
		'default'     => '',
		'desc_tip'    => true,
	),
);

$shipping_classes = WC()->shipping()->get_shipping_classes();

if ( ! empty( $shipping_classes ) ) {
	$settings['class_costs'] = array(
		'title'       => __( '配送类型的费用', 'woocommerce' ),
		'type'        => 'title',
		'default'     => '',
		/* translators: %s: Admin shipping settings URL */
		'description' => sprintf( __( '这些成本可选地可添加到<a href=\"%s\">产品物流费用类</a>。', 'woocommerce' ), admin_url( 'admin.php?page=wc-settings&tab=shipping&section=classes' ) ),
	);
	foreach ( $shipping_classes as $shipping_class ) {
		if ( ! isset( $shipping_class->term_id ) ) {
			continue;
		}
		$settings[ 'class_cost_' . $shipping_class->term_id ] = array(
			/* translators: %s: shipping class name */
			'title'       => sprintf( __( '\"%s\" 配送类型收费', 'woocommerce' ), esc_html( $shipping_class->name ) ),
			'type'        => 'text',
			'placeholder' => __( 'N/A', 'woocommerce' ),
			'description' => $cost_desc,
			'default'     => $this->get_option( 'class_cost_' . $shipping_class->slug ), // Before 2.5.0, we used slug here which caused issues with long setting names.
			'desc_tip'    => true,
		);
	}
	$settings['no_class_cost'] = array(
		'title'       => __( '无需配送类型的费用', 'woocommerce' ),
		'type'        => 'text',
		'placeholder' => __( 'N/A', 'woocommerce' ),
		'description' => $cost_desc,
		'default'     => '',
		'desc_tip'    => true,
	);
	$settings['type']          = array(
		'title'   => __( '计算方式', 'woocommerce' ),
		'type'    => 'select',
		'class'   => 'wc-enhanced-select',
		'default' => 'class',
		'options' => array(
			'class' => __( '每个配送类型：每个配送类型单独收费', 'woocommerce' ),
			'order' => __( '每个订单：按最贵的配送类型进行收费。', 'woocommerce' ),
		),
	);
}

if ( apply_filters( 'woocommerce_enable_deprecated_additional_flat_rates', $this->get_option( 'options', false ) ) ) {
	$settings['additional_rates'] = array(
		'title'       => __( '附加的税率', 'woocommerce' ),
		'type'        => 'title',
		'default'     => '',
		'description' => __( '这些比率是额外的物流费用选项（基于统一费率）。', 'woocommerce' ),
	);
	$settings['options']          = array(
		'title'       => __( '附加的税率', 'woocommerce' ),
		'type'        => 'textarea',
		'description' => __( '每行一个：可选名称|附加收费 [+- 百分比]| 每个成本类型(order、class，或者item) 例如：<code>优先配送 | 6.95 [+ 0.2%] | order</code>.', 'woocommerce' ),
		'default'     => '',
		'desc_tip'    => true,
		'placeholder' => __( '选项名称 | 附加费用 [+- 百分比] | 收费  (按订单，类，产品)', 'woocommerce' ),
	);
}

return $settings;
