<?php

/**
 * Class ActionScheduler_AdminView
 * @codeCoverageIgnore
 */
class ActionScheduler_AdminView extends ActionScheduler_AdminView_Deprecated {

	private static $admin_view = NULL;

	private static $screen_id = 'tools_page_action-scheduler';

	/** @var ActionScheduler_ListTable */
	protected $list_table;

	/**
	 * @return ActionScheduler_AdminView
	 * @codeCoverageIgnore
	 */
	public static function instance() {

		if ( empty( self::$admin_view ) ) {
			$class = apply_filters('action_scheduler_admin_view_class', 'ActionScheduler_AdminView');
			self::$admin_view = new $class();
		}

		return self::$admin_view;
	}

	/**
	 * @codeCoverageIgnore
	 */
	public function init() {
		if ( is_admin() && ( ! defined( 'DOING_AJAX' ) || false == DOING_AJAX ) ) {

			if ( class_exists( 'WooCommerce' ) ) {
				add_action( 'woocommerce_admin_status_content_action-scheduler', array( $this, 'render_admin_ui' ) );
				add_action( 'woocommerce_system_status_report', array( $this, 'system_status_report' ) );
				add_filter( 'woocommerce_admin_status_tabs', array( $this, 'register_system_status_tab' ) );
			}

			add_action( 'admin_menu', array( $this, 'register_menu' ) );

			add_action( 'current_screen', array( $this, 'add_help_tabs' ) );
		}
	}

	public function system_status_report() {
		$table = new ActionScheduler_wcSystemStatus( ActionScheduler::store() );
		$table->render();
	}

	/**
	 * Registers action-scheduler into WooCommerce > System status.
	 *
	 * @param array $tabs An associative array of tab key => label.
	 * @return array $tabs An associative array of tab key => label, including Action Scheduler's tabs
	 */
	public function register_system_status_tab( array $tabs ) {
		$tabs['action-scheduler'] = __( '计划动作', 'woocommerce' );

		return $tabs;
	}

	/**
	 * Include Action Scheduler's administration under the Tools menu.
	 *
	 * A menu under the Tools menu is important for backward compatibility (as that's
	 * where it started), and also provides more convenient access than the WooCommerce
	 * System Status page, and for sites where WooCommerce isn't active.
	 */
	public function register_menu() {
		$hook_suffix = add_submenu_page(
			'tools.php',
			__( '计划动作', 'woocommerce' ),
			__( '计划动作', 'woocommerce' ),
			'manage_options',
			'action-scheduler',
			array( $this, 'render_admin_ui' )
		);
		add_action( 'load-' . $hook_suffix , array( $this, 'process_admin_ui' ) );
	}

	/**
	 * Triggers processing of any pending actions.
	 */
	public function process_admin_ui() {
		$this->get_list_table();
	}

	/**
	 * Renders the Admin UI
	 */
	public function render_admin_ui() {
		$table = $this->get_list_table();
		$table->display_page();
	}

	/**
	 * Get the admin UI object and process any requested actions.
	 *
	 * @return ActionScheduler_ListTable
	 */
	protected function get_list_table() {
		if ( null === $this->list_table ) {
			$this->list_table = new ActionScheduler_ListTable( ActionScheduler::store(), ActionScheduler::logger(), ActionScheduler::runner() );
			$this->list_table->process_actions();
		}

		return $this->list_table;
	}

	/**
	 * Provide more information about the screen and its data in the help tab.
	 */
	public function add_help_tabs() {
		$screen = get_current_screen();

		if ( ! $screen || self::$screen_id != $screen->id ) {
			return;
		}

		$as_version = ActionScheduler_Versions::instance()->latest_version();
		$screen->add_help_tab(
			array(
				'id'      => 'action_scheduler_about',
				'title'   => __( '关于', 'woocommerce' ),
				'content' =>
					'<h2>' . sprintf( __( '关于操作计划程序 %s', 'woocommerce' ), $as_version ) . '</h2>' .
					'<p>' .
						__( '操作计划程序是可扩展、可跟踪的作业队列，用于在后台处理大量操作。操作计划程序会在将来的某个时间触发操作钩子以运行。计划操作还可以按照定期计划运行。', 'woocommerce' ) .
					'</p>',
			)
		);

		$screen->add_help_tab(
			array(
				'id'      => 'action_scheduler_columns',
				'title'   => __( '列', 'woocommerce' ),
				'content' =>
					'<h2>' . __( '计划操作列', 'woocommerce' ) . '</h2>' .
					'<ul>' .
					sprintf( '<li><strong>%1$s</strong>: %2$s</li>', __( '钩子', 'woocommerce' ), __( '将触发的操作钩子的名称。', 'woocommerce' ) ) .
					sprintf( '<li><strong>%1$s</strong>: %2$s</li>', __( '状态', 'woocommerce' ), __( '操作状态为“待处理”、“已完成”、“已取消”、“已失败”', 'woocommerce' ) ) .
					sprintf( '<li><strong>%1$s</strong>: %2$s</li>', __( '参数', 'woocommerce' ), __( '传递给操作钩子的可选数据数组。', 'woocommerce' ) ) .
					sprintf( '<li><strong>%1$s</strong>: %2$s</li>', __( '组', 'woocommerce' ), __( '可选操作组。', 'woocommerce' ) ) .
					sprintf( '<li><strong>%1$s</strong>: %2$s</li>', __( '循环', 'woocommerce' ), __( '操作的计划频率。', 'woocommerce' ) ) .
					sprintf( '<li><strong>%1$s</strong>: %2$s</li>', __( '预发布', 'woocommerce' ), __( '操作计划运行的日期/时间。', 'woocommerce' ) ) .
					sprintf( '<li><strong>%1$s</strong>: %2$s</li>', __( '记录', 'woocommerce' ), __( '操作的活动日志。', 'woocommerce' ) ) .
					'</ul>',
			)
		);
	}
}
