/**
 * External dependencies
 */
import { __ } from '@gechiui/i18n';
import { InspectorControls, useBlockProps } from '@gechiui/block-editor';
import { createInterpolateElement } from '@gechiui/element';
import { getAdminLink } from '@woocommerce/settings';
import {
	Disabled,
	PanelBody,
	ToggleControl,
	// eslint-disable-next-line @gechiui/no-unsafe-gc-apis
	__experimentalToggleGroupControl as ToggleGroupControl,
	// eslint-disable-next-line @gechiui/no-unsafe-gc-apis
	__experimentalToggleGroupControlOption as ToggleGroupControlOption,
} from '@gechiui/components';

/**
 * Internal dependencies
 */
import Block from './block';
import withProductSelector from '../shared/with-product-selector';
import { BLOCK_TITLE, BLOCK_ICON } from './constants';

const Edit = ( { attributes, setAttributes } ) => {
	const {
		showProductLink,
		imageSizing,
		showSaleBadge,
		saleBadgeAlign,
	} = attributes;

	const blockProps = useBlockProps();

	return (
		<div { ...blockProps }>
			<InspectorControls>
				<PanelBody
					title={ __( '内容', 'woocommerce' ) }
				>
					<ToggleControl
						label={ __(
							'链接到产品页面',
							'woocommerce'
						) }
						help={ __(
							'将图片链接到单个产品详情。',
							'woocommerce'
						) }
						checked={ showProductLink }
						onChange={ () =>
							setAttributes( {
								showProductLink: ! showProductLink,
							} )
						}
					/>
					<ToggleControl
						label={ __(
							'显示降价标志',
							'woocommerce'
						) }
						help={ __(
							'如果产品正在降价销售，则叠加显示“降价”标志。',
							'woocommerce'
						) }
						checked={ showSaleBadge }
						onChange={ () =>
							setAttributes( {
								showSaleBadge: ! showSaleBadge,
							} )
						}
					/>
					{ showSaleBadge && (
						<ToggleGroupControl
							label={ __(
								'降价标志对齐',
								'woocommerce'
							) }
							value={ saleBadgeAlign }
							onChange={ ( value ) =>
								setAttributes( { saleBadgeAlign: value } )
							}
						>
							<ToggleGroupControlOption
								value="left"
								label={ __(
									'Left',
									'woocommerce'
								) }
							/>
							<ToggleGroupControlOption
								value="center"
								label={ __(
									'Center',
									'woocommerce'
								) }
							/>
							<ToggleGroupControlOption
								value="right"
								label={ __(
									'Right',
									'woocommerce'
								) }
							/>
						</ToggleGroupControl>
					) }
					<ToggleGroupControl
						label={ __(
							'图片尺寸调整',
							'woocommerce'
						) }
						help={ createInterpolateElement(
							__(
								'可以在<a>定制器</a>中修改产品图片裁切。',
								'woocommerce'
							),
							{
								a: (
									// eslint-disable-next-line jsx-a11y/anchor-has-content
									<a
										href={ `${ getAdminLink(
											'customize.php'
										) }?autofocus[panel]=woocommerce&autofocus[section]=woocommerce_product_images` }
										target="_blank"
										rel="noopener noreferrer"
									/>
								),
							}
						) }
						value={ imageSizing }
						onChange={ ( value ) =>
							setAttributes( { imageSizing: value } )
						}
					>
						<ToggleGroupControlOption
							value="full-size"
							label={ __(
								'完整尺寸',
								'woocommerce'
							) }
						/>
						<ToggleGroupControlOption
							value="cropped"
							label={ __(
								'Cropped',
								'woocommerce'
							) }
						/>
					</ToggleGroupControl>
				</PanelBody>
			</InspectorControls>
			<Disabled>
				<Block { ...attributes } />
			</Disabled>
		</div>
	);
};

export default withProductSelector( {
	icon: BLOCK_ICON,
	label: BLOCK_TITLE,
	description: __(
		'选择一个产品以显示其图片。',
		'woocommerce'
	),
} )( Edit );
