/**
 * External dependencies
 */
import { __ } from '@gechiui/i18n';
import { Notice } from 'gechiui-components';
import classnames from 'classnames';

/**
 * Internal dependencies
 */
import ShippingRatesControl from '../../shipping-rates-control';

const ShippingRateSelector = ( {
	hasRates,
	shippingRates,
	isLoadingRates,
} ) => {
	const legend = hasRates
		? __( '配送选项', 'woocommerce' )
		: __( '选择配送选项', 'woocommerce' );
	return (
		<fieldset className="wc-block-components-totals-shipping__fieldset">
			<legend className="screen-reader-text">{ legend }</legend>
			<ShippingRatesControl
				className="wc-block-components-totals-shipping__options"
				collapsible={ true }
				noResultsMessage={
					<Notice
						isDismissible={ false }
						className={ classnames(
							'wc-block-components-shipping-rates-control__no-results-notice',
							'woocommerce-error'
						) }
					>
						{ __(
							'未找到配送选项。',
							'woocommerce'
						) }
					</Notice>
				}
				shippingRates={ shippingRates }
				isLoadingRates={ isLoadingRates }
				context="woocommerce/cart"
			/>
		</fieldset>
	);
};

export default ShippingRateSelector;
