/**
 * External dependencies
 */
import { __ } from '@gechiui/i18n';
import PropTypes from 'prop-types';
import SortSelect from '@woocommerce/base-components/sort-select';

/**
 * Internal dependencies
 */
import './style.scss';

const ReviewSortSelect = ( { onChange, readOnly, value } ) => {
	return (
		<SortSelect
			className="wc-block-review-sort-select wc-block-components-review-sort-select"
			label={ __( '排序方式', 'woocommerce' ) }
			onChange={ onChange }
			options={ [
				{
					key: 'most-recent',
					label: __( '最新', 'woocommerce' ),
				},
				{
					key: 'highest-rating',
					label: __(
						'最高评级',
						'woocommerce'
					),
				},
				{
					key: 'lowest-rating',
					label: __(
						'最低评级',
						'woocommerce'
					),
				},
			] }
			readOnly={ readOnly }
			screenReaderLabel={ __(
				'评价排序依据',
				'woocommerce'
			) }
			value={ value }
		/>
	);
};

ReviewSortSelect.propTypes = {
	onChange: PropTypes.func,
	readOnly: PropTypes.bool,
	value: PropTypes.oneOf( [
		'most-recent',
		'highest-rating',
		'lowest-rating',
	] ),
};

export default ReviewSortSelect;
