/**
 * External dependencies
 */
import { __ } from '@gechiui/i18n';
import { InspectorControls, useBlockProps } from '@gechiui/block-editor';
import { getAdminLink } from '@woocommerce/settings';
import { blocksConfig } from '@woocommerce/block-settings';
import HeadingToolbar from '@woocommerce/editor-components/heading-toolbar';
import BlockTitle from '@woocommerce/editor-components/block-title';
import { Icon, currencyDollar, external } from '@gechiui/icons';
import {
	Placeholder,
	Disabled,
	PanelBody,
	ToggleControl,
	Button,
	// eslint-disable-next-line @gechiui/no-unsafe-gc-apis
	__experimentalToggleGroupControl as ToggleGroupControl,
	// eslint-disable-next-line @gechiui/no-unsafe-gc-apis
	__experimentalToggleGroupControlOption as ToggleGroupControlOption,
} from '@gechiui/components';

/**
 * Internal dependencies
 */
import Block from './block.js';
import './editor.scss';

export default function ( { attributes, setAttributes } ) {
	const {
		heading,
		headingLevel,
		showInputFields,
		showFilterButton,
	} = attributes;

	const blockProps = useBlockProps();

	const getInspectorControls = () => {
		return (
			<InspectorControls key="inspector">
				<PanelBody
					title={ __(
						'区块设置',
						'woocommerce'
					) }
				>
					<ToggleGroupControl
						label={ __(
							'价格范围',
							'woocommerce'
						) }
						value={ showInputFields ? 'editable' : 'text' }
						onChange={ ( value ) =>
							setAttributes( {
								showInputFields: value === 'editable',
							} )
						}
					>
						<ToggleGroupControlOption
							value="editable"
							label={ __(
								'Editable',
								'woocommerce'
							) }
						/>
						<ToggleGroupControlOption
							value="text"
							label={ __(
								'Text',
								'woocommerce'
							) }
						/>
					</ToggleGroupControl>
					<ToggleControl
						label={ __(
							'过滤器按钮',
							'woocommerce'
						) }
						help={
							showFilterButton
								? __(
										'产品仅在按下按钮时更新。',
										'woocommerce'
								  )
								: __(
										'移动滑块时，产品将更新。',
										'woocommerce'
								  )
						}
						checked={ showFilterButton }
						onChange={ () =>
							setAttributes( {
								showFilterButton: ! showFilterButton,
							} )
						}
					/>
					<p>
						{ __(
							'标题级别',
							'woocommerce'
						) }
					</p>
					<HeadingToolbar
						isCollapsed={ false }
						minLevel={ 2 }
						maxLevel={ 7 }
						selectedLevel={ headingLevel }
						onChange={ ( newLevel ) =>
							setAttributes( { headingLevel: newLevel } )
						}
					/>
				</PanelBody>
			</InspectorControls>
		);
	};

	const noProductsPlaceholder = () => (
		<Placeholder
			className="wc-block-price-slider"
			icon={ <Icon icon={ currencyDollar } /> }
			label={ __(
				'按价格筛选产品',
				'woocommerce'
			) }
			instructions={ __(
				'显示过滤产品的价格滑块。',
				'woocommerce'
			) }
		>
			<p>
				{ __(
					"有价格的产品才能按价格过滤，您尚未创建任何产品。",
					'woocommerce'
				) }
			</p>
			<Button
				className="wc-block-price-slider__add-product-button"
				isSecondary
				href={ getAdminLink( 'post-new.php?post_type=product' ) }
			>
				{ __( '添加新产品', 'woocommerce' ) +
					' ' }
				<Icon icon={ external } />
			</Button>
			<Button
				className="wc-block-price-slider__read_more_button"
				isTertiary
				href="https://docs.woocommerce.com/document/managing-products/"
			>
				{ __( '了解更多', 'woocommerce' ) }
			</Button>
		</Placeholder>
	);

	return (
		<div { ...blockProps }>
			{ blocksConfig.productCount === 0 ? (
				noProductsPlaceholder()
			) : (
				<>
					{ getInspectorControls() }
					<BlockTitle
						className="wc-block-price-filter__title"
						headingLevel={ headingLevel }
						heading={ heading }
						onChange={ ( value ) =>
							setAttributes( { heading: value } )
						}
					/>
					<Disabled>
						<Block attributes={ attributes } isEditor={ true } />
					</Disabled>
				</>
			) }
		</div>
	);
}
