/**
 * External dependencies
 */
import { __ } from '@gechiui/i18n';
import { SelectControl } from '@gechiui/components';
import PropTypes from 'prop-types';

/**
 * A pre-configured SelectControl for product orderby settings.
 *
 * @param {Object}            props               Incoming props for the component.
 * @param {string}            props.value
 * @param {function(any):any} props.setAttributes Setter for block attributes.
 */
const ProductOrderbyControl = ( { value, setAttributes } ) => {
	return (
		<SelectControl
			label={ __( '产品排序依据', 'woocommerce' ) }
			value={ value }
			options={ [
				{
					label: __(
						'新鲜度 - 从新到旧',
						'woocommerce'
					),
					value: 'date',
				},
				{
					label: __(
						'价格 - 从低到高',
						'woocommerce'
					),
					value: 'price_asc',
				},
				{
					label: __(
						'价格 - 从高到低',
						'woocommerce'
					),
					value: 'price_desc',
				},
				{
					label: __(
						'评级 - 从高到低',
						'woocommerce'
					),
					value: 'rating',
				},
				{
					label: __(
						'销量 - 从多到少',
						'woocommerce'
					),
					value: 'popularity',
				},
				{
					label: __(
						'标题 - 按字母顺序',
						'woocommerce'
					),
					value: 'title',
				},
				{
					label: __( '菜单排序', 'woocommerce' ),
					value: 'menu_order',
				},
			] }
			onChange={ ( orderby ) => setAttributes( { orderby } ) }
		/>
	);
};

ProductOrderbyControl.propTypes = {
	/**
	 * Callback to update the order setting.
	 */
	setAttributes: PropTypes.func.isRequired,
	/**
	 * The selected order setting.
	 */
	value: PropTypes.string.isRequired,
};

export default ProductOrderbyControl;
