<?php
/**
 * New! Manage your store activity from the Home screen.
 */

namespace Automattic\WooCommerce\Internal\Admin\Notes;

defined( 'ABSPATH' ) || exit;

use Automattic\WooCommerce\Admin\Notes\Note;
use Automattic\WooCommerce\Admin\Notes\NoteTraits;

/**
 * New! Manage your store activity from the Home screen.
 */
class ManageStoreActivityFromHomeScreen {
	/**
	 * Note traits.
	 */
	use NoteTraits;

	/**
	 * Name of the note for use in the database.
	 */
	const NOTE_NAME = 'wc-admin-manage-store-activity-from-home-screen';

	/**
	 * Attach hooks.
	 */
	public function __construct() {
		add_action(
			'woocommerce_updated',
			array( $this, 'possibly_add_note' )
		);
	}

	/**
	 * Get the note.
	 *
	 * @return Note|null
	 */
	public static function get_note() {
		$installed_version = get_option( 'woocommerce_admin_version' );
		// the value can be in 1.9.0-rc.3 format for RC or BETA releases
		// get the version without -rc.3.
		$version_segments  = explode( '-', $installed_version );
		$installed_version = $version_segments[0];
		if ( ! version_compare( $installed_version, '1.9.0', '=' ) ) {
			return;
		}

		$note = new Note();

		$note->set_title( __( '新功能！ 通过主屏幕管理商店活动', 'woocommerce' ) );
		$note->set_content( __( '开始新的一天，了解下一步需要对订单、产品和客户反馈执行哪些操作。<br/><br/>阅读有关如何使用主屏幕上的活动面板的更多信息。', 'woocommerce' ) );
		$note->set_type( Note::E_WC_ADMIN_NOTE_INFORMATIONAL );
		$note->set_name( self::NOTE_NAME );
		$note->set_source( 'woocommerce-admin' );
		$note->add_action(
			'learn-more',
			__( '了解更多', 'woocommerce' ),
			'https://woocommerce.com/document/home-screen/?utm_source=inbox&utm_medium=product',
			Note::E_WC_ADMIN_NOTE_ACTIONED
		);

		return $note;
	}
}
