<?php
/**
 * UpdateStoreDetails class
 */

namespace Automattic\WooCommerce\Internal\Admin\Notes;

defined( 'ABSPATH' ) || exit;

use \Automattic\WooCommerce\Admin\Notes\Note;
use \Automattic\WooCommerce\Admin\Notes\NoteTraits;

/**
 * Adds a note when the profiler is completed.
 */
class UpdateStoreDetails {
	/**
	 * Note traits.
	 */
	use NoteTraits;

	/**
	 * Name of the note for use in the database.
	 */
	const NOTE_NAME = 'wc-admin-update-store-details';

	/**
	 * Get the note.
	 *
	 * @return Note
	 */
	public static function get_note() {
		$onboarding_profile = get_option( 'woocommerce_onboarding_profile', array() );

		// Bail when profile was set up by client.
		if ( isset( $onboarding_profile['setup_client'] ) && $onboarding_profile['setup_client'] ) {
			return;
		}

		// Bail when profile is not yet completed.
		if ( ! isset( $onboarding_profile['completed'] ) || ! $onboarding_profile['completed'] ) {
			return;
		}

		$note = new Note();
		$note->set_title( __( '如果需要，可以编辑商店详细信息', 'woocommerce' ) );
		$note->set_content( __( '成功完成商店资料！ 您可以根据需要随时返回并编辑刚刚共享的详细信息。', 'woocommerce' ) );
		$note->set_type( Note::E_WC_ADMIN_NOTE_INFORMATIONAL );
		$note->set_name( self::NOTE_NAME );
		$note->set_content_data( (object) array() );
		$note->set_source( 'woocommerce-admin' );
		$note->add_action(
			'update-store-details',
			__( '更新商店详细信息', 'woocommerce' ),
			wc_admin_url( '&path=/setup-wizard' )
		);

		return $note;
	}
}
